Package: EasyStat
Type: Package
Title: Automated Statistical Analysis, Visualization and Multi-Format
        Narrative Reporting
Version: 2.0.0
Date: 2026-04-28
Authors@R: c(
    person("Mahesh", "Divakaran",
           email   = "imaheshdivakaran@gmail.com",
           role    = c("aut", "cre"),
           comment = c(Affiliation = "Amity School of Applied Sciences, Amity University Lucknow")),
    person("Gunjan", "Singh",
           role    = "aut",
           comment = c(Affiliation = "Amity School of Applied Sciences, Amity University Lucknow")),
    person("Jayadevan", "Shreedharan",
           role    = "aut",
           comment = c(Affiliation = "Gulf Medical University"))
    )
Description: Provides automated statistical analysis, rich visualization, and
    multi-format narrative reporting through a unified pipeline. Descriptive
    statistics are available via easy_describe() and easy_group_summary().
    Inferential tests with plain-language narratives are provided by
    easy_regression(), easy_logistic_regression(), easy_ttest(), easy_anova(),
    easy_chisq(), easy_ztest(), easy_ftest(), easy_correlation(), easy_wilcox(),
    and easy_kruskal(). Publication-ready 'ggplot2' visualizations are produced
    by easy_histogram(), easy_boxplot(), easy_scatter(), easy_barplot(),
    easy_qqplot(), easy_density(), easy_correlation_heatmap(),
    easy_regression_diagnostics(), and easy_odds_ratio_plot(). The core
    Narrative Generator Module applies conditional logic to extracted p-values,
    effect sizes, and model-fit metrics to produce statistically sound,
    human-readable explanations automatically. Results render in the 'RStudio'
    Viewer (HTML), the console (ASCII), or export directly to Microsoft Word
    via 'flextable' and 'officer'.
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
Depends: R (>= 4.1.0)
RoxygenNote: 7.3.3
Imports: broom (>= 1.0.0), glue (>= 1.6.0), ggplot2 (>= 3.4.0), knitr
        (>= 1.40), kableExtra (>= 1.3.4), htmltools (>= 0.5.0),
        flextable (>= 0.9.0), officer (>= 0.6.0), stats, utils, tools
Suggests: testthat (>= 3.0.0), scales (>= 1.2.0), rmarkdown (>= 2.0)
VignetteBuilder: knitr
URL: https://github.com/itsmdivakaran/Easystat,
        https://itsmdivakaran.github.io/Easystat/
BugReports: https://github.com/itsmdivakaran/Easystat/issues
NeedsCompilation: no
Packaged: 2026-04-29 08:21:54 UTC; maheshdivakaran
Author: Mahesh Divakaran [aut, cre] (Affiliation: Amity School of Applied
    Sciences, Amity University Lucknow),
  Gunjan Singh [aut] (Affiliation: Amity School of Applied Sciences,
    Amity University Lucknow),
  Jayadevan Shreedharan [aut] (Affiliation: Gulf Medical University)
Maintainer: Mahesh Divakaran <imaheshdivakaran@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-29 19:10:14 UTC
Built: R 4.5.2; ; 2026-04-29 20:36:20 UTC; unix

# Generated by roxygen2: do not edit by hand

S3method(print,easystat_result)
S3method(summary,easystat_result)
export(easy_anova)
export(easy_autoplot)
export(easy_barplot)
export(easy_boxplot)
export(easy_chisq)
export(easy_correlation)
export(easy_correlation_heatmap)
export(easy_density)
export(easy_describe)
export(easy_ftest)
export(easy_group_summary)
export(easy_histogram)
export(easy_kruskal)
export(easy_logistic_regression)
export(easy_odds_ratio_plot)
export(easy_qqplot)
export(easy_regression)
export(easy_regression_diagnostics)
export(easy_scatter)
export(easy_ttest)
export(easy_wilcox)
export(easy_ztest)
export(export_to_word)
export(theme_easystat)

# EasyStat <img src="man/figures/logo.svg" align="right" height="139" alt="EasyStat logo"/>

<!-- badges: start -->
[![CRAN status](https://www.r-pkg.org/badges/version/EasyStat)](https://CRAN.R-project.org/package=EasyStat)
[![R-CMD-check](https://github.com/itsmdivakaran/Easystat/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/itsmdivakaran/Easystat/actions/workflows/R-CMD-check.yaml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![pkgdown](https://img.shields.io/badge/docs-pkgdown-blue)](https://itsmdivakaran.github.io/Easystat/)
<!-- badges: end -->

**Automated Statistical Analysis, Visualization, and Multi-Format Narrative Reporting in R**

> **Authors:** Mr. Mahesh Divakaran & Dr. Gunjan Singh (Amity School of Applied Sciences, Amity University Lucknow) - Prof. Dr. Jayadevan Shreedharan (Gulf Medical University)

## Overview

EasyStat bridges the gap between statistical output and actionable insight. A single function call delivers the statistical result, a plain-language narrative interpretation, and publication-ready tables, rendered in the RStudio Viewer, the R console, or Microsoft Word.

User-facing p-values are reported as percentages rounded to 4 decimal places, while raw model objects still retain the original numeric p-values for advanced use.

## Installation

```r
# From CRAN (when available)
install.packages("EasyStat")

# Development version from GitHub
# install.packages("devtools")
devtools::install_github("itsmdivakaran/Easystat")

# From local source
install.packages("path/to/EasyStat", repos = NULL, type = "source")
```

## Quick Start

```r
library(EasyStat)

# Linear regression with narrative
easy_regression(mpg ~ wt + hp, data = mtcars)

# Logistic regression with odds ratios
easy_logistic_regression(am ~ mpg + wt, data = mtcars)

# t-test
easy_ttest(mpg ~ am, data = mtcars)

# One-way ANOVA
easy_anova(Sepal.Length ~ Species, data = iris)

# Descriptive statistics for multiple variables
easy_describe(mtcars, vars = c("mpg", "hp", "wt"))

# Correlation heatmap
easy_correlation_heatmap(mtcars, vars = c("mpg", "hp", "wt", "qsec", "drat"))

# Export any result to Word
result <- easy_logistic_regression(am ~ mpg + wt, data = mtcars)
export_to_word(result, file = "report.docx", title = "Transmission Model",
               author = "Mahesh Divakaran, Gunjan Singh, Jayadevan Shreedharan")
```

## Four-Step Pipeline

| Step | Module | Role |
|------|--------|------|
| 1 | Core Statistical Engine | Wraps `lm()`, `glm()`, `t.test()`, `aov()`, `chisq.test()`, `var.test()`, `cor.test()` |
| 2 | Metric Extractor | Uses model summaries and `broom` helpers to extract p-values, effect sizes, CIs, and fit metrics |
| 3 | Narrative Generator Module | Applies conditional logic to produce plain-language explanations |
| 4 | Unified Result Object | Returns `easystat_result` S3 objects with tables, narrative, and optional plots |

## Function Reference

### Descriptive Statistics

| Function | Description |
|----------|-------------|
| `easy_describe()` | 21-statistic summary for one or more numeric variables |
| `easy_group_summary()` | Stratified descriptives by a grouping factor |

### Regression Models

| Function | Model | Key Output |
|----------|-------|------------|
| `easy_regression()` | Linear regression | R-squared, ANOVA table, diagnostics, influential observations |
| `easy_logistic_regression()` | Binary logistic regression | Odds ratios, OR CIs, classification table, McFadden pseudo-R2 |

### Inferential Tests

| Function | Test | Effect Size |
|----------|------|-------------|
| `easy_ttest()` | Independent / one-sample t-test | Cohen's d |
| `easy_anova()` | One-way ANOVA with post-hoc context | eta-squared |
| `easy_chisq()` | Chi-square independence and GOF | Cramér's V |
| `easy_ztest()` | One- and two-sample z-test | Cohen's d |
| `easy_ftest()` | F-test for equality of variances | Variance ratio + CI |
| `easy_correlation()` | Pearson / Spearman / Kendall correlation and matrix | r, r-squared |
| `easy_wilcox()` | Wilcoxon rank-sum / signed-rank test | Median comparison + CI |
| `easy_kruskal()` | Kruskal-Wallis test | Rank-based eta-squared |

### Visualizations

| Function | Plot type |
|----------|-----------|
| `easy_histogram()` | Histogram with normal-curve overlay |
| `easy_boxplot()` | Grouped box-and-whisker plot |
| `easy_scatter()` | Scatter plot with regression line and R-squared |
| `easy_barplot()` | Count or mean (+/- SE) bar chart |
| `easy_qqplot()` | Q-Q normality plot |
| `easy_density()` | Kernel density curve, optionally grouped |
| `easy_correlation_heatmap()` | Annotated pairwise correlation heatmap |
| `easy_regression_diagnostics()` | Fitted-vs-residuals diagnostic plot |
| `easy_odds_ratio_plot()` | Logistic regression odds-ratio plot |
| `easy_autoplot()` | Smart dispatcher that picks the right plot for a result |

### Theme & Export

| Function | Description |
|----------|-------------|
| `theme_easystat()` | Consistent ggplot2 theme for all plots |
| `export_to_word()` | Formatted `.docx` report with flextable and officer |

## Output Modes

| Mode | Trigger |
|------|---------|
| RStudio HTML Viewer | Auto-detected in interactive sessions |
| Console | Scripts, terminals, non-interactive sessions |
| Word `.docx` | `export_to_word()` |

## Running the Smoke Test

```r
source(system.file("smoke_test.R", package = "EasyStat"))
```

## Citation

If you use EasyStat in your research, please cite:

> Divakaran M., Singh G., & Shreedharan J. (2026). *EasyStat: Automated Statistical Analysis, Visualization and Multi-Format Narrative Reporting in R* (Version 2.0.0). Amity University Lucknow & Gulf Medical University. <https://itsmdivakaran.github.io/Easystat/index.html>

## License

MIT (c) 2026 EasyStat Authors. See [LICENSE](LICENSE) for details.

# ============================================================================
# EasyStat v2.0 — Full Smoke Test Suite
# ============================================================================
# INSTALL (once):
#   install.packages(c("broom","glue","ggplot2","knitr","kableExtra",
#                      "htmltools","flextable","officer"))
#   install.packages("path/to/EasyStat", repos=NULL, type="source")
#
# RUN:
#   source(system.file("smoke_test.R", package = "EasyStat"))
# ============================================================================

library(EasyStat)

PASS    <- function(lbl) cat(sprintf("  [PASS] %s\n", lbl))
SECTION <- function(lbl) cat(sprintf("\n%s\n  %s\n%s\n", strrep("=",58), lbl, strrep("=",58)))

# ============================================================
SECTION("1. DESCRIPTIVE STATISTICS")
# ============================================================

r <- easy_describe(mtcars$mpg)
stopifnot(inherits(r, "easystat_result"), r$test_type == "describe")
PASS("easy_describe (single vector)")

r <- easy_describe(mtcars, vars = c("mpg","hp","wt"))
stopifnot(nrow(r$coefficients_table) == 3)
PASS("easy_describe (data frame, 3 vars)")
print(r, viewer = FALSE)

r <- easy_group_summary(mpg ~ cyl, data = mtcars)
stopifnot(nrow(r$coefficients_table) == 3)
PASS("easy_group_summary (mpg ~ cyl)")
print(r, viewer = FALSE)

# ============================================================
SECTION("2. CORE INFERENTIAL TESTS")
# ============================================================

r <- easy_regression(mpg ~ wt + hp, data = mtcars)
stopifnot(r$test_type == "regression")
stopifnot("Regression Diagnostics" %in% names(r$additional_tables))
PASS("easy_regression (mpg ~ wt + hp)")
print(r, viewer = FALSE)

r <- easy_logistic_regression(am ~ mpg + wt, data = mtcars)
stopifnot(r$test_type == "logistic_regression")
stopifnot("Confusion Matrix" %in% names(r$additional_tables))
PASS("easy_logistic_regression (am ~ mpg + wt)")
print(r, viewer = FALSE)

r <- easy_ttest(mpg ~ am, data = mtcars)
stopifnot(r$test_type == "ttest"); PASS("easy_ttest (mpg ~ am)")

r <- easy_anova(Sepal.Length ~ Species, data = iris)
stopifnot(r$test_type == "anova")
stopifnot("Tukey Post-hoc Comparisons" %in% names(r$additional_tables))
PASS("easy_anova")
print(r, viewer = FALSE)

# ============================================================
SECTION("3. EXTENDED INFERENTIAL TESTS")
# ============================================================

r <- easy_chisq(~ cyl + am, data = mtcars)
stopifnot(r$test_type == "chisq")
stopifnot("Observed Contingency Table" %in% names(r$additional_tables))
PASS("easy_chisq independence")
print(r, viewer = FALSE)

r <- easy_chisq(~ cyl, data = mtcars)
stopifnot(r$test_type == "chisq"); PASS("easy_chisq GOF")

r <- easy_ztest(mtcars$mpg, mu = 20)
stopifnot(r$test_type == "ztest"); PASS("easy_ztest one-sample")
print(r, viewer = FALSE)

r <- easy_ztest(mpg ~ am, data = mtcars)
stopifnot(r$test_type == "ztest"); PASS("easy_ztest two-sample (formula)")

r <- easy_ftest(mpg ~ am, data = mtcars)
stopifnot(r$test_type == "ftest"); PASS("easy_ftest")
print(r, viewer = FALSE)

r <- easy_correlation(~ mpg + wt, data = mtcars)
stopifnot(r$test_type == "correlation"); PASS("easy_correlation bivariate")
print(r, viewer = FALSE)

r <- easy_correlation(mtcars, vars = c("mpg","hp","wt","disp"))
stopifnot(r$test_type == "correlation_matrix"); PASS("easy_correlation matrix")

r <- easy_wilcox(mpg ~ am, data = mtcars)
stopifnot(r$test_type == "wilcox"); PASS("easy_wilcox")

r <- easy_kruskal(Sepal.Length ~ Species, data = iris)
stopifnot(r$test_type == "kruskal"); PASS("easy_kruskal")

# ============================================================
SECTION("4. VISUALIZATIONS")
# ============================================================

p <- easy_histogram("mpg", data = mtcars)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_histogram")
print(p$plot_object)

p <- easy_boxplot(Sepal.Length ~ Species, data = iris)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_boxplot (grouped)")
print(p$plot_object)

p <- easy_scatter(mpg ~ wt, data = mtcars)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_scatter")
print(p$plot_object)

p <- easy_barplot("cyl", data = mtcars)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_barplot (count)")
print(p$plot_object)

p <- easy_barplot("mpg", data = mtcars, group_by = "cyl", stat = "mean")
PASS("easy_barplot (mean +/- SE)")

p <- easy_qqplot("mpg", data = mtcars)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_qqplot")
print(p$plot_object)

p <- easy_density("Sepal.Length", data = iris)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_density (single)")

p <- easy_density("Sepal.Length", data = iris, group_by = "Species")
PASS("easy_density (grouped by Species)")
print(p$plot_object)

p <- easy_correlation_heatmap(mtcars, vars = c("mpg","hp","wt","qsec","drat"))
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_correlation_heatmap")
print(p$plot_object)

reg_result <- easy_regression(mpg ~ wt, data = mtcars)
p <- easy_regression_diagnostics(reg_result)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_regression_diagnostics")

logit_result <- easy_logistic_regression(am ~ mpg + wt, data = mtcars)
p <- easy_odds_ratio_plot(logit_result)
stopifnot(inherits(p$plot_object, "gg")); PASS("easy_odds_ratio_plot")

easy_autoplot(reg_result, data = mtcars)
PASS("easy_autoplot (regression -> scatter)")

# ============================================================
SECTION("5. WORD EXPORT")
# ============================================================

tmp <- tempfile(fileext = ".docx")
export_to_word(reg_result, file = tmp,
  title  = "EasyStat v2.0 Smoke Test",
  author = "Mr. Mahesh Divakaran, Dr. Gunjan Singh, Prof. Dr. Jayadevan Shreedharan")
stopifnot(file.exists(tmp), file.size(tmp) > 5000)
PASS(paste0("export_to_word -> ", basename(tmp)))

cat(sprintf("\n%s\n  ALL TESTS PASSED\n%s\n\n", strrep("=",58), strrep("=",58)))

#' One-Sample and Two-Sample Z-Tests with Automated Narrative Reporting
#'
#' Performs a z-test using the normal distribution. When the population
#' standard deviation (\code{sigma}) is not provided, the sample SD is used
#' (valid for large samples, n \eqn{\geq} 30, by the Central Limit Theorem).
#' Key metrics — z-statistic, p-value, confidence interval, and Cohen's d —
#' are extracted and fed to the Narrative Generator Module.
#'
#' @param x A numeric vector (Group 1), OR a formula \code{outcome ~ group}
#'   for a two-sample test when \code{data} is provided.
#' @param y A numeric vector (Group 2) for a two-sample test. Ignored when
#'   \code{x} is a formula.
#' @param data A data frame. Required when \code{x} is a formula.
#' @param mu Hypothesized population mean (one-sample) or mean difference
#'   (two-sample). Default \code{0}.
#' @param sigma Known population SD for Group 1 (or the single group).
#'   If \code{NULL} (default), the sample SD is used.
#' @param sigma2 Known population SD for Group 2. If \code{NULL}, uses
#'   the sample SD of Group 2.
#' @param alternative \code{"two.sided"} (default), \code{"less"},
#'   or \code{"greater"}.
#' @param conf_level Confidence level. Default \code{0.95}.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An \code{"easystat_result"} object.
#'
#' @examples
#' # One-sample z-test (large n, CLT)
#' result <- easy_ztest(mtcars$mpg, mu = 20)
#' print(result)
#'
#' # Two-sample z-test via formula
#' result <- easy_ztest(mpg ~ am, data = mtcars)
#' print(result)
#'
#' @export
easy_ztest <- function(x, y = NULL, data = NULL, mu = 0,
                       sigma = NULL, sigma2 = NULL,
                       alternative = "two.sided",
                       conf_level = 0.95, alpha = 0.05) {

  alt_choices <- c("two.sided", "less", "greater")
  alternative <- match.arg(alternative, alt_choices)

  label       <- NULL
  grp1_name   <- "Sample"
  grp2_name   <- NULL
  two_sample  <- FALSE

  # ---- Parse inputs ----
  if (inherits(x, "formula") || is.character(x)) {
    if (is.character(x)) x <- stats::as.formula(x)
    if (is.null(data)) stop("'data' must be provided when 'x' is a formula.")
    vars <- all.vars(x)
    outcome_var <- vars[1]; group_var <- vars[2]
    label <- deparse(x)
    grp_levels <- levels(factor(data[[group_var]]))
    if (length(grp_levels) != 2)
      stop("The grouping variable must have exactly 2 levels for a two-sample z-test.")
    grp1_name  <- grp_levels[1]; grp2_name <- grp_levels[2]
    x_vec <- data[[outcome_var]][data[[group_var]] == grp_levels[1]]
    y_vec <- data[[outcome_var]][data[[group_var]] == grp_levels[2]]
    two_sample <- TRUE
  } else {
    x_vec <- x
    if (!is.null(y)) { y_vec <- y; two_sample <- TRUE }
    label <- if (two_sample) "Two-sample comparison (x vs. y)" else "One-sample test"
    grp1_name <- deparse(substitute(x))
    grp2_name <- if (two_sample) deparse(substitute(y)) else NULL
  }

  x_vec <- x_vec[!is.na(x_vec)]
  n1    <- length(x_vec)
  if (n1 < 2) stop("Group 1 must have at least 2 observations.")
  x_bar <- mean(x_vec)
  s1    <- if (is.null(sigma))  stats::sd(x_vec) else sigma

  if (n1 < 30 && is.null(sigma))
    warning("n < 30 and sigma unknown: z-test assumes CLT (large-sample approximation). Consider t-test instead.")

  z_crit <- stats::qnorm((1 + conf_level) / 2)

  if (!two_sample) {
    # ---- ONE-SAMPLE Z-TEST ----
    se_1   <- s1 / sqrt(n1)
    z_stat <- (x_bar - mu) / se_1
    ci_lo  <- x_bar - z_crit * se_1
    ci_hi  <- x_bar + z_crit * se_1
    d      <- (x_bar - mu) / s1

    p_val  <- switch(alternative,
      two.sided = 2 * stats::pnorm(-abs(z_stat)),
      less      = stats::pnorm(z_stat),
      greater   = stats::pnorm(z_stat, lower.tail = FALSE)
    )

    coef_tbl <- data.frame(
      Metric = c(paste0("Sample mean (", grp1_name, ")"),
                 "Hypothesised mean (\u03bc\u2080)",
                 "Mean difference",
                 paste0(round(conf_level * 100), "% CI lower"),
                 paste0(round(conf_level * 100), "% CI upper"),
                 "SD used (sigma)",
                 "Standard Error"),
      Value  = c(round(x_bar, 6), mu, round(x_bar - mu, 6),
                 round(ci_lo, 6), round(ci_hi, 6),
                 round(s1, 6), round(se_1, 6)),
      stringsAsFactors = FALSE
    )
    metrics <- list(test_type_z = "one_sample", z_stat = z_stat, p_value = p_val,
                    x_bar = x_bar, mu = mu, ci_lower = ci_lo, ci_upper = ci_hi,
                    cohens_d = d)

  } else {
    # ---- TWO-SAMPLE Z-TEST ----
    y_vec  <- y_vec[!is.na(y_vec)]
    n2     <- length(y_vec)
    if (n2 < 2) stop("Group 2 must have at least 2 observations.")
    x_bar2 <- mean(y_vec)
    s2     <- if (is.null(sigma2)) stats::sd(y_vec) else sigma2

    if (n2 < 30 && is.null(sigma2))
      warning("Group 2: n < 30 and sigma unknown. Using CLT approximation.")

    se_2   <- sqrt(s1^2 / n1 + s2^2 / n2)
    diff   <- x_bar - x_bar2
    z_stat <- (diff - mu) / se_2
    ci_lo  <- diff - z_crit * se_2
    ci_hi  <- diff + z_crit * se_2

    # Pooled SD for Cohen's d
    sp     <- sqrt(((n1 - 1) * s1^2 + (n2 - 1) * s2^2) / (n1 + n2 - 2))
    d      <- diff / sp

    p_val  <- switch(alternative,
      two.sided = 2 * stats::pnorm(-abs(z_stat)),
      less      = stats::pnorm(z_stat),
      greater   = stats::pnorm(z_stat, lower.tail = FALSE)
    )

    coef_tbl <- data.frame(
      Metric = c(paste0("Mean \u2014 ", grp1_name), paste0("Mean \u2014 ", grp2_name),
                 "Mean difference",
                 paste0(round(conf_level * 100), "% CI lower"),
                 paste0(round(conf_level * 100), "% CI upper"),
                 paste0("SD (", grp1_name, ")"), paste0("SD (", grp2_name, ")"),
                 paste0("n (", grp1_name, ")"),  paste0("n (", grp2_name, ")")),
      Value  = c(round(x_bar, 6), round(x_bar2, 6), round(diff, 6),
                 round(ci_lo, 6), round(ci_hi, 6),
                 round(s1, 6), round(s2, 6), n1, n2),
      stringsAsFactors = FALSE
    )
    metrics <- list(test_type_z = "two_sample", z_stat = z_stat, p_value = p_val,
                    x_bar = x_bar, x_bar2 = x_bar2, mu = mu,
                    ci_lower = ci_lo, ci_upper = ci_hi, cohens_d = d)
  }

  fit_tbl <- data.frame(
    Metric = c("z-statistic", "p-value", "Alternative", "Cohen's d", "Effect size class"),
    Value  = c(round(z_stat, 4),
               .format_p_value(p_val),
               alternative,
               round(metrics$cohens_d, 4),
               .cohens_d_label(metrics$cohens_d)),
    stringsAsFactors = FALSE
  )

  explanation <- .generate_ztest_narrative(metrics, label)

  structure(
    list(
      test_type          = "ztest",
      formula_str        = label,
      raw_model          = list(z = z_stat, p = p_val, ci = c(ci_lo, ci_hi)),
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

# Internal formatting helpers -------------------------------------------------

.format_p_value <- function(p_value, digits = 4) {
  vapply(p_value, function(p) {
    if (is.na(p)) return("NA")

    pct <- p * 100
    eps <- 10^-digits

    if (pct > 0 && pct < eps) {
      paste0("<", formatC(eps, format = "f", digits = digits), "%")
    } else {
      paste0(formatC(pct, format = "f", digits = digits), "%")
    }
  }, character(1), USE.NAMES = FALSE)
}

.format_p_statement <- function(p_value, digits = 4) {
  p_text <- .format_p_value(p_value, digits = digits)
  ifelse(grepl("^<", p_text),
         paste0("p < ", sub("^<", "", p_text)),
         paste0("p = ", p_text))
}

.format_compact_number <- function(x, digits = 4) {
  vapply(x, function(value) {
    if (is.na(value)) return("NA")
    if (abs(value) >= 10000 || (abs(value) > 0 && abs(value) < 0.0001)) {
      formatC(value, format = "e", digits = digits)
    } else {
      formatC(value, format = "f", digits = digits)
    }
  }, character(1), USE.NAMES = FALSE)
}

# zzz.R \u2014 Package-level declarations for R CMD check compliance

# Suppress "no visible binding for global variable" notes arising from
# ggplot2 aes() / dplyr non-standard evaluation in easy_plots.R.
utils::globalVariables(c(
  # ggplot2 .data pronoun
  ".data",
  # Variables created inside dplyr / base aggregation in easy_plots.R
  "freq", "pct", "mean_val", "se", "med",
  # Reshaping / melting variable names used in correlation heatmap
  "Var1", "Var2", "r", "label",
  # Misc intermediate columns in barplot / density helpers
  "v", "y", "ave",
  # stats::ave is imported separately; suppress the column name "ave" note
  "grp_mean",
  # ggplot2 computed aesthetic 'density' used in easy_histogram after_stat()
  "density"
))

# Print and Display Methods for EasyStat Results
# Provides console, plain-text, and HTML Viewer rendering for
# easystat_result objects. Depending on whether the session is
# interactive and whether the RStudio Viewer is available, output is
# automatically directed to the most suitable output channel.
# (Internal module)

# ---------------------------------------------------------------------------
# print.easystat_result  \u2014  smart dispatcher
# ---------------------------------------------------------------------------

#' Print an EasyStat Result Object
#'
#' Automatically renders an \code{easystat_result} object. In an interactive
#' RStudio session the HTML Viewer is used; otherwise clean ASCII tables and
#' the plain-language narrative are written to the console.
#'
#' @param x An object of class \code{"easystat_result"}.
#' @param viewer Logical. Force HTML Viewer output (\code{TRUE}) or console
#'   output (\code{FALSE}). Default \code{NULL} auto-detects.
#' @param ... Currently ignored.
#'
#' @return \code{x} invisibly.
#' @export
print.easystat_result <- function(x, viewer = NULL, ...) {

  # Auto-detect preferred output mode
  use_viewer <- if (!is.null(viewer)) {
    isTRUE(viewer)
  } else {
    interactive() &&
      !is.null(getOption("viewer")) &&
      requireNamespace("htmltools", quietly = TRUE) &&
      requireNamespace("knitr",     quietly = TRUE) &&
      requireNamespace("kableExtra",quietly = TRUE)
  }

  if (use_viewer) {
    .render_html_viewer(x)
  } else {
    .render_console(x)
  }

  invisible(x)
}

# ---------------------------------------------------------------------------
# Console renderer  (ASCII / plain-text)
# ---------------------------------------------------------------------------
.render_console <- function(x) {
  width  <- max(getOption("width", 80), 60)
  border <- paste(rep("=", width), collapse = "")
  thin   <- paste(rep("-", width), collapse = "")

  cat("\n", border, "\n", sep = "")
  cat(" EasyStat Result :: ", toupper(x$test_type), "\n", sep = "")
  cat(border, "\n\n", sep = "")

  # --- Coefficients / Main Table ---
  cat("TABLE 1 \u2014 MAIN RESULTS\n")
  cat(thin, "\n", sep = "")
  print(x$coefficients_table, row.names = FALSE)
  cat("\n")

  # --- Model Fit / Summary Table ---
  cat("TABLE 2 \u2014 MODEL FIT / SUMMARY\n")
  cat(thin, "\n", sep = "")
  print(x$model_fit_table, row.names = FALSE)
  cat("\n")

  if (!is.null(x$additional_tables) && length(x$additional_tables) > 0) {
    table_no <- 3
    for (nm in names(x$additional_tables)) {
      cat("TABLE ", table_no, " \u2014 ", toupper(nm), "\n", sep = "")
      cat(thin, "\n", sep = "")
      print(x$additional_tables[[nm]], row.names = FALSE)
      cat("\n")
      table_no <- table_no + 1
    }
  }

  # --- Narrative ---
  cat(border, "\n", sep = "")
  cat(" PLAIN-LANGUAGE INTERPRETATION\n")
  cat(border, "\n\n", sep = "")

  # Word-wrap narrative to console width
  narrative_lines <- strwrap(x$explanation, width = width - 2, exdent = 2)
  cat(paste(narrative_lines, collapse = "\n"), "\n\n", sep = "")

  cat(border, "\n\n", sep = "")
}

# ---------------------------------------------------------------------------
# HTML Viewer renderer
# ---------------------------------------------------------------------------
.render_html_viewer <- function(x) {
  # Defensive require
  if (!requireNamespace("htmltools",  quietly = TRUE) ||
      !requireNamespace("knitr",      quietly = TRUE) ||
      !requireNamespace("kableExtra", quietly = TRUE)) {
    message("HTML Viewer packages not available. Falling back to console output.")
    .render_console(x)
    return(invisible(NULL))
  }

  test_label <- switch(x$test_type,
    regression          = "Linear Regression",
    logistic_regression = "Logistic Regression",
    ttest               = "Independent-Samples t-Test",
    anova               = "One-Way ANOVA",
    toupper(x$test_type)
  )

  # Build kable tables with kableExtra styling
  tbl1_html <- knitr::kable(x$coefficients_table, format = "html",
                             caption = "Table 1 \u2014 Main Results",
                             align = "l") |>
    kableExtra::kable_styling(
      bootstrap_options = c("striped", "hover", "condensed", "bordered"),
      full_width        = TRUE,
      font_size         = 13
    ) |>
    kableExtra::row_spec(0, bold = TRUE, background = "#2E5FA3", color = "white")

  tbl2_html <- knitr::kable(x$model_fit_table, format = "html",
                             caption = "Table 2 \u2014 Model Fit / Summary",
                             align = "l") |>
    kableExtra::kable_styling(
      bootstrap_options = c("striped", "hover", "condensed", "bordered"),
      full_width        = FALSE,
      font_size         = 13
    ) |>
    kableExtra::row_spec(0, bold = TRUE, background = "#2E5FA3", color = "white")

  extra_html <- ""
  if (!is.null(x$additional_tables) && length(x$additional_tables) > 0) {
    extra_html <- paste(vapply(names(x$additional_tables), function(nm) {
      tbl <- knitr::kable(x$additional_tables[[nm]], format = "html",
                          caption = paste("Table -", nm), align = "l") |>
        kableExtra::kable_styling(
          bootstrap_options = c("striped", "hover", "condensed", "bordered"),
          full_width = TRUE,
          font_size = 13
        ) |>
        kableExtra::row_spec(0, bold = TRUE, background = "#2E5FA3", color = "white")
      paste0('<div class="section-title" style="margin-top:28px;">',
             htmltools::htmlEscape(nm), "</div>", as.character(tbl))
    }, character(1)), collapse = "\n")
  }

  # Wrap narrative paragraphs
  narrative_paragraphs <- strsplit(x$explanation, "\n")[[1]]
  narrative_html <- paste0(
    '<p style="font-family:Arial,sans-serif;font-size:14px;line-height:1.7;',
    'color:#222;margin:8px 0;">',
    htmltools::htmlEscape(narrative_paragraphs),
    "</p>",
    collapse = "\n"
  )

  # Full HTML page
  full_html <- htmltools::HTML(paste0('
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
<title>EasyStat \u2014 ', test_label, '</title>
<style>
  body { font-family: Arial, sans-serif; max-width: 900px; margin: 30px auto;
         padding: 0 20px; background: #F8F9FA; color: #222; }
  .header { background: #2E5FA3; color: white; padding: 18px 24px;
            border-radius: 8px 8px 0 0; margin-bottom: 0; }
  .header h1 { margin: 0; font-size: 20px; letter-spacing: 0.5px; }
  .header p  { margin: 4px 0 0; font-size: 13px; opacity: 0.85; }
  .card { background: white; border: 1px solid #DEE2E6; padding: 20px 24px;
          margin-bottom: 16px; border-radius: 0 0 8px 8px; }
  .section-title { font-size: 15px; font-weight: bold; color: #2E5FA3;
                   border-bottom: 2px solid #2E5FA3; padding-bottom: 6px;
                   margin: 20px 0 12px; }
  .narrative-box { background: #EEF3FB; border-left: 4px solid #2E5FA3;
                   padding: 16px 20px; border-radius: 4px; margin-top: 16px; }
  .narrative-box p { margin: 0 0 10px; }
  .narrative-box p:last-child { margin-bottom: 0; }
  .footer { font-size: 11px; color: #888; text-align: right;
            margin-top: 10px; padding-top: 8px; border-top: 1px solid #DEE2E6; }
</style>
</head>
<body>
<div class="header">
  <h1>EasyStat &mdash; ', htmltools::htmlEscape(test_label), '</h1>
  <p>Formula / Comparison: <em>', htmltools::htmlEscape(x$formula_str), '</em></p>
</div>
<div class="card">
  <div class="section-title">Main Results</div>
  ', as.character(tbl1_html), '
  <div class="section-title" style="margin-top:28px;">Model Fit / Summary</div>
  ', as.character(tbl2_html), '
  ', extra_html, '
  <div class="section-title" style="margin-top:28px;">Plain-Language Interpretation</div>
  <div class="narrative-box">
  ', narrative_html, '
  </div>
  <div class="footer">Generated by EasyStat &bull; ', format(Sys.time(), "%Y-%m-%d %H:%M"), '</div>
</div>
</body>
</html>
'))

  # Write to temp file and open in Viewer
  tmp <- tempfile(fileext = ".html")
  htmltools::save_html(full_html, file = tmp)
  viewer_fn <- getOption("viewer")
  if (!is.null(viewer_fn)) {
    viewer_fn(tmp)
  } else {
    utils::browseURL(tmp)
  }
  invisible(NULL)
}

# ---------------------------------------------------------------------------
# summary method \u2014 alias to print
# ---------------------------------------------------------------------------

#' Summarize an EasyStat Result Object
#' @param object An \code{"easystat_result"} object.
#' @param ... Passed to \code{print.easystat_result}.
#' @return Called for its side effects (printing to the console or RStudio
#'   Viewer). Returns \code{object} invisibly via
#'   \code{\link{print.easystat_result}}.
#' @export
summary.easystat_result <- function(object, ...) {
  print.easystat_result(object, ...)
}

#' Run an Independent-Samples t-Test with Automated Narrative Reporting
#'
#' Executes a two-sample (or one-sample) t-test using \code{stats::t.test()},
#' extracts key metrics via \code{broom}, and generates a plain-language
#' narrative via the Narrative Generator Module.
#'
#' @param x A numeric vector, OR a formula of the form \code{outcome ~ group}
#'   when \code{data} is provided.
#' @param y A numeric vector (second group) when \code{x} is not a formula.
#'   Ignored when \code{x} is a formula.
#' @param data A data frame. Required when \code{x} is a formula.
#' @param mu Null hypothesis value for the mean (one-sample test). Default \code{0}.
#' @param var.equal Logical; assume equal variances? Default \code{FALSE} (Welch).
#' @param conf.level Confidence level. Default \code{0.95}.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An object of class \code{"easystat_result"} with:
#'   \describe{
#'     \item{\code{test_type}}{Character: \code{"ttest"}}
#'     \item{\code{formula_str}}{Description of the comparison}
#'     \item{\code{raw_model}}{The raw \code{htest} object}
#'     \item{\code{coefficients_table}}{Group means and confidence interval}
#'     \item{\code{model_fit_table}}{t-statistic, df, and p-value}
#'     \item{\code{explanation}}{Plain-language narrative string}
#'   }
#'
#' @examples
#' result <- easy_ttest(mpg ~ am, data = mtcars)
#' print(result)
#'
#' @export
easy_ttest <- function(x, y = NULL, data = NULL, mu = 0,
                       var.equal = FALSE, conf.level = 0.95, alpha = 0.05) {

  # ---- Input handling: formula vs. vectors ----
  formula_str <- NULL
  grp1_name   <- "Group 1"
  grp2_name   <- "Group 2"

  if (inherits(x, "formula") || is.character(x)) {
    if (is.character(x)) x <- stats::as.formula(x)
    if (is.null(data)) stop("'data' must be provided when 'x' is a formula.")

    formula_str <- deparse(x)
    vars        <- all.vars(x)
    outcome_var <- vars[1]
    group_var   <- vars[2]

    group_levels <- levels(factor(data[[group_var]]))
    if (length(group_levels) != 2) {
      stop("The grouping variable must have exactly 2 levels for an independent-samples t-test.")
    }
    grp1_name <- as.character(group_levels[1])
    grp2_name <- as.character(group_levels[2])

    # ---- Step 1: Core Statistical Engine ----
    ttest_result <- stats::t.test(x, data = data, var.equal = var.equal,
                                  conf.level = conf.level)
  } else {
    if (!is.numeric(x)) stop("'x' must be a numeric vector or a formula.")
    formula_str <- if (!is.null(y)) "Two-sample comparison (x vs. y)" else "One-sample test"
    # ---- Step 1: Core Statistical Engine ----
    if (!is.null(y)) {
      ttest_result <- stats::t.test(x, y, mu = mu, var.equal = var.equal,
                                    conf.level = conf.level)
      grp1_name <- deparse(substitute(x))
      grp2_name <- deparse(substitute(y))
    } else {
      ttest_result <- stats::t.test(x, mu = mu, conf.level = conf.level)
      grp1_name <- "sample"
      grp2_name <- NULL
    }
  }

  # ---- Step 2: Metric Extractor Module (broom) ----
  tidy_result <- broom::tidy(ttest_result)
  t_stat      <- tidy_result$statistic
  df_val      <- tidy_result$parameter
  p_val       <- tidy_result$p.value
  est1        <- tidy_result$estimate1
  est2        <- if ("estimate2" %in% names(tidy_result)) tidy_result$estimate2 else NA
  conf_lo     <- tidy_result$conf.low
  conf_hi     <- tidy_result$conf.high

  # Coefficients table (group means + CI)
  coef_rows <- list(
    c("Mean (Group 1)", grp1_name, round(est1, 4)),
    c("Mean (Group 2)", grp2_name, round(est2, 4)),
    c("95% CI (lower)", "-", round(conf_lo, 4)),
    c("95% CI (upper)", "-", round(conf_hi, 4))
  )
  coef_tbl <- as.data.frame(do.call(rbind, coef_rows), stringsAsFactors = FALSE)
  colnames(coef_tbl) <- c("Metric", "Label", "Value")

  # Model fit table
  fit_tbl <- data.frame(
    Metric = c("t-statistic", "Degrees of Freedom", "p-value"),
    Value  = c(round(t_stat, 4), round(df_val, 2), .format_p_value(p_val)),
    stringsAsFactors = FALSE
  )

  # Metrics bundle
  metrics <- list(
    p_value   = p_val,
    statistic = t_stat,
    parameter = df_val,
    estimate1 = est1,
    estimate2 = est2,
    conf_low  = conf_lo,
    conf_high = conf_hi,
    group1    = grp1_name,
    group2    = grp2_name
  )

  # ---- Step 3: Narrative Generator Module ----
  explanation <- .generate_ttest_narrative(metrics, formula_str)

  # ---- Step 4: Unified Result Object ----
  result <- structure(
    list(
      test_type          = "ttest",
      formula_str        = formula_str,
      raw_model          = ttest_result,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation
    ),
    class = "easystat_result"
  )

  result
}

#' Run a One-Way ANOVA with Automated Narrative Reporting
#'
#' Executes a one-way ANOVA using \code{stats::aov()}, extracts key metrics
#' via \code{broom}, computes eta-squared as an effect-size measure, and
#' generates a plain-language narrative via the Narrative Generator Module.
#'
#' @param formula A \code{formula} of the form \code{outcome ~ group_factor}, or
#'   a character string. Passed directly to \code{stats::aov()}.
#' @param data A data frame containing the variables in \code{formula}.
#' @param alpha Significance threshold for the narrative. Default \code{0.05}.
#'
#' @return An object of class \code{"easystat_result"} with:
#'   \describe{
#'     \item{\code{test_type}}{Character: \code{"anova"}}
#'     \item{\code{formula_str}}{Character string of the formula used}
#'     \item{\code{raw_model}}{The raw \code{aov} object}
#'     \item{\code{coefficients_table}}{ANOVA table (SS, df, MS, F, p)}
#'     \item{\code{model_fit_table}}{Summary metrics (F-statistic, eta-squared, p-value)}
#'     \item{\code{explanation}}{Plain-language narrative string}
#'   }
#'
#' @examples
#' result <- easy_anova(Sepal.Length ~ Species, data = iris)
#' print(result)
#'
#' @export
easy_anova <- function(formula, data, alpha = 0.05) {

  # ---- Input validation ----
  if (is.character(formula)) formula <- stats::as.formula(formula)
  if (!inherits(formula, "formula")) stop("'formula' must be a formula object or a character string.")
  if (!is.data.frame(data))          stop("'data' must be a data frame.")

  formula_str <- deparse(formula)

  # ---- Step 1: Core Statistical Engine ----
  model <- stats::aov(formula, data = data)

  # ---- Step 2: Metric Extractor Module (broom) ----
  tidy_df  <- broom::tidy(model)
  tidy_df  <- as.data.frame(tidy_df)

  # Build clean ANOVA table
  coef_tbl <- tidy_df
  colnames(coef_tbl) <- c("Source", "df", "Sum of Squares", "Mean Square",
                           "F Statistic", "p-value")
  coef_tbl[, 2:5] <- lapply(coef_tbl[, 2:5], function(v) round(as.numeric(v), 4))
  coef_tbl[, 6]   <- .format_p_value(as.numeric(coef_tbl[, 6]))

  # Extract primary effect row (first non-Residuals row)
  effect_row <- tidy_df[tidy_df$term != "Residuals", , drop = FALSE][1, ]
  resid_row  <- tidy_df[tidy_df$term == "Residuals", , drop = FALSE][1, ]

  f_stat  <- as.numeric(effect_row$statistic)
  p_val   <- as.numeric(effect_row$p.value)
  df_grp  <- as.numeric(effect_row$df)
  df_res  <- as.numeric(resid_row$df)
  ss_grp  <- as.numeric(effect_row$sumsq)
  ss_res  <- as.numeric(resid_row$sumsq)
  eta_sq  <- ss_grp / (ss_grp + ss_res)

  # Count groups
  grp_var  <- all.vars(formula)[2]
  n_groups <- length(unique(data[[grp_var]]))

  fit_tbl <- data.frame(
    Metric = c("F-statistic", "Group df", "Residual df",
               "Overall p-value", "Eta-squared (\u03b7\u00b2)"),
    Value  = c(round(f_stat, 4), df_grp, df_res,
               .format_p_value(p_val),
               round(eta_sq, 4)),
    stringsAsFactors = FALSE
  )

  additional_tables <- .anova_support_tables(model, formula, data, alpha)

  # Metrics bundle
  metrics <- list(
    p_value     = p_val,
    f_statistic = f_stat,
    df_group    = df_grp,
    df_resid    = df_res,
    eta_squared = eta_sq,
    n_groups    = n_groups
  )

  # ---- Step 3: Narrative Generator Module ----
  explanation <- .generate_anova_narrative(metrics, formula_str)

  # ---- Step 4: Unified Result Object ----
  result <- structure(
    list(
      test_type          = "anova",
      formula_str        = formula_str,
      raw_model          = model,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      additional_tables  = additional_tables,
      explanation        = explanation
    ),
    class = "easystat_result"
  )

  result
}

# Narrative Generator Module
# Internal module that converts extracted statistical metrics into
# plain-language, report-ready narrative strings. This is the core inventive
# component of the EasyStat System, applying conditional logic to assembled
# metric values and populating pre-written glue templates to produce
# statistically sound, human-readable explanations.
# (Internal module)

# ---------------------------------------------------------------------------
# Helper: significance label
# ---------------------------------------------------------------------------
.sig_label <- function(p_value, alpha = 0.05) {
  if (is.na(p_value)) return("could not be determined")
  p_text <- .format_p_statement(p_value)
  if (p_value < 0.001) return(glue::glue("highly statistically significant ({p_text})"))
  if (p_value < 0.01)  return(glue::glue("statistically significant ({p_text})"))
  if (p_value < alpha) return(glue::glue("statistically significant ({p_text})"))
  return(glue::glue("not statistically significant ({p_text})"))
}

# ---------------------------------------------------------------------------
# Helper: direction label for coefficients
# ---------------------------------------------------------------------------
.direction_label <- function(estimate) {
  if (is.na(estimate)) return("an unknown change")
  if (estimate > 0) return(glue::glue("an increase of {round(estimate, 4)}"))
  return(glue::glue("a decrease of {abs(round(estimate, 4))}"))
}

# ---------------------------------------------------------------------------
# Helper: effect-size adjective for R-squared
# ---------------------------------------------------------------------------
.r2_label <- function(r_squared) {
  if (is.na(r_squared)) return("unknown")
  if (r_squared >= 0.75) return(glue::glue("{round(r_squared * 100, 1)}% (large effect)"))
  if (r_squared >= 0.50) return(glue::glue("{round(r_squared * 100, 1)}% (moderate effect)"))
  if (r_squared >= 0.25) return(glue::glue("{round(r_squared * 100, 1)}% (small-to-moderate effect)"))
  return(glue::glue("{round(r_squared * 100, 1)}% (small effect)"))
}

# ---------------------------------------------------------------------------
# Narrative: Linear Regression
# ---------------------------------------------------------------------------
.generate_regression_narrative <- function(metrics, formula_str) {
  sig      <- .sig_label(metrics$p_value_overall)
  r2_text  <- .r2_label(metrics$r_squared)
  adj_r2   <- if (!is.na(metrics$adj_r_squared)) round(metrics$adj_r_squared * 100, 1) else "N/A"
  f_stat   <- if (!is.na(metrics$f_statistic)) round(metrics$f_statistic, 3) else "N/A"
  df1      <- if (!is.na(metrics$df1)) metrics$df1 else "N/A"
  df2      <- if (!is.na(metrics$df2)) metrics$df2 else "N/A"
  n_pred   <- if (!is.na(metrics$n_predictors)) metrics$n_predictors else "unknown"

  # Significance sentence
  sig_sentence <- if (!is.na(metrics$p_value_overall) && metrics$p_value_overall < 0.05) {
    glue::glue(
      "The overall regression model is {sig}, indicating that the set of {n_pred} ",
      "predictor(s) collectively explains a meaningful portion of the variance ",
      "in the outcome variable (F({df1}, {df2}) = {f_stat})."
    )
  } else {
    glue::glue(
      "The overall regression model is {sig}. This suggests that the predictor(s) ",
      "included in the model do not collectively explain a significant portion of ",
      "the variance in the outcome variable (F({df1}, {df2}) = {f_stat})."
    )
  }

  # R-squared sentence
  r2_sentence <- glue::glue(
    "The model accounts for {r2_text} of the total variance in the response variable ",
    "(Adjusted R\u00b2 = {adj_r2}%)."
  )

  # Predictor sentences
  pred_sentences <- ""
  if (!is.null(metrics$term_details) && nrow(metrics$term_details) > 0) {
    term_lines <- apply(metrics$term_details, 1, function(row) {
      term_name <- row["term"]
      est       <- suppressWarnings(as.numeric(row["estimate"]))
      pv        <- suppressWarnings(as.numeric(row["p.value"]))
      dir_text  <- .direction_label(est)
      sig_text  <- .sig_label(pv)

      if (term_name == "(Intercept)") {
        glue::glue(
          "The intercept is estimated at {round(est, 4)}, representing the predicted ",
          "value of the outcome when all predictors equal zero ({sig_text})."
        )
      } else {
        glue::glue(
          "The predictor '{term_name}' is associated with {dir_text} in the outcome ",
          "for each one-unit increase, and this effect is {sig_text}."
        )
      }
    })
    pred_sentences <- paste(term_lines, collapse = " ")
  }

  conclusion <- if (!is.na(metrics$p_value_overall) && metrics$p_value_overall < 0.05) {
    "Overall, the model provides statistically meaningful insight and may be suitable for predictive or inferential purposes."
  } else {
    "Overall, caution is warranted in using this model for prediction or inference given the lack of statistical significance."
  }

  glue::glue(
    "LINEAR REGRESSION ANALYSIS\n",
    "Formula: {formula_str}\n\n",
    "{sig_sentence} {r2_sentence} {pred_sentences} {conclusion}"
  )
}

# ---------------------------------------------------------------------------
# Narrative: Logistic Regression
# ---------------------------------------------------------------------------
.generate_logistic_regression_narrative <- function(metrics, formula_str) {
  sig      <- .sig_label(metrics$p_value_overall)
  chi_val  <- if (!is.na(metrics$lrt_chisq)) round(metrics$lrt_chisq, 3) else "N/A"
  df_val   <- if (!is.na(metrics$model_df)) metrics$model_df else "N/A"
  r2_text  <- if (!is.na(metrics$pseudo_r2)) {
    glue::glue("{round(metrics$pseudo_r2 * 100, 1)}%")
  } else {
    "N/A"
  }

  sig_sentence <- if (!is.na(metrics$p_value_overall) && metrics$p_value_overall < 0.05) {
    glue::glue(
      "The overall logistic regression model is {sig}, indicating that the predictor(s) ",
      "improve classification of the binary outcome compared with an intercept-only model ",
      "(\u03c7\u00b2({df_val}) = {chi_val})."
    )
  } else {
    glue::glue(
      "The overall logistic regression model is {sig}. This suggests that the predictor(s) ",
      "do not improve classification of the binary outcome enough to reject the intercept-only model ",
      "(\u03c7\u00b2({df_val}) = {chi_val})."
    )
  }

  fit_sentence <- glue::glue(
    "McFadden's pseudo-R\u00b2 is {r2_text}, with AIC = {round(metrics$aic, 3)} ",
    "and BIC = {round(metrics$bic, 3)}."
  )

  pred_sentences <- ""
  if (!is.null(metrics$term_details) && nrow(metrics$term_details) > 0) {
    term_lines <- apply(metrics$term_details, 1, function(row) {
      term_name <- row["term"]
      est       <- suppressWarnings(as.numeric(row["estimate"]))
      or_val    <- suppressWarnings(as.numeric(row["odds_ratio"]))
      pv        <- suppressWarnings(as.numeric(row["p.value"]))
      sig_text  <- .sig_label(pv)

      if (term_name == "(Intercept)") {
        glue::glue(
          "The intercept corresponds to baseline odds of {.format_compact_number(or_val)} ({sig_text})."
        )
      } else {
        direction <- if (!is.na(est) && est >= 0) "higher" else "lower"
        glue::glue(
          "For '{term_name}', each one-unit increase is associated with {direction} odds ",
          "of the event (odds ratio = {.format_compact_number(or_val)}), and this effect is {sig_text}."
        )
      }
    })
    pred_sentences <- paste(term_lines, collapse = " ")
  }

  conclusion <- if (!is.na(metrics$p_value_overall) && metrics$p_value_overall < 0.05) {
    "Overall, the model provides statistically meaningful evidence about the binary outcome."
  } else {
    "Overall, the model should be interpreted cautiously because the overall improvement over the null model is not statistically significant."
  }

  glue::glue(
    "LOGISTIC REGRESSION ANALYSIS\n",
    "Formula: {formula_str}\n\n",
    "{sig_sentence} {fit_sentence} {pred_sentences} {conclusion}"
  )
}

# ---------------------------------------------------------------------------
# Narrative: Independent-Samples t-Test
# ---------------------------------------------------------------------------
.generate_ttest_narrative <- function(metrics, formula_or_label) {
  sig     <- .sig_label(metrics$p_value)
  t_val   <- if (!is.na(metrics$statistic)) round(metrics$statistic, 3) else "N/A"
  df_val  <- if (!is.na(metrics$parameter)) round(metrics$parameter, 2) else "N/A"
  m1      <- if (!is.na(metrics$estimate1)) round(metrics$estimate1, 4) else "N/A"
  m2      <- if (!is.na(metrics$estimate2)) round(metrics$estimate2, 4) else "N/A"
  lo      <- if (!is.na(metrics$conf_low))  round(metrics$conf_low, 4) else "N/A"
  hi      <- if (!is.na(metrics$conf_high)) round(metrics$conf_high, 4) else "N/A"
  grp1    <- if (!is.null(metrics$group1)) metrics$group1 else "Group 1"
  grp2    <- if (!is.null(metrics$group2)) metrics$group2 else "Group 2"

  sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    glue::glue(
      "An independent-samples t-test revealed a {sig} difference between ",
      "the two groups (t({df_val}) = {t_val})."
    )
  } else {
    glue::glue(
      "An independent-samples t-test found {sig} evidence of a difference between ",
      "the two groups (t({df_val}) = {t_val})."
    )
  }

  means_sentence <- glue::glue(
    "The mean for '{grp1}' was {m1} and the mean for '{grp2}' was {m2}. ",
    "The 95% confidence interval for the difference in means ranged from {lo} to {hi}."
  )

  conclusion <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    glue::glue(
      "These results provide statistically significant evidence that '{grp1}' and ",
      "'{grp2}' differ meaningfully on the measured variable."
    )
  } else {
    glue::glue(
      "Based on this sample, there is insufficient statistical evidence to conclude ",
      "that '{grp1}' and '{grp2}' differ on the measured variable."
    )
  }

  glue::glue(
    "INDEPENDENT-SAMPLES t-TEST\n",
    "Comparison: {formula_or_label}\n\n",
    "{sig_sentence} {means_sentence} {conclusion}"
  )
}

# ---------------------------------------------------------------------------
# Narrative: One-Way ANOVA
# ---------------------------------------------------------------------------
.generate_anova_narrative <- function(metrics, formula_str) {
  sig      <- .sig_label(metrics$p_value)
  f_val    <- if (!is.na(metrics$f_statistic)) round(metrics$f_statistic, 3) else "N/A"
  df1      <- if (!is.na(metrics$df_group))  metrics$df_group  else "N/A"
  df2      <- if (!is.na(metrics$df_resid))  metrics$df_resid  else "N/A"
  n_groups <- if (!is.na(metrics$n_groups))  metrics$n_groups  else "N/A"
  eta_sq   <- if (!is.na(metrics$eta_squared)) round(metrics$eta_squared, 4) else "N/A"

  effect_label <- if (!is.na(metrics$eta_squared)) {
    if (metrics$eta_squared >= 0.14)     "large"
    else if (metrics$eta_squared >= 0.06) "medium"
    else if (metrics$eta_squared >= 0.01) "small"
    else "negligible"
  } else "unknown"

  sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    glue::glue(
      "A one-way ANOVA revealed a {sig} difference across the {n_groups} groups ",
      "(F({df1}, {df2}) = {f_val})."
    )
  } else {
    glue::glue(
      "A one-way ANOVA found {sig} evidence of a difference across the {n_groups} groups ",
      "(F({df1}, {df2}) = {f_val})."
    )
  }

  effect_sentence <- glue::glue(
    "The effect size (eta-squared = {eta_sq}) indicates a {effect_label} practical ",
    "significance of the group factor, meaning the grouping variable accounts for ",
    "approximately {round(as.numeric(eta_sq) * 100, 1)}% of the total variance in the outcome."
  )

  conclusion <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    "Post-hoc tests (e.g., Tukey HSD) are recommended to determine which specific group pairs differ significantly."
  } else {
    "The data do not provide sufficient evidence to conclude that the group means differ. Post-hoc testing is not warranted at this stage."
  }

  glue::glue(
    "ONE-WAY ANOVA\n",
    "Formula: {formula_str}\n\n",
    "{sig_sentence} {effect_sentence} {conclusion}"
  )
}

# ===========================================================================
#  EXTENDED NARRATIVE FUNCTIONS  (v1.1)
# ===========================================================================

# ---------------------------------------------------------------------------
# Helpers: effect-size labels (shared across tests)
# ---------------------------------------------------------------------------
.cohens_d_label <- function(d) {
  d <- abs(d)
  if (is.na(d))        return("unknown")
  if (d >= 0.80)       return("large (d \u2265 0.80)")
  if (d >= 0.50)       return("medium (0.50 \u2264 d < 0.80)")
  if (d >= 0.20)       return("small (0.20 \u2264 d < 0.50)")
  return("negligible (d < 0.20)")
}

.cramers_v_label <- function(v) {
  if (is.na(v))   return("unknown")
  if (v >= 0.50)  return("very strong")
  if (v >= 0.30)  return("strong")
  if (v >= 0.10)  return("moderate")
  return("weak")
}

.corr_label <- function(r) {
  r <- abs(r)
  if (is.na(r))   return("unknown")
  if (r >= 0.90)  return("very strong")
  if (r >= 0.70)  return("strong")
  if (r >= 0.50)  return("moderate")
  if (r >= 0.30)  return("weak")
  return("very weak or negligible")
}

.skew_label <- function(sk) {
  if (is.na(sk))   return("unknown")
  if (sk >  1.0)   return("strongly right-skewed (positive skew)")
  if (sk >  0.5)   return("moderately right-skewed")
  if (sk > -0.5)   return("approximately symmetric")
  if (sk > -1.0)   return("moderately left-skewed")
  return("strongly left-skewed (negative skew)")
}

.kurt_label <- function(k) {
  if (is.na(k))  return("unknown")
  if (k >  1.0)  return("leptokurtic (heavy-tailed, sharper peak than normal)")
  if (k < -1.0)  return("platykurtic (light-tailed, flatter than normal)")
  return("approximately mesokurtic (similar tail weight to a normal distribution)")
}

.norm_label <- function(p) {
  if (is.na(p)) return("normality could not be assessed")
  if (p < 0.05) return(glue::glue("non-normal (Shapiro-Wilk {.format_p_statement(p)})"))
  return(glue::glue("approximately normal (Shapiro-Wilk {.format_p_statement(p)})"))
}

# ---------------------------------------------------------------------------
# Narrative: Descriptive Statistics
# ---------------------------------------------------------------------------
.generate_describe_narrative <- function(metrics, var_name) {
  skew_txt <- .skew_label(metrics$skewness)
  kurt_txt <- .kurt_label(metrics$kurtosis)
  norm_txt <- .norm_label(metrics$shapiro_p)

  cv_note <- if (!is.na(metrics$cv_pct)) {
    cv <- round(metrics$cv_pct, 1)
    if (cv > 30) glue::glue("The coefficient of variation is {cv}%, indicating high relative variability.")
    else if (cv > 15) glue::glue("The coefficient of variation is {cv}%, indicating moderate relative variability.")
    else glue::glue("The coefficient of variation is {cv}%, indicating low relative variability.")
  } else ""

  glue::glue(
    "DESCRIPTIVE STATISTICS: {var_name}\n\n",
    "The variable '{var_name}' has {metrics$n} valid observations (missing: {metrics$n_missing}). ",
    "The central tendency is characterised by a mean of {round(metrics$mean, 4)} and a ",
    "median of {round(metrics$median, 4)}, with a standard deviation of {round(metrics$sd, 4)}. ",
    "Values range from {round(metrics$min, 4)} to {round(metrics$max, 4)} (range = {round(metrics$range_val, 4)}; ",
    "IQR = {round(metrics$iqr, 4)}). ",
    "The distribution is {skew_txt} and {kurt_txt}. ",
    "Based on the Shapiro-Wilk test, the data are {norm_txt}. ",
    "{cv_note} ",
    "The 95% confidence interval for the population mean is [{round(metrics$ci_lower, 4)}, {round(metrics$ci_upper, 4)}]."
  )
}

# ---------------------------------------------------------------------------
# Narrative: Chi-Square
# ---------------------------------------------------------------------------
.generate_chisq_narrative <- function(metrics, chisq_type, var1, var2 = NULL) {
  sig      <- .sig_label(metrics$p_value)
  x2_val   <- if (!is.na(metrics$statistic)) round(metrics$statistic, 3) else "N/A"
  df_val   <- if (!is.na(metrics$df))        metrics$df                  else "N/A"
  v_label  <- .cramers_v_label(metrics$cramers_v)
  v_val    <- if (!is.na(metrics$cramers_v)) round(metrics$cramers_v, 4) else "N/A"

  if (chisq_type == "independence") {
    sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
      glue::glue(
        "A Pearson chi-square test of independence revealed a {sig} association ",
        "between '{var1}' and '{var2}' (\u03c7\u00b2({df_val}) = {x2_val})."
      )
    } else {
      glue::glue(
        "A Pearson chi-square test of independence found {sig} evidence of an ",
        "association between '{var1}' and '{var2}' (\u03c7\u00b2({df_val}) = {x2_val})."
      )
    }
    effect_sentence <- glue::glue(
      "The effect size, measured by Cram\u00e9r's V = {v_val}, indicates a {v_label} ",
      "practical association between the two categorical variables."
    )
    conclusion <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
      glue::glue(
        "The observed cell frequencies deviate meaningfully from what would be expected ",
        "under statistical independence, suggesting a genuine relationship between '{var1}' and '{var2}'."
      )
    } else {
      "The observed cell frequencies are consistent with statistical independence. No meaningful relationship between the two variables is supported by these data."
    }
    glue::glue("CHI-SQUARE TEST OF INDEPENDENCE\n\n{sig_sentence} {effect_sentence} {conclusion}")

  } else {
    sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
      glue::glue(
        "A chi-square goodness-of-fit test for '{var1}' is {sig} ",
        "(\u03c7\u00b2({df_val}) = {x2_val})."
      )
    } else {
      glue::glue(
        "A chi-square goodness-of-fit test for '{var1}' is {sig} ",
        "(\u03c7\u00b2({df_val}) = {x2_val})."
      )
    }
    conclusion <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
      "The observed frequency distribution differs significantly from the expected (theoretical) distribution."
    } else {
      "The observed frequency distribution is consistent with the expected (theoretical) distribution."
    }
    glue::glue("CHI-SQUARE GOODNESS-OF-FIT TEST\n\n{sig_sentence} {conclusion}")
  }
}

# ---------------------------------------------------------------------------
# Narrative: Z-Test
# ---------------------------------------------------------------------------
.generate_ztest_narrative <- function(metrics, label) {
  sig      <- .sig_label(metrics$p_value)
  z_val    <- if (!is.na(metrics$z_stat))   round(metrics$z_stat, 3)   else "N/A"
  d_label  <- .cohens_d_label(metrics$cohens_d)
  d_val    <- if (!is.na(metrics$cohens_d)) round(abs(metrics$cohens_d), 4) else "N/A"

  if (metrics$test_type_z == "one_sample") {
    sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
      glue::glue(
        "A one-sample z-test revealed that the sample mean ({round(metrics$x_bar, 4)}) ",
        "differs {sig} from the hypothesised population mean of {metrics$mu} (z = {z_val})."
      )
    } else {
      glue::glue(
        "A one-sample z-test found {sig} evidence that the sample mean ({round(metrics$x_bar, 4)}) ",
        "differs from the hypothesised population mean of {metrics$mu} (z = {z_val})."
      )
    }
    effect_sentence <- glue::glue(
      "The standardised effect size (Cohen's d = {d_val}) is classified as {d_label}. ",
      "The 95% CI for the population mean is [{round(metrics$ci_lower, 4)}, {round(metrics$ci_upper, 4)}]."
    )
  } else {
    sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
      glue::glue(
        "A two-sample z-test revealed a {sig} difference between the two group means ",
        "(z = {z_val}). Mean\u2081 = {round(metrics$x_bar, 4)}, Mean\u2082 = {round(metrics$x_bar2, 4)}."
      )
    } else {
      glue::glue(
        "A two-sample z-test found {sig} evidence of a difference between the two group means ",
        "(z = {z_val}). Mean\u2081 = {round(metrics$x_bar, 4)}, Mean\u2082 = {round(metrics$x_bar2, 4)}."
      )
    }
    effect_sentence <- glue::glue(
      "The standardised effect size (Cohen's d = {d_val}) is classified as {d_label}. ",
      "The 95% CI for the mean difference is [{round(metrics$ci_lower, 4)}, {round(metrics$ci_upper, 4)}]."
    )
  }
  glue::glue("Z-TEST\nComparison: {label}\n\n{sig_sentence} {effect_sentence}")
}

# ---------------------------------------------------------------------------
# Narrative: F-Test (Variance Ratio)
# ---------------------------------------------------------------------------
.generate_ftest_narrative <- function(metrics, label) {
  sig      <- .sig_label(metrics$p_value)
  f_val    <- if (!is.na(metrics$f_stat)) round(metrics$f_stat, 4) else "N/A"
  df1      <- if (!is.na(metrics$df1))    metrics$df1               else "N/A"
  df2      <- if (!is.na(metrics$df2))    metrics$df2               else "N/A"
  ratio    <- if (!is.na(metrics$var_ratio)) round(metrics$var_ratio, 4) else "N/A"

  sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    glue::glue(
      "An F-test for equality of variances revealed a {sig} difference in variance ",
      "between the two groups (F({df1}, {df2}) = {f_val}). ",
      "The ratio of variances is {ratio}."
    )
  } else {
    glue::glue(
      "An F-test for equality of variances found {sig} evidence of a difference in variance ",
      "between the two groups (F({df1}, {df2}) = {f_val}). ",
      "The ratio of variances is {ratio}."
    )
  }

  implication <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    "IMPLICATION: The assumption of equal variances (homoscedasticity) is VIOLATED. It is recommended to use Welch's t-test (var.equal = FALSE) rather than the classical t-test."
  } else {
    "IMPLICATION: The assumption of equal variances (homoscedasticity) is SUPPORTED. Both the classical t-test and Welch's t-test are appropriate."
  }

  glue::glue(
    "F-TEST FOR EQUALITY OF VARIANCES\n",
    "Comparison: {label}\n\n",
    "{sig_sentence} ",
    "The 95% CI for the variance ratio is [{round(metrics$ci_lower, 4)}, {round(metrics$ci_upper, 4)}]. ",
    "{implication}"
  )
}

# ---------------------------------------------------------------------------
# Narrative: Correlation
# ---------------------------------------------------------------------------
.generate_correlation_narrative <- function(metrics) {
  r_val    <- round(metrics$r, 4)
  p_sig    <- .sig_label(metrics$p_value)
  strength <- .corr_label(metrics$r)
  dir      <- if (metrics$r >= 0) "positive" else "negative"
  method   <- tools::toTitleCase(metrics$method)
  r2_pct   <- round(metrics$r^2 * 100, 1)

  sig_sentence <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    glue::glue(
      "A {method} correlation analysis revealed a {strength} {dir} correlation ",
      "between the two variables (r = {r_val}), which is {p_sig}."
    )
  } else {
    glue::glue(
      "A {method} correlation analysis found a {strength} {dir} correlation ",
      "between the two variables (r = {r_val}), which is {p_sig}."
    )
  }

  r2_sentence <- glue::glue(
    "The coefficient of determination (r\u00b2 = {round(metrics$r^2, 4)}) indicates that ",
    "approximately {r2_pct}% of the variance in one variable is shared with the other."
  )

  ci_sentence <- glue::glue(
    "The 95% confidence interval for the correlation coefficient is [{round(metrics$ci_lower, 4)}, {round(metrics$ci_upper, 4)}]."
  )

  conclusion <- if (!is.na(metrics$p_value) && metrics$p_value < 0.05) {
    if (abs(metrics$r) >= 0.70) "This strong relationship may have meaningful practical implications and warrants further investigation."
    else if (abs(metrics$r) >= 0.30) "The moderate relationship suggests a real but imperfect association between the variables."
    else "Though statistically significant, the weak correlation indicates limited practical association."
  } else {
    "The data do not provide sufficient evidence to conclude that the two variables are linearly related."
  }

  glue::glue(
    "CORRELATION ANALYSIS ({method})\n\n",
    "{sig_sentence} {r2_sentence} {ci_sentence} {conclusion}"
  )
}

# ---------------------------------------------------------------------------
# Narrative: Plot Interpretations
# ---------------------------------------------------------------------------
.generate_histogram_interpretation <- function(metrics) {
  skew_txt <- .skew_label(metrics$skewness)
  kurt_txt <- .kurt_label(metrics$kurtosis)
  norm_txt <- .norm_label(metrics$shapiro_p)
  glue::glue(
    "HISTOGRAM INTERPRETATION\n\n",
    "The histogram displays the frequency distribution of '{metrics$var_name}' (n = {metrics$n}). ",
    "The distribution appears {skew_txt} and {kurt_txt}. ",
    "The data are {norm_txt}. ",
    "The mean ({round(metrics$mean, 3)}) and median ({round(metrics$median, 3)}) ",
    if (abs(metrics$mean - metrics$median) / metrics$sd < 0.1)
      "are very close together, consistent with a symmetric distribution."
    else if (metrics$mean > metrics$median)
      "suggest a right-skewed distribution with the mean pulled toward the upper tail."
    else
      "suggest a left-skewed distribution with the mean pulled toward the lower tail."
  )
}

.generate_boxplot_interpretation <- function(metrics) {
  glue::glue(
    "BOXPLOT INTERPRETATION\n\n",
    "The boxplot visualises the distribution of '{metrics$outcome}' ",
    if (!is.null(metrics$group)) glue::glue("across {metrics$n_groups} levels of '{metrics$group}'. ") else ". ",
    "The central box spans from Q1 ({round(metrics$q1, 3)}) to Q3 ({round(metrics$q3, 3)}), ",
    "with a median of {round(metrics$median, 3)} (IQR = {round(metrics$iqr, 3)}). ",
    if (metrics$n_outliers > 0)
      glue::glue("{metrics$n_outliers} outlier(s) are visible beyond the whiskers and may warrant further investigation. ")
    else
      "No outliers are detected beyond the whiskers. ",
    "The whiskers extend to the most extreme non-outlier values."
  )
}

.generate_scatter_interpretation <- function(metrics) {
  strength <- .corr_label(metrics$r)
  dir      <- if (metrics$r >= 0) "positive" else "negative"
  sig_txt  <- .sig_label(metrics$p_value_r)
  glue::glue(
    "SCATTERPLOT INTERPRETATION\n\n",
    "The scatterplot shows the relationship between '{metrics$x_var}' (x-axis) and ",
    "'{metrics$y_var}' (y-axis) across {metrics$n} observations. ",
    "The Pearson correlation is r = {round(metrics$r, 4)}, indicating a {strength} {dir} linear ",
    "relationship that is {sig_txt}. ",
    "The regression line (slope = {round(metrics$slope, 4)}) ",
    if (metrics$r >= 0) "slopes upward, confirming the positive association." else "slopes downward, confirming the negative association.",
    " Approximately {round(metrics$r^2 * 100, 1)}% of variance in '{metrics$y_var}' is explained by '{metrics$x_var}'."
  )
}

.generate_qqplot_interpretation <- function(metrics) {
  norm_txt <- .norm_label(metrics$shapiro_p)
  glue::glue(
    "Q-Q PLOT INTERPRETATION\n\n",
    "The Q-Q plot compares the quantiles of '{metrics$var_name}' against theoretical normal quantiles. ",
    "Points closely following the diagonal reference line indicate normality. ",
    "The Shapiro-Wilk test indicates the data are {norm_txt}. ",
    if (!is.na(metrics$shapiro_p) && metrics$shapiro_p < 0.05)
      "Noticeable deviations from the diagonal \u2014 particularly at the tails \u2014 suggest departure from normality. Consider data transformations or non-parametric alternatives."
    else
      "Points lie close to the diagonal, supporting the assumption of normality."
  )
}

.generate_density_interpretation <- function(metrics) {
  skew_txt <- .skew_label(metrics$skewness)
  glue::glue(
    "DENSITY PLOT INTERPRETATION\n\n",
    "The kernel density plot provides a smooth estimate of the probability density of '{metrics$var_name}'. ",
    "The distribution is {skew_txt}. ",
    "The peak (mode \u2248 {round(metrics$mode_approx, 3)}) represents the most frequently occurring value region. ",
    "The shaded area under the curve integrates to 1, representing 100% of the data."
  )
}

.generate_corr_heatmap_interpretation <- function(metrics) {
  n_strong    <- sum(abs(metrics$corr_values) >= 0.7 & abs(metrics$corr_values) < 1, na.rm = TRUE)
  n_moderate  <- sum(abs(metrics$corr_values) >= 0.3 & abs(metrics$corr_values) < 0.7, na.rm = TRUE)
  glue::glue(
    "CORRELATION HEATMAP INTERPRETATION\n\n",
    "The heatmap displays pairwise {metrics$method} correlations among {metrics$n_vars} variables. ",
    "Cell colour intensity reflects the strength of association: dark blue = strong positive, ",
    "dark red = strong negative, white = no correlation. ",
    "Among the {metrics$n_pairs} pairs examined, {n_strong} show strong correlations (|r| \u2265 0.70) ",
    "and {n_moderate} show moderate correlations (0.30 \u2264 |r| < 0.70). ",
    "Diagonal values are 1.0 by definition (each variable correlates perfectly with itself)."
  )
}

#' Run a Logistic Regression with Automated Narrative Reporting
#'
#' Executes a binary logistic regression using \code{stats::glm()} with
#' \code{family = binomial}, extracts coefficients, odds ratios, approximate
#' confidence intervals, and model-fit metrics, then generates a plain-language
#' narrative via the Narrative Generator Module.
#'
#' @param formula A \code{formula} object or a character string formula (e.g.,
#'   \code{"am ~ mpg + wt"}). The outcome must be binary.
#' @param data A data frame containing the variables referenced in \code{formula}.
#' @param alpha Significance threshold used in narrative generation. Default \code{0.05}.
#' @param conf_level Confidence level for odds-ratio intervals. Default \code{0.95}.
#'
#' @return An object of class \code{"easystat_result"} with coefficient, odds-ratio,
#'   model-fit, raw \code{glm}, and narrative components.
#'
#' @examples
#' result <- easy_logistic_regression(am ~ mpg + wt, data = mtcars)
#' print(result)
#'
#' @export
easy_logistic_regression <- function(formula, data, alpha = 0.05, conf_level = 0.95) {

  if (is.character(formula)) formula <- stats::as.formula(formula)
  if (!inherits(formula, "formula")) stop("'formula' must be a formula object or a character string.")
  if (!is.data.frame(data))          stop("'data' must be a data frame.")

  formula_str <- deparse(formula)
  outcome_var <- all.vars(formula)[1]
  if (is.na(outcome_var) || !outcome_var %in% names(data)) {
    stop("The formula must include a valid binary outcome variable.")
  }

  outcome <- data[[outcome_var]]
  valid_outcome <- stats::na.omit(outcome)
  n_levels <- if (is.numeric(valid_outcome)) {
    length(unique(valid_outcome))
  } else {
    length(unique(as.character(valid_outcome)))
  }
  if (n_levels != 2) {
    stop("Logistic regression requires a binary outcome with exactly 2 observed levels.")
  }
  if (is.numeric(valid_outcome) && !all(sort(unique(valid_outcome)) %in% c(0, 1))) {
    warning("Numeric binary outcomes are interpreted by glm(binomial) on the logit scale; 0/1 coding is recommended.")
  }

  model <- stats::glm(formula, data = data, family = stats::binomial())
  model_summary <- summary(model)
  coef_mat <- as.data.frame(model_summary$coefficients)
  coef_mat$Term <- rownames(coef_mat)
  rownames(coef_mat) <- NULL

  z_crit <- stats::qnorm((1 + conf_level) / 2)
  estimate <- coef_mat$Estimate
  std_error <- coef_mat$`Std. Error`
  p_values <- coef_mat$`Pr(>|z|)`
  odds_ratio <- exp(estimate)
  or_low <- exp(estimate - z_crit * std_error)
  or_high <- exp(estimate + z_crit * std_error)

  coef_tbl <- data.frame(
    Term = coef_mat$Term,
    Estimate = round(estimate, 4),
    `Std. Error` = round(std_error, 4),
    `z Statistic` = round(coef_mat$`z value`, 4),
    `p-value` = .format_p_value(p_values),
    `Odds Ratio` = round(odds_ratio, 4),
    `OR CI Lower` = round(or_low, 4),
    `OR CI Upper` = round(or_high, 4),
    check.names = FALSE,
    stringsAsFactors = FALSE
  )

  null_dev <- model$null.deviance
  resid_dev <- model$deviance
  model_df <- model$df.null - model$df.residual
  lrt_chisq <- null_dev - resid_dev
  p_overall <- stats::pchisq(lrt_chisq, df = model_df, lower.tail = FALSE)
  pseudo_r2 <- if (!is.na(null_dev) && null_dev > 0) 1 - (resid_dev / null_dev) else NA_real_

  fit_tbl <- data.frame(
    Metric = c("Null deviance", "Residual deviance", "Model df",
               "Likelihood-ratio \u03c7\u00b2", "Overall p-value",
               "McFadden pseudo-R\u00b2", "AIC", "BIC", "N"),
    Value = c(round(null_dev, 4), round(resid_dev, 4), model_df,
              round(lrt_chisq, 4), .format_p_value(p_overall),
              round(pseudo_r2, 4), round(stats::AIC(model), 4),
              round(stats::BIC(model), 4), stats::nobs(model)),
    stringsAsFactors = FALSE
  )

  diagnostics <- data.frame(
    Metric = c("Classification cutoff", "Accuracy", "Sensitivity",
               "Specificity", "Null deviance", "Residual deviance"),
    Value = c("0.50",
              round(mean((stats::fitted(model) >= 0.5) == model$y, na.rm = TRUE), 4),
              round(sum(stats::fitted(model) >= 0.5 & model$y == 1, na.rm = TRUE) /
                      sum(model$y == 1, na.rm = TRUE), 4),
              round(sum(stats::fitted(model) < 0.5 & model$y == 0, na.rm = TRUE) /
                      sum(model$y == 0, na.rm = TRUE), 4),
              round(null_dev, 4), round(resid_dev, 4)),
    stringsAsFactors = FALSE
  )
  conf_tbl <- table(
    Actual = factor(model$y, levels = c(0, 1)),
    Predicted = factor(ifelse(stats::fitted(model) >= 0.5, 1, 0), levels = c(0, 1))
  )
  confusion <- as.data.frame.matrix(conf_tbl)
  confusion <- cbind(Actual = rownames(confusion), confusion, row.names = NULL)
  additional_tables <- list(
    "Classification Diagnostics" = diagnostics,
    "Confusion Matrix" = confusion
  )

  term_details <- data.frame(
    term = coef_mat$Term,
    estimate = estimate,
    odds_ratio = odds_ratio,
    p.value = p_values,
    stringsAsFactors = FALSE
  )

  metrics <- list(
    p_value_overall = p_overall,
    lrt_chisq       = lrt_chisq,
    model_df        = model_df,
    pseudo_r2       = pseudo_r2,
    aic             = stats::AIC(model),
    bic             = stats::BIC(model),
    term_details    = term_details
  )

  explanation <- .generate_logistic_regression_narrative(metrics, formula_str)

  structure(
    list(
      test_type          = "logistic_regression",
      formula_str        = formula_str,
      raw_model          = model,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      additional_tables  = additional_tables,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

#' Chi-Square Tests with Automated Narrative Reporting
#'
#' Runs either a \strong{chi-square test of independence} (two categorical
#' variables) or a \strong{goodness-of-fit test} (one variable vs. expected
#' proportions), extracts Cramér's V as the effect-size measure, and generates
#' a plain-language narrative via the Narrative Generator Module.
#'
#' @param x A factor/character vector, OR a contingency table (matrix), OR a
#'   formula \code{~ var1 + var2} for independence, or \code{~ var1} for GOF.
#' @param y A factor/character vector (second categorical variable) for the
#'   independence test. Ignored when \code{x} is a table or formula.
#' @param data A data frame. Required when \code{x} is a formula.
#' @param p Numeric vector of expected probabilities for the GOF test.
#'   If \code{NULL} (default), equal probabilities are assumed.
#' @param correct Logical; apply Yates' continuity correction? Default \code{TRUE}.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An \code{"easystat_result"} object with:
#'   \describe{
#'     \item{\code{coefficients_table}}{Observed vs. expected frequency table}
#'     \item{\code{model_fit_table}}{Chi-square statistic, df, p-value, Cramér's V}
#'     \item{\code{explanation}}{Plain-language narrative}
#'   }
#'
#' @examples
#' # Independence test
#' result <- easy_chisq(~ cyl + am, data = mtcars)
#' print(result)
#'
#' # Goodness-of-fit
#' result <- easy_chisq(~ cyl, data = mtcars)
#' print(result)
#'
#' @export
easy_chisq <- function(x, y = NULL, data = NULL,
                       p = NULL, correct = TRUE, alpha = 0.05) {

  var1 <- "Variable 1"
  var2 <- NULL
  chisq_type <- "independence"

  # ---- Parse inputs ----
  if (inherits(x, "formula") || is.character(x)) {
    if (is.character(x)) x <- stats::as.formula(x)
    if (is.null(data)) stop("'data' must be provided when 'x' is a formula.")
    vars <- all.vars(x)
    if (length(vars) == 2) {
      var1 <- vars[1]; var2 <- vars[2]
      chisq_type <- "independence"
      tbl <- table(data[[var1]], data[[var2]])
      dimnames(tbl) <- list(var1 = levels(factor(data[[var1]])),
                            var2 = levels(factor(data[[var2]])))
    } else if (length(vars) == 1) {
      var1 <- vars[1]
      chisq_type <- "gof"
      tbl <- table(data[[var1]])
    } else {
      stop("Formula must have 1 or 2 variables.")
    }
  } else if (is.table(x) || is.matrix(x)) {
    tbl <- x
    chisq_type <- if (length(dim(tbl)) == 2) "independence" else "gof"
    var1 <- if (!is.null(rownames(tbl))) "Row Variable" else "Variable"
    var2 <- if (!is.null(colnames(tbl))) "Col Variable" else NULL
  } else {
    if (!is.null(y)) {
      var1 <- deparse(substitute(x))
      var2 <- deparse(substitute(y))
      chisq_type <- "independence"
      tbl <- table(x, y)
    } else {
      var1 <- deparse(substitute(x))
      chisq_type <- "gof"
      tbl <- table(x)
    }
  }

  formula_str <- if (chisq_type == "independence")
    paste0("~ ", var1, " + ", var2) else paste0("~ ", var1)

  # ---- Step 1: Core Statistical Engine ----
  test_result <- if (chisq_type == "gof") {
    if (!is.null(p)) {
      if (length(p) != length(tbl)) stop("'p' length must match the number of categories.")
      stats::chisq.test(tbl, p = p, correct = FALSE)
    } else {
      stats::chisq.test(tbl, correct = FALSE)
    }
  } else {
    stats::chisq.test(tbl, correct = correct)
  }

  # ---- Step 2: Metric Extractor ----
  x2_val  <- as.numeric(test_result$statistic)
  df_val  <- as.numeric(test_result$parameter)
  p_val   <- test_result$p.value
  n_total <- sum(tbl)

  # Cram\u00E9r's V
  k          <- min(dim(tbl)) - 1  # for 1-way GOF, dim(tbl) is 1 so k defaults to 0
  if (chisq_type == "gof") k <- 1
  cramers_v  <- sqrt(x2_val / (n_total * max(k, 1)))

  # Observed vs expected table
  obs_vec  <- as.vector(tbl)
  exp_vec  <- as.vector(test_result$expected)
  if (chisq_type == "independence") {
    cell_labels <- paste0(rep(rownames(tbl), each = ncol(tbl)),
                          " | ", rep(colnames(tbl), nrow(tbl)))
  } else {
    cell_labels <- names(tbl)
  }
  coef_tbl <- data.frame(
    Category         = cell_labels,
    Observed         = obs_vec,
    Expected         = round(exp_vec, 2),
    Residual         = round(obs_vec - exp_vec, 4),
    Std_Residual     = round((obs_vec - exp_vec) / sqrt(exp_vec), 4),
    stringsAsFactors = FALSE
  )

  fit_tbl <- data.frame(
    Metric = c("Chi-square statistic (\u03c7\u00b2)", "Degrees of Freedom",
               "p-value", "N (total)", "Cram\u00e9r's V", "Effect Strength"),
    Value  = c(round(x2_val, 4), df_val,
               .format_p_value(p_val),
               n_total, round(cramers_v, 4),
               .cramers_v_label(cramers_v)),
    stringsAsFactors = FALSE
  )

  additional_tables <- if (chisq_type == "independence") {
    .contingency_tables(tbl, test_result$expected)
  } else {
    list(
      "Goodness-of-fit Table" = data.frame(
        Category = names(tbl),
        Observed = as.vector(tbl),
        Expected = round(as.vector(test_result$expected), 4),
        Percentage = round(as.vector(prop.table(tbl) * 100), 4),
        stringsAsFactors = FALSE
      )
    )
  }

  # ---- Step 3: Narrative ----
  metrics <- list(
    p_value   = p_val,
    statistic = x2_val,
    df        = df_val,
    cramers_v = cramers_v
  )
  explanation <- .generate_chisq_narrative(metrics, chisq_type, var1, var2)

  structure(
    list(
      test_type          = "chisq",
      formula_str        = formula_str,
      raw_model          = test_result,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      additional_tables  = additional_tables,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

#' Run a Linear Regression with Automated Narrative Reporting
#'
#' Executes a standard OLS linear regression using \code{stats::lm()}, extracts
#' key metrics via the \code{broom} package, and automatically generates a
#' plain-language narrative explanation via the Narrative Generator Module.
#'
#' @param formula A \code{formula} object or a character string formula (e.g.,
#'   \code{"mpg ~ wt + hp"}). Passed directly to \code{stats::lm()}.
#' @param data A data frame containing the variables referenced in \code{formula}.
#' @param alpha Significance threshold used in narrative generation. Default \code{0.05}.
#'
#' @return An object of class \code{"easystat_result"} (an R \code{list}) with:
#'   \describe{
#'     \item{\code{test_type}}{Character: \code{"regression"}}
#'     \item{\code{formula_str}}{Character string of the formula used}
#'     \item{\code{raw_model}}{The raw \code{lm} object for advanced use}
#'     \item{\code{coefficients_table}}{Tidy data frame of coefficients, SEs, t-stats, p-values}
#'     \item{\code{model_fit_table}}{Data frame with R\eqn{^2}, Adjusted R\eqn{^2}, F-statistic, p-value}
#'     \item{\code{explanation}}{Plain-language narrative string}
#'   }
#'
#' @examples
#' result <- easy_regression(mpg ~ wt + hp, data = mtcars)
#' print(result)
#'
#' @export
easy_regression <- function(formula, data, alpha = 0.05) {

  # ---- Input validation ----
  if (is.character(formula)) formula <- stats::as.formula(formula)
  if (!inherits(formula, "formula")) stop("'formula' must be a formula object or a character string.")
  if (!is.data.frame(data))          stop("'data' must be a data frame.")

  formula_str <- deparse(formula)

  # ---- Step 1: Core Statistical Engine ----
  model <- stats::lm(formula, data = data)

  # ---- Step 2: Metric Extractor Module (broom) ----
  term_df <- broom::tidy(model)
  coef_tbl <- as.data.frame(term_df)
  colnames(coef_tbl) <- c("Term", "Estimate", "Std. Error", "t Statistic", "p-value")
  coef_tbl[, c("Estimate", "Std. Error", "t Statistic")] <-
    lapply(coef_tbl[, c("Estimate", "Std. Error", "t Statistic")], function(v) round(v, 4))
  coef_tbl[["p-value"]] <- .format_p_value(coef_tbl[["p-value"]])

  glance_df  <- broom::glance(model)
  r_sq       <- glance_df$r.squared
  adj_r_sq   <- glance_df$adj.r.squared
  f_stat     <- glance_df$statistic
  p_overall  <- glance_df$p.value
  df1        <- glance_df$df
  df2        <- glance_df$df.residual

  fit_tbl <- data.frame(
    Metric  = c("R-squared", "Adjusted R-squared", "F-statistic",
                "Model df", "Residual df", "Overall p-value"),
    Value   = c(round(r_sq, 6), round(adj_r_sq, 6), round(f_stat, 4),
                df1, df2, .format_p_value(p_overall)),
    stringsAsFactors = FALSE
  )

  anova_tbl <- as.data.frame(stats::anova(model))
  anova_tbl$Term <- rownames(anova_tbl)
  rownames(anova_tbl) <- NULL
  anova_tbl <- data.frame(
    Term = anova_tbl$Term,
    Df = anova_tbl$Df,
    Sum_Sq = round(anova_tbl$`Sum Sq`, 4),
    Mean_Sq = round(anova_tbl$`Mean Sq`, 4),
    F_value = round(anova_tbl$`F value`, 4),
    p_value = .format_p_value(anova_tbl$`Pr(>F)`),
    stringsAsFactors = FALSE
  )
  additional_tables <- c(
    list("Regression ANOVA Table" = anova_tbl),
    .model_diagnostic_tables(model)
  )

  # Metrics bundle fed to Narrative Generator
  metrics <- list(
    p_value_overall = p_overall,
    r_squared       = r_sq,
    adj_r_squared   = adj_r_sq,
    f_statistic     = f_stat,
    df1             = df1,
    df2             = df2,
    n_predictors    = df1,
    term_details    = term_df[, c("term", "estimate", "p.value")]
  )

  # ---- Step 3: Narrative Generator Module ----
  explanation <- .generate_regression_narrative(metrics, formula_str)

  # ---- Step 4: Unified Result Object ----
  result <- structure(
    list(
      test_type          = "regression",
      formula_str        = formula_str,
      raw_model          = model,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      additional_tables  = additional_tables,
      explanation        = explanation
    ),
    class = "easystat_result"
  )

  result
}

#' Correlation Analysis with Automated Narrative Reporting
#'
#' Computes bivariate or pairwise correlations (Pearson, Spearman, or Kendall)
#' with significance tests and confidence intervals. For two variables a full
#' narrative is generated; for multiple variables a correlation matrix is
#' returned with a summary digest.
#'
#' @param x A numeric vector, a data frame, OR a formula \code{~ x + y}.
#' @param y A numeric vector (paired with \code{x}). Ignored when \code{x}
#'   is a formula or data frame.
#' @param data A data frame. Required when \code{x} is a formula.
#' @param vars Character vector of column names when \code{x} is a data frame
#'   and pairwise analysis is desired. Default \code{NULL} = all numeric cols.
#' @param method Correlation method: \code{"pearson"} (default),
#'   \code{"spearman"}, or \code{"kendall"}.
#' @param conf_level Confidence level for Pearson CI. Default \code{0.95}.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An \code{"easystat_result"} object.
#'
#' @examples
#' result <- easy_correlation(~ mpg + wt, data = mtcars)
#' print(result)
#'
#' result <- easy_correlation(mtcars, vars = c("mpg", "hp", "wt", "disp"))
#' print(result)
#'
#' @export
easy_correlation <- function(x, y = NULL, data = NULL, vars = NULL,
                              method = "pearson",
                              conf_level = 0.95, alpha = 0.05) {

  method <- match.arg(method, c("pearson", "spearman", "kendall"))

  # ---- Dispatch: bivariate vs. matrix ----
  if (is.data.frame(x) && is.null(y)) {
    return(.easy_corr_matrix(x, vars, method, conf_level, alpha))
  }

  if ((inherits(x, "formula") || is.character(x))) {
    if (is.character(x)) x <- stats::as.formula(x)
    if (is.null(data)) stop("'data' must be provided when 'x' is a formula.")
    vars2 <- all.vars(x)
    if (length(vars2) == 2) {
      xv <- data[[vars2[1]]]
      yv <- data[[vars2[2]]]
      xname <- vars2[1]; yname <- vars2[2]
      if (!is.numeric(xv) || !is.numeric(yv))
        stop("Both variables in the formula must be numeric for correlation.")
      formula_str <- deparse(x)
    } else if (length(vars2) > 2) {
      sub_data <- data[, vars2, drop = FALSE]
      return(.easy_corr_matrix(sub_data, vars2, method, conf_level, alpha))
    } else {
      stop("Formula must name at least two variables.")
    }
  } else {
    xv <- x
    yv <- y
    if (is.null(yv)) stop("'y' must be provided when 'x' is a numeric vector.")
    xname <- deparse(substitute(x))
    yname <- deparse(substitute(y))
    formula_str <- paste("~", xname, "+", yname)
  }

  # ---- Bivariate correlation ----
  complete_idx <- stats::complete.cases(xv, yv)
  xv <- xv[complete_idx]; yv <- yv[complete_idx]
  n  <- length(xv)
  if (n < 3) stop("At least 3 complete observations are required for correlation.")

  cor_test <- stats::cor.test(xv, yv, method = method, conf.level = conf_level)
  r_val    <- as.numeric(cor_test$estimate)
  p_val    <- cor_test$p.value
  ci_lo    <- if (!is.null(cor_test$conf.int)) cor_test$conf.int[1] else NA_real_
  ci_hi    <- if (!is.null(cor_test$conf.int)) cor_test$conf.int[2] else NA_real_
  t_stat   <- if (!is.null(cor_test$statistic)) as.numeric(cor_test$statistic) else NA_real_

  # Slope and intercept from simple regression (for scatter annotation)
  lm_fit <- stats::lm(yv ~ xv)
  slope  <- stats::coef(lm_fit)[2]
  interc <- stats::coef(lm_fit)[1]

  coef_tbl <- data.frame(
    Metric = c(paste0("r (", tools::toTitleCase(method), ")"),
               "r\u00b2 (shared variance %)",
               paste0(round(conf_level * 100), "% CI lower"),
               paste0(round(conf_level * 100), "% CI upper"),
               "t-statistic", "n (valid pairs)",
               "Regression slope", "Regression intercept"),
    Value  = c(round(r_val, 6),
               paste0(round(r_val^2 * 100, 2), "%"),
               round(ci_lo, 6), round(ci_hi, 6),
               round(t_stat, 4), n,
               round(slope, 6), round(interc, 6)),
    stringsAsFactors = FALSE
  )

  fit_tbl <- data.frame(
    Metric = c("p-value", "Correlation strength",
               "Direction", "Effect size class"),
    Value  = c(.format_p_value(p_val),
               .corr_label(r_val),
               if (r_val >= 0) "Positive" else "Negative",
               .cohens_d_label(r_val)),
    stringsAsFactors = FALSE
  )

  metrics <- list(r = r_val, p_value = p_val, ci_lower = ci_lo,
                  ci_upper = ci_hi, method = method,
                  x_var = xname, y_var = yname,
                  n = n, slope = slope)

  explanation <- .generate_correlation_narrative(metrics)

  structure(
    list(
      test_type          = "correlation",
      formula_str        = formula_str,
      raw_model          = cor_test,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

# ---------------------------------------------------------------------------
# Internal: pairwise correlation matrix
# ---------------------------------------------------------------------------
.easy_corr_matrix <- function(data, vars = NULL, method = "pearson",
                               conf_level = 0.95, alpha = 0.05) {
  if (is.null(vars)) vars <- names(data)[sapply(data, is.numeric)]
  if (length(vars) < 2) stop("Need at least 2 numeric variables.")
  mat <- data[, vars, drop = FALSE]
  n_v <- length(vars)

  # Correlation matrix
  corr_mat <- stats::cor(mat, use = "pairwise.complete.obs", method = method)

  # p-value matrix
  p_mat <- matrix(NA_real_, nrow = n_v, ncol = n_v,
                  dimnames = list(vars, vars))
  for (i in seq_len(n_v)) {
    for (j in seq_len(n_v)) {
      if (i != j) {
        idx <- stats::complete.cases(mat[[i]], mat[[j]])
        if (sum(idx) >= 3) {
          ct <- stats::cor.test(mat[[vars[i]]][idx], mat[[vars[j]]][idx],
                                method = method)
          p_mat[i, j] <- ct$p.value
        }
      }
    }
  }

  # Build long-format coefficient table
  rows <- list()
  for (i in seq_len(n_v - 1)) {
    for (j in (i + 1):n_v) {
      rows[[length(rows) + 1]] <- data.frame(
        Var1      = vars[i],
        Var2      = vars[j],
        r         = round(corr_mat[i, j], 4),
        r_squared = round(corr_mat[i, j]^2, 4),
        p_value   = .format_p_value(p_mat[i, j]),
        Strength  = .corr_label(corr_mat[i, j]),
        Direction = if (corr_mat[i, j] >= 0) "Positive" else "Negative",
        Sig       = if (!is.na(p_mat[i, j]) && p_mat[i, j] < alpha) "Yes" else "No",
        stringsAsFactors = FALSE
      )
    }
  }
  coef_tbl <- do.call(rbind, rows)

  # Summary
  all_r <- corr_mat[lower.tri(corr_mat)]
  fit_tbl <- data.frame(
    Metric = c("Method", "Variables", "Pairs examined",
               "Strongest correlation", "Weakest correlation",
               "Pairs significant"),
    Value  = c(tools::toTitleCase(method), n_v, nrow(coef_tbl),
               round(max(abs(all_r), na.rm = TRUE), 4),
               round(min(abs(all_r), na.rm = TRUE), 4),
               sum(coef_tbl$Sig == "Yes", na.rm = TRUE)),
    stringsAsFactors = FALSE
  )

  # Narrative for matrix
  n_strong   <- sum(abs(all_r) >= 0.70, na.rm = TRUE)
  n_moderate <- sum(abs(all_r) >= 0.30 & abs(all_r) < 0.70, na.rm = TRUE)
  metrics    <- list(
    method = method, n_vars = n_v, n_pairs = nrow(coef_tbl),
    corr_values = all_r
  )
  explanation <- .generate_corr_heatmap_interpretation(metrics)

  structure(
    list(
      test_type          = "correlation_matrix",
      formula_str        = paste("Pairwise:", paste(vars, collapse = ", ")),
      raw_model          = list(corr_matrix = corr_mat, p_matrix = p_mat),
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation,
      corr_matrix_raw    = corr_mat  # extra: used by easy_correlation_heatmap
    ),
    class = "easystat_result"
  )
}

# Internal table helpers ------------------------------------------------------

.model_diagnostic_tables <- function(model) {
  resid <- stats::residuals(model)
  fitted <- stats::fitted(model)
  complete <- stats::complete.cases(resid, fitted)
  resid <- resid[complete]
  fitted <- fitted[complete]
  n <- length(resid)

  rmse <- sqrt(mean(resid^2, na.rm = TRUE))
  mae <- mean(abs(resid), na.rm = TRUE)
  shapiro_p <- .shapiro_p(resid)
  dw <- if (n > 1) sum(diff(resid)^2, na.rm = TRUE) / sum(resid^2, na.rm = TRUE) else NA_real_

  diagnostics <- data.frame(
    Metric = c("N used", "RMSE", "MAE", "Residual SD", "Mean residual",
               "Shapiro-Wilk residual p", "Durbin-Watson statistic"),
    Value = c(n, round(rmse, 4), round(mae, 4), round(stats::sd(resid), 4),
              round(mean(resid), 4), .format_p_value(shapiro_p), round(dw, 4)),
    stringsAsFactors = FALSE
  )

  infl <- stats::influence.measures(model)
  cooks <- stats::cooks.distance(model)
  hat <- stats::hatvalues(model)
  std_resid <- stats::rstandard(model)
  top_idx <- utils::head(order(cooks, decreasing = TRUE), min(5, length(cooks)))
  influence <- data.frame(
    Observation = as.integer(top_idx),
    Cook_Distance = round(cooks[top_idx], 6),
    Leverage = round(hat[top_idx], 6),
    Std_Residual = round(std_resid[top_idx], 4),
    Influential = ifelse(apply(infl$is.inf[top_idx, , drop = FALSE], 1, any), "Yes", "No"),
    stringsAsFactors = FALSE
  )

  list(
    "Regression Diagnostics" = diagnostics,
    "Influential Observations" = influence
  )
}

.anova_support_tables <- function(model, formula, data, alpha = 0.05) {
  vars <- all.vars(formula)
  outcome_var <- vars[1]
  group_var <- vars[2]

  grp <- factor(data[[group_var]])
  y <- data[[outcome_var]]
  group_levels <- levels(grp)
  group_rows <- lapply(group_levels, function(g) {
    vals <- y[grp == g]
    vals <- vals[!is.na(vals)]
    n <- length(vals)
    sd_val <- if (n > 1) stats::sd(vals) else NA_real_
    se <- if (n > 1) sd_val / sqrt(n) else NA_real_
    ci <- if (n > 1) stats::qt(0.975, df = n - 1) * se else NA_real_
    data.frame(
      Group = g,
      N = n,
      Mean = round(mean(vals), 4),
      SD = round(sd_val, 4),
      SE = round(se, 4),
      CI_Lower = round(mean(vals) - ci, 4),
      CI_Upper = round(mean(vals) + ci, 4),
      stringsAsFactors = FALSE
    )
  })
  group_summary <- do.call(rbind, group_rows)

  resid <- stats::residuals(model)
  shapiro_p <- .shapiro_p(resid)
  bartlett_p <- tryCatch(stats::bartlett.test(stats::as.formula(paste(outcome_var, "~", group_var)),
                                             data = data)$p.value,
                         error = function(e) NA_real_)
  assumptions <- data.frame(
    Check = c("Residual normality (Shapiro-Wilk)",
              "Equal variances (Bartlett)",
              "Recommended next step"),
    Result = c(.format_p_value(shapiro_p),
               .format_p_value(bartlett_p),
               if (!is.na(bartlett_p) && bartlett_p < alpha)
                 "Consider Welch ANOVA or Kruskal-Wallis"
               else "Classical one-way ANOVA assumptions are broadly supported"),
    stringsAsFactors = FALSE
  )

  tukey_table <- tryCatch({
    tk <- stats::TukeyHSD(model)
    tk_df <- as.data.frame(tk[[1]])
    tk_df$Comparison <- rownames(tk_df)
    rownames(tk_df) <- NULL
    data.frame(
      Comparison = tk_df$Comparison,
      Difference = round(tk_df$diff, 4),
      CI_Lower = round(tk_df$lwr, 4),
      CI_Upper = round(tk_df$upr, 4),
      Adj_p_value = .format_p_value(tk_df$`p adj`),
      Significant = ifelse(tk_df$`p adj` < alpha, "Yes", "No"),
      stringsAsFactors = FALSE
    )
  }, error = function(e) NULL)

  out <- list(
    "Group Descriptives" = group_summary,
    "Assumption Checks" = assumptions
  )
  if (!is.null(tukey_table)) out[["Tukey Post-hoc Comparisons"]] <- tukey_table
  out
}

.contingency_tables <- function(tbl, expected) {
  observed_df <- as.data.frame.matrix(tbl)
  observed_df <- cbind(Category = rownames(observed_df), observed_df, row.names = NULL)

  expected_df <- as.data.frame.matrix(round(expected, 4))
  expected_df <- cbind(Category = rownames(expected_df), expected_df, row.names = NULL)

  row_pct <- round(prop.table(tbl, margin = 1) * 100, 4)
  row_pct_df <- as.data.frame.matrix(row_pct)
  row_pct_df <- cbind(Category = rownames(row_pct_df), row_pct_df, row.names = NULL)

  col_pct <- round(prop.table(tbl, margin = 2) * 100, 4)
  col_pct_df <- as.data.frame.matrix(col_pct)
  col_pct_df <- cbind(Category = rownames(col_pct_df), col_pct_df, row.names = NULL)

  total_pct <- round(prop.table(tbl) * 100, 4)
  total_pct_df <- as.data.frame.matrix(total_pct)
  total_pct_df <- cbind(Category = rownames(total_pct_df), total_pct_df, row.names = NULL)

  list(
    "Observed Contingency Table" = observed_df,
    "Expected Counts" = expected_df,
    "Row Percentages" = row_pct_df,
    "Column Percentages" = col_pct_df,
    "Total Percentages" = total_pct_df
  )
}

#' Wilcoxon Tests with Automated Narrative Reporting
#'
#' Runs a one-sample, paired, or two-sample Wilcoxon test using
#' \code{stats::wilcox.test()} and returns an \code{"easystat_result"} object.
#'
#' @param x Numeric vector, or a formula of the form \code{outcome ~ group}.
#' @param y Optional numeric vector for paired or two-sample tests.
#' @param data Data frame used when \code{x} is a formula.
#' @param mu Null hypothesized location or location shift. Default \code{0}.
#' @param paired Logical. Use paired test? Default \code{FALSE}.
#' @param alternative \code{"two.sided"}, \code{"less"}, or \code{"greater"}.
#' @param conf_level Confidence level. Default \code{0.95}.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An \code{"easystat_result"} object.
#'
#' @examples
#' result <- easy_wilcox(mpg ~ am, data = mtcars)
#' print(result)
#'
#' @export
easy_wilcox <- function(x, y = NULL, data = NULL, mu = 0, paired = FALSE,
                        alternative = "two.sided", conf_level = 0.95,
                        alpha = 0.05) {
  alternative <- match.arg(alternative, c("two.sided", "less", "greater"))
  formula_str <- NULL
  group1 <- "Sample"
  group2 <- NULL

  if (inherits(x, "formula") || is.character(x)) {
    if (is.character(x)) x <- stats::as.formula(x)
    if (is.null(data)) stop("'data' must be provided when 'x' is a formula.")
    vars <- all.vars(x)
    outcome <- vars[1]
    group <- vars[2]
    levels_g <- levels(factor(data[[group]]))
    if (length(levels_g) != 2) stop("Wilcoxon formula tests require exactly 2 groups.")
    group1 <- levels_g[1]
    group2 <- levels_g[2]
    x_vec <- data[[outcome]][data[[group]] == group1]
    y_vec <- data[[outcome]][data[[group]] == group2]
    formula_str <- deparse(x)
  } else {
    x_vec <- x
    y_vec <- y
    formula_str <- if (is.null(y)) "One-sample Wilcoxon test" else "Wilcoxon comparison"
    if (!is.null(y)) {
      group1 <- deparse(substitute(x))
      group2 <- deparse(substitute(y))
    }
  }

  test <- stats::wilcox.test(x_vec, y_vec, mu = mu, paired = paired,
                             alternative = alternative,
                             conf.int = TRUE, conf.level = conf_level,
                             exact = FALSE)
  p_val <- test$p.value
  stat <- as.numeric(test$statistic)

  median1 <- stats::median(x_vec, na.rm = TRUE)
  median2 <- if (!is.null(y_vec)) stats::median(y_vec, na.rm = TRUE) else NA_real_
  n1 <- sum(!is.na(x_vec))
  n2 <- if (!is.null(y_vec)) sum(!is.na(y_vec)) else NA_integer_

  coef_tbl <- data.frame(
    Metric = c("Median Group 1", "Median Group 2", "n Group 1", "n Group 2",
               paste0(round(conf_level * 100), "% CI lower"),
               paste0(round(conf_level * 100), "% CI upper")),
    Value = c(round(median1, 4), round(median2, 4), n1, n2,
              round(test$conf.int[1], 4), round(test$conf.int[2], 4)),
    stringsAsFactors = FALSE
  )
  fit_tbl <- data.frame(
    Metric = c("W statistic", "p-value", "Alternative", "Paired"),
    Value = c(round(stat, 4), .format_p_value(p_val), alternative, paired),
    stringsAsFactors = FALSE
  )

  explanation <- glue::glue(
    "WILCOXON TEST\nComparison: {formula_str}\n\n",
    "The Wilcoxon test produced W = {round(stat, 4)} and was {.sig_label(p_val, alpha)}. ",
    if (!is.null(group2)) glue::glue("The medians were {round(median1, 4)} for '{group1}' and {round(median2, 4)} for '{group2}'. ")
    else glue::glue("The sample median was {round(median1, 4)}. "),
    if (!is.na(p_val) && p_val < alpha)
      "This supports a statistically meaningful difference in distribution/location."
    else
      "The data do not provide sufficient evidence of a distribution/location difference."
  )

  structure(
    list(
      test_type = "wilcox",
      formula_str = formula_str,
      raw_model = test,
      coefficients_table = coef_tbl,
      model_fit_table = fit_tbl,
      explanation = explanation
    ),
    class = "easystat_result"
  )
}

#' Kruskal-Wallis Test with Automated Narrative Reporting
#'
#' Runs a Kruskal-Wallis rank-sum test for comparing three or more groups.
#'
#' @param formula A formula of the form \code{outcome ~ group}.
#' @param data A data frame.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An \code{"easystat_result"} object.
#'
#' @examples
#' result <- easy_kruskal(Sepal.Length ~ Species, data = iris)
#' print(result)
#'
#' @export
easy_kruskal <- function(formula, data, alpha = 0.05) {
  if (is.character(formula)) formula <- stats::as.formula(formula)
  if (!inherits(formula, "formula")) stop("'formula' must be a formula object or character string.")
  if (!is.data.frame(data)) stop("'data' must be a data frame.")

  vars <- all.vars(formula)
  outcome <- vars[1]
  group <- vars[2]
  test <- stats::kruskal.test(formula, data = data)

  grp <- factor(data[[group]])
  y <- data[[outcome]]
  levels_g <- levels(grp)
  rows <- lapply(levels_g, function(g) {
    vals <- y[grp == g]
    vals <- vals[!is.na(vals)]
    data.frame(
      Group = g,
      N = length(vals),
      Median = round(stats::median(vals), 4),
      Mean_Rank = round(mean(rank(y, na.last = "keep")[grp == g], na.rm = TRUE), 4),
      stringsAsFactors = FALSE
    )
  })
  coef_tbl <- do.call(rbind, rows)

  h <- as.numeric(test$statistic)
  df <- as.numeric(test$parameter)
  p_val <- test$p.value
  n <- sum(!is.na(y) & !is.na(grp))
  k <- length(levels_g)
  eta_sq <- max(0, (h - k + 1) / (n - k))

  fit_tbl <- data.frame(
    Metric = c("Kruskal-Wallis H", "Degrees of Freedom", "p-value",
               "Eta-squared estimate", "Groups", "N"),
    Value = c(round(h, 4), df, .format_p_value(p_val),
              round(eta_sq, 4), k, n),
    stringsAsFactors = FALSE
  )

  explanation <- glue::glue(
    "KRUSKAL-WALLIS TEST\nFormula: {deparse(formula)}\n\n",
    "The Kruskal-Wallis test produced H({df}) = {round(h, 4)} and was {.sig_label(p_val, alpha)}. ",
    "The estimated rank-based eta-squared is {round(eta_sq, 4)}. ",
    if (!is.na(p_val) && p_val < alpha)
      "At least one group distribution differs; pairwise Wilcoxon tests with p-value adjustment are recommended."
    else
      "The data do not provide sufficient evidence that the group distributions differ."
  )

  structure(
    list(
      test_type = "kruskal",
      formula_str = deparse(formula),
      raw_model = test,
      coefficients_table = coef_tbl,
      model_fit_table = fit_tbl,
      explanation = explanation
    ),
    class = "easystat_result"
  )
}

# Descriptive Statistics and Group Summary Functions
# Provides comprehensive descriptive statistics for numeric variables,
# including measures of central tendency, spread, shape, and normality,
# plus group-wise summaries and automatic narrative generation.

# ---------------------------------------------------------------------------
# Internal helpers
# ---------------------------------------------------------------------------
.mode_val <- function(x) {
  x <- x[!is.na(x)]
  ux <- unique(x)
  ux[which.max(tabulate(match(x, ux)))]
}

.skewness_calc <- function(x) {
  x <- x[!is.na(x)]
  n <- length(x)
  if (n < 3) return(NA_real_)
  (n / ((n - 1) * (n - 2))) * sum(((x - mean(x)) / stats::sd(x))^3)
}

.kurtosis_calc <- function(x) {
  x <- x[!is.na(x)]
  n <- length(x)
  if (n < 4) return(NA_real_)
  k_raw <- ((n * (n + 1)) / ((n - 1) * (n - 2) * (n - 3))) *
            sum(((x - mean(x)) / stats::sd(x))^4)
  k_cor <- (3 * (n - 1)^2) / ((n - 2) * (n - 3))
  k_raw - k_cor
}

.shapiro_p <- function(x) {
  x <- x[!is.na(x)]
  if (length(x) < 3 || length(x) > 5000) return(NA_real_)
  tryCatch(stats::shapiro.test(x)$p.value, error = function(e) NA_real_)
}

.describe_one <- function(x, var_name = "x", digits = 4, conf_level = 0.95) {
  x_clean  <- x[!is.na(x)]
  n        <- length(x_clean)
  n_miss   <- sum(is.na(x))
  if (n == 0) stop("No non-missing values found in '", var_name, "'.")

  mn       <- mean(x_clean)
  med      <- stats::median(x_clean)
  mod      <- .mode_val(x_clean)
  trim_mn  <- mean(x_clean, trim = 0.05)
  s        <- if (n > 1) stats::sd(x_clean)  else NA_real_
  v        <- if (n > 1) stats::var(x_clean) else NA_real_
  se       <- if (n > 1) s / sqrt(n)         else NA_real_
  cv_pct   <- if (!is.na(s) && mn != 0) (s / abs(mn)) * 100 else NA_real_
  q        <- stats::quantile(x_clean, c(0, 0.25, 0.50, 0.75, 1))
  iqr_val  <- as.numeric(q[4] - q[2])
  rng      <- as.numeric(q[5] - q[1])
  sk       <- .skewness_calc(x_clean)
  kt       <- .kurtosis_calc(x_clean)
  sw_p     <- .shapiro_p(x_clean)

  # CI for mean
  t_crit   <- if (n > 1) stats::qt((1 + conf_level) / 2, df = n - 1) else NA_real_
  ci_lo    <- mn - t_crit * se
  ci_hi    <- mn + t_crit * se

  list(
    var_name   = var_name,
    n          = n,
    n_missing  = n_miss,
    mean       = mn,
    trimmed_mean = trim_mn,
    median     = med,
    mode       = mod,
    sd         = s,
    variance   = v,
    se_mean    = se,
    cv_pct     = cv_pct,
    min        = as.numeric(q[1]),
    q1         = as.numeric(q[2]),
    q3         = as.numeric(q[4]),
    max        = as.numeric(q[5]),
    range_val  = rng,
    iqr        = iqr_val,
    skewness   = sk,
    kurtosis   = kt,
    shapiro_p  = sw_p,
    ci_lower   = ci_lo,
    ci_upper   = ci_hi
  )
}

# ---------------------------------------------------------------------------
# easy_describe  \u2014 Comprehensive Descriptive Statistics
# ---------------------------------------------------------------------------

#' Comprehensive Descriptive Statistics with Narrative
#'
#' Computes a rich set of descriptive statistics for one or more numeric
#' variables, including measures of central tendency, dispersion, shape
#' (skewness, kurtosis), and normality (Shapiro-Wilk), together with an
#' automatic plain-language narrative interpretation.
#'
#' @param data A numeric vector \strong{or} a data frame.
#' @param vars Character vector of column names to describe when \code{data}
#'   is a data frame. If \code{NULL} (default), all numeric columns are used.
#' @param digits Number of decimal places in the summary table. Default \code{4}.
#' @param conf_level Confidence level for the mean CI. Default \code{0.95}.
#'
#' @return An \code{"easystat_result"} object with:
#'   \describe{
#'     \item{\code{coefficients_table}}{Wide-format summary statistics table}
#'     \item{\code{model_fit_table}}{Shape and normality digest}
#'     \item{\code{explanation}}{Plain-language narrative (one per variable)}
#'   }
#'
#' @examples
#' result <- easy_describe(mtcars, vars = c("mpg", "hp", "wt"))
#' print(result)
#'
#' @export
easy_describe <- function(data, vars = NULL, digits = 4, conf_level = 0.95) {

  # ---- Normalise input ----
  if (is.numeric(data)) {
    vname <- deparse(substitute(data))
    df    <- data.frame(x = data)
    colnames(df) <- vname
    vars  <- vname
  } else {
    if (!is.data.frame(data)) stop("'data' must be a numeric vector or data frame.")
    if (is.null(vars)) {
      vars <- names(data)[sapply(data, is.numeric)]
    }
    if (length(vars) == 0) stop("No numeric variables found.")
    df <- data[, vars, drop = FALSE]
  }

  # ---- Compute stats per variable ----
  stats_list <- lapply(vars, function(v) .describe_one(df[[v]], v, digits, conf_level))
  names(stats_list) <- vars

  # ---- Build summary table (one row per variable) ----
  rows <- lapply(stats_list, function(m) {
    data.frame(
      Variable   = m$var_name,
      N          = m$n,
      Missing    = m$n_missing,
      Mean       = round(m$mean, digits),
      Median     = round(m$median, digits),
      Mode       = round(m$mode, digits),
      SD         = round(m$sd, digits),
      SE         = round(m$se_mean, digits),
      Variance   = round(m$variance, digits),
      Min        = round(m$min, digits),
      Q1         = round(m$q1, digits),
      Q3         = round(m$q3, digits),
      Max        = round(m$max, digits),
      Range      = round(m$range_val, digits),
      IQR        = round(m$iqr, digits),
      CV_pct     = round(m$cv_pct, digits),
      Skewness   = round(m$skewness, digits),
      Kurtosis   = round(m$kurtosis, digits),
      CI_lower   = round(m$ci_lower, digits),
      CI_upper   = round(m$ci_upper, digits),
      Shapiro_p  = .format_p_value(m$shapiro_p),
      stringsAsFactors = FALSE
    )
  })
  coef_tbl <- do.call(rbind, rows)

  # ---- Shape / normality digest ----
  fit_rows <- lapply(stats_list, function(m) {
    data.frame(
      Variable    = m$var_name,
      Shape       = .skew_label(m$skewness),
      Kurtosis    = .kurt_label(m$kurtosis),
      Normality   = .norm_label(m$shapiro_p),
      Shapiro_p   = .format_p_value(m$shapiro_p),
      stringsAsFactors = FALSE
    )
  })
  fit_tbl <- do.call(rbind, fit_rows)

  # ---- Narrative (concatenate all variables) ----
  narratives <- sapply(stats_list, function(m) .generate_describe_narrative(m, m$var_name))
  explanation <- paste(narratives, collapse = "\n\n---\n\n")

  structure(
    list(
      test_type          = "describe",
      formula_str        = paste("Descriptive:", paste(vars, collapse = ", ")),
      raw_model          = stats_list,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

# ---------------------------------------------------------------------------
# easy_group_summary  \u2014 Group-Wise Descriptive Statistics
# ---------------------------------------------------------------------------

#' Group-Wise Summary Statistics with Narrative
#'
#' Computes descriptive statistics for a numeric outcome variable stratified
#' by a grouping factor, providing both a comparison table and a narrative
#' highlighting which group has the highest/lowest mean and variability.
#'
#' @param formula A formula of the form \code{outcome ~ group}.
#' @param data A data frame containing the variables.
#' @param digits Number of decimal places. Default \code{4}.
#'
#' @return An \code{"easystat_result"} object.
#'
#' @examples
#' result <- easy_group_summary(mpg ~ cyl, data = mtcars)
#' print(result)
#'
#' @export
easy_group_summary <- function(formula, data, digits = 4) {

  if (is.character(formula)) formula <- stats::as.formula(formula)
  if (!is.data.frame(data))  stop("'data' must be a data frame.")

  formula_str <- deparse(formula)
  vars        <- all.vars(formula)
  outcome_var <- vars[1]
  group_var   <- vars[2]

  if (!is.numeric(data[[outcome_var]]))
    stop("'", outcome_var, "' must be numeric.")

  groups  <- unique(data[[group_var]])
  n_grps  <- length(groups)

  # Compute stats per group
  rows <- lapply(groups, function(g) {
    x_g  <- data[[outcome_var]][data[[group_var]] == g]
    m    <- .describe_one(x_g, as.character(g))
    data.frame(
      Group   = as.character(g),
      N       = m$n,
      Mean    = round(m$mean, digits),
      Median  = round(m$median, digits),
      SD      = round(m$sd, digits),
      SE      = round(m$se_mean, digits),
      Min     = round(m$min, digits),
      Max     = round(m$max, digits),
      IQR     = round(m$iqr, digits),
      CV_pct  = round(m$cv_pct, digits),
      Skewness = round(m$skewness, digits),
      CI_lower = round(m$ci_lower, digits),
      CI_upper = round(m$ci_upper, digits),
      stringsAsFactors = FALSE
    )
  })
  coef_tbl <- do.call(rbind, rows)

  # Overall stats for model_fit_table
  overall <- .describe_one(data[[outcome_var]], outcome_var)
  fit_tbl <- data.frame(
    Metric = c("Outcome variable", "Grouping variable",
               "Number of groups", "Overall Mean",
               "Overall SD", "Overall Median"),
    Value  = c(outcome_var, group_var,
               n_grps, round(overall$mean, digits),
               round(overall$sd, digits), round(overall$median, digits)),
    stringsAsFactors = FALSE
  )

  # ---- Narrative ----
  max_mean_grp <- coef_tbl$Group[which.max(coef_tbl$Mean)]
  min_mean_grp <- coef_tbl$Group[which.min(coef_tbl$Mean)]
  max_sd_grp   <- coef_tbl$Group[which.max(coef_tbl$SD)]

  explanation <- glue::glue(
    "GROUP SUMMARY: {outcome_var} by {group_var}\n\n",
    "Descriptive statistics were computed for '{outcome_var}' across {n_grps} groups of '{group_var}'. ",
    "The group with the highest mean is '{max_mean_grp}' (M = {max(coef_tbl$Mean, na.rm=TRUE)}), ",
    "while the group with the lowest mean is '{min_mean_grp}' (M = {min(coef_tbl$Mean, na.rm=TRUE)}). ",
    "The group with the greatest variability (highest SD) is '{max_sd_grp}' ",
    "(SD = {coef_tbl$SD[coef_tbl$Group == max_sd_grp]}). ",
    "Overall, the grand mean across all groups is {round(overall$mean, digits)} ",
    "(SD = {round(overall$sd, digits)}, Median = {round(overall$median, digits)}). ",
    "These group-level statistics provide the foundation for inferential comparisons ",
    "using ANOVA or t-tests."
  )

  structure(
    list(
      test_type          = "group_summary",
      formula_str        = formula_str,
      raw_model          = rows,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

#' Export an EasyStat Result to a Formatted Microsoft Word Document
#'
#' Takes a unified \code{easystat_result} object and writes a fully formatted
#' \code{.docx} report using the \code{flextable} and \code{officer} packages.
#' The report contains a title page header, the plain-language narrative,
#' both statistical tables rendered as professional \code{flextable} objects,
#' and a footer with metadata. All of this is produced in a single function call.
#'
#' @param result An object of class \code{"easystat_result"} as returned by
#'   \code{\link{easy_regression}}, \code{\link{easy_logistic_regression}},
#'   \code{\link{easy_ttest}}, or \code{\link{easy_anova}}.
#' @param file Character string. Path to the output \code{.docx} file.
#'   Must be provided by the caller; for example, use
#'   \code{tempfile(fileext = ".docx")} for a temporary file.
#' @param title Character string. Report title printed at the top of the
#'   document. If \code{NULL} (default) a title is auto-generated from the
#'   test type.
#' @param author Character string. Author name(s) for the report header.
#'   Default \code{"EasyStat"}.
#'
#' @return The \code{file} path invisibly (a length-one character vector). The
#'   \code{.docx} file is written to the path supplied via \code{file} as a
#'   side-effect.
#'
#' @examples
#' \donttest{
#'   result <- easy_regression(mpg ~ wt + hp, data = mtcars)
#'   export_to_word(result, file = tempfile(fileext = ".docx"),
#'                 author = "Mr. Mahesh Divakaran")
#' }
#'
#' @export
export_to_word <- function(result,
                           file,
                           title  = NULL,
                           author = "EasyStat") {

  # ---- Dependency check ----
  for (pkg in c("officer", "flextable")) {
    if (!requireNamespace(pkg, quietly = TRUE)) {
      stop(paste0("Package '", pkg, "' is required for export_to_word(). ",
                  "Install with: install.packages('", pkg, "')"))
    }
  }

  if (!inherits(result, "easystat_result")) {
    stop("'result' must be an object of class 'easystat_result'.")
  }

  # ---- Auto-title ----
  test_label <- switch(result$test_type,
    regression          = "Linear Regression Analysis",
    logistic_regression = "Logistic Regression Analysis",
    ttest               = "Independent-Samples t-Test",
    anova               = "One-Way ANOVA",
    "Statistical Analysis"
  )
  if (is.null(title)) title <- paste("EasyStat Report:", test_label)

  # ---- Helper: build a themed flextable ----
  .make_ft <- function(df) {
    ft <- flextable::flextable(df)
    ft <- flextable::set_table_properties(ft, width = 1, layout = "autofit")
    ft <- flextable::bold(ft, part = "header")
    ft <- flextable::bg(ft, bg = "#2E5FA3", part = "header")
    ft <- flextable::color(ft, color = "white", part = "header")
    ft <- flextable::bg(ft, i = seq(2, nrow(df), by = 2),
                        bg = "#EEF3FB", part = "body")
    ft <- flextable::border_outer(ft,
            border = officer::fp_border(color = "#2E5FA3", width = 1.5))
    ft <- flextable::border_inner_h(ft,
            border = officer::fp_border(color = "#BED0E8", width = 0.5))
    ft <- flextable::fontsize(ft, size = 10, part = "all")
    ft <- flextable::font(ft, fontname = "Arial", part = "all")
    ft <- flextable::padding(ft, padding = 4, part = "all")
    ft
  }

  # ---- Helper: body text paragraph ----
  .body_text <- function(doc, text_str) {
    doc <- officer::body_add_par(doc, text_str,
             style = "Normal")
    doc
  }

  # ---- Build officer document ----
  doc <- officer::read_docx()

  # Title
  doc <- officer::body_add_par(doc, title, style = "heading 1")

  # Metadata line
  meta <- paste0("Test type: ", test_label,
                 "  |  Formula/Comparison: ", result$formula_str,
                 "  |  Generated: ", format(Sys.time(), "%Y-%m-%d %H:%M"),
                 "  |  Author: ", author)
  doc <- officer::body_add_par(doc, meta, style = "Normal")
  doc <- officer::body_add_par(doc, "", style = "Normal")  # spacer

  # Section: Narrative
  doc <- officer::body_add_par(doc, "Plain-Language Interpretation", style = "heading 2")

  # Split narrative on newlines and add each as its own paragraph
  narrative_parts <- strsplit(result$explanation, "\n")[[1]]
  for (part in narrative_parts) {
    if (nchar(trimws(part)) > 0) {
      doc <- officer::body_add_par(doc, part, style = "Normal")
    }
  }
  doc <- officer::body_add_par(doc, "", style = "Normal")

  # Section: Main Results Table
  doc <- officer::body_add_par(doc, "Table 1 \u2014 Main Results", style = "heading 2")
  doc <- flextable::body_add_flextable(doc, .make_ft(result$coefficients_table))
  doc <- officer::body_add_par(doc, "", style = "Normal")

  # Section: Model Fit Table
  doc <- officer::body_add_par(doc, "Table 2 \u2014 Model Fit / Summary", style = "heading 2")
  doc <- flextable::body_add_flextable(doc, .make_ft(result$model_fit_table))
  doc <- officer::body_add_par(doc, "", style = "Normal")

  if (!is.null(result$additional_tables) && length(result$additional_tables) > 0) {
    table_no <- 3
    for (nm in names(result$additional_tables)) {
      doc <- officer::body_add_par(doc, paste0("Table ", table_no, " \u2014 ", nm), style = "heading 2")
      doc <- flextable::body_add_flextable(doc, .make_ft(result$additional_tables[[nm]]))
      doc <- officer::body_add_par(doc, "", style = "Normal")
      table_no <- table_no + 1
    }
  }

  # Footer note
  doc <- officer::body_add_par(doc,
    paste0("Report generated by the EasyStat R Package. ",
           "Authors: Mr. Mahesh Divakaran, Dr. Gunjan Singh, ",
           "Prof. Dr. Jayadevan Shreedharan. ",
           "Amity University Lucknow & Gulf Medical University."),
    style = "Normal")

  # ---- Write to disk ----
  print(doc, target = file)

  message("Word document saved: ", normalizePath(file, mustWork = FALSE))
  invisible(file)
}

# EasyStat Visualization Functions
# A suite of ggplot2-based plotting functions, each returning an
# "easystat_result" object containing the plot object, a plain-language
# interpretation narrative, and a summary statistics table. All plots apply
# the unified theme_easystat() theme for a consistent visual identity.

# ---------------------------------------------------------------------------
# easy_histogram  \u2014  Distribution with Normal Curve Overlay
# ---------------------------------------------------------------------------

#' Annotated Histogram with Normal Curve Overlay
#'
#' Draws a histogram of a numeric variable, overlays a fitted normal density
#' curve, and annotates the plot with the mean, median, and standard deviation.
#' Normality is assessed via the Shapiro-Wilk test, and the result is displayed
#' in the subtitle.
#'
#' @param x Character column name OR a numeric vector.
#' @param data A data frame (required when \code{x} is a column name).
#' @param bins Number of histogram bins. Default \code{NULL} (auto).
#' @param fill_color Bar fill color. Default EasyStat primary blue.
#' @param show_normal Logical; overlay normal curve? Default \code{TRUE}.
#' @param title Custom plot title. Default auto-generated.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_histogram <- function(x, data = NULL, bins = NULL,
                            fill_color = NULL, show_normal = TRUE,
                            title = NULL) {
  if (is.character(x) && !is.null(data)) {
    var_name <- x; x_vec <- data[[x]]
  } else {
    var_name <- deparse(substitute(x)); x_vec <- x
  }
  x_vec <- x_vec[!is.na(x_vec)]
  if (!is.numeric(x_vec)) stop("'x' must be numeric.")

  fill_c  <- if (is.null(fill_color)) .ES_COLORS["primary"] else fill_color
  n       <- length(x_vec)
  mn      <- mean(x_vec); med <- stats::median(x_vec); s <- stats::sd(x_vec)
  sw_p    <- .shapiro_p(x_vec)
  sk      <- .skewness_calc(x_vec); kt <- .kurtosis_calc(x_vec)
  nbins   <- if (is.null(bins)) max(10, round(sqrt(n))) else bins

  # Subtitle
  norm_badge <- if (!is.na(sw_p) && sw_p < 0.05) "Non-Normal" else "Approximately Normal"
  subtitle   <- glue::glue(
    "n = {n}  |  Mean = {round(mn,3)}  |  Median = {round(med,3)}  ",
    "|  SD = {round(s,3)}  |  {norm_badge}"
  )
  plot_title <- if (is.null(title)) paste0("Distribution of ", var_name) else title

  df_plot <- data.frame(v = x_vec)
  bw      <- (max(x_vec) - min(x_vec)) / nbins

  gg <- ggplot2::ggplot(df_plot, ggplot2::aes(x = v)) +
    ggplot2::geom_histogram(ggplot2::aes(y = ggplot2::after_stat(density)),
                             bins  = nbins, fill = fill_c,
                             color = "white", alpha = 0.85) +
    ggplot2::geom_rug(color = fill_c, alpha = 0.4, linewidth = 0.3)

  if (show_normal) {
    x_seq <- seq(min(x_vec), max(x_vec), length.out = 300)
    norm_df <- data.frame(x = x_seq, y = stats::dnorm(x_seq, mn, s))
    gg <- gg +
      ggplot2::geom_line(data = norm_df, ggplot2::aes(x = x, y = y),
                          color = .ES_COLORS["secondary"], linewidth = 1.2,
                          linetype = "dashed")
  }

  # Mean & Median lines
  gg <- gg +
    ggplot2::geom_vline(xintercept = mn,  color = .ES_COLORS["accent2"],
                         linewidth = 1.0, linetype = "solid") +
    ggplot2::geom_vline(xintercept = med, color = .ES_COLORS["accent1"],
                         linewidth = 1.0, linetype = "longdash") +
    ggplot2::annotate("text", x = mn,  y = Inf, vjust = -0.3, hjust = -0.1,
                       label = paste0("Mean=", round(mn, 2)),
                       color = .ES_COLORS["accent2"], size = 3.2, fontface = "bold") +
    ggplot2::annotate("text", x = med, y = Inf, vjust = -0.3, hjust = 1.1,
                       label = paste0("Med=", round(med, 2)),
                       color = .ES_COLORS["accent1"], size = 3.2, fontface = "bold") +
    ggplot2::labs(title = plot_title, subtitle = subtitle,
                   x = var_name, y = "Density",
                   caption = .es_caption("Histogram")) +
    theme_easystat()

  metrics <- list(var_name = var_name, n = n, mean = mn, median = med,
                  sd = s, skewness = sk, kurtosis = kt, shapiro_p = sw_p)
  interp  <- .generate_histogram_interpretation(metrics)

  stats_tbl <- data.frame(
    Metric = c("n", "Mean", "Median", "SD", "Skewness", "Kurtosis", "Shapiro-Wilk p"),
    Value  = c(n, round(mn,4), round(med,4), round(s,4),
               round(sk,4), round(kt,4),
               .format_p_value(sw_p)),
    stringsAsFactors = FALSE
  )

  .make_easystat_plot("histogram", gg, interp,
    list(stats_table = stats_tbl, formula_str = paste0("Histogram: ", var_name)))
}


# ---------------------------------------------------------------------------
# easy_boxplot  \u2014  Group Comparison Boxplot
# ---------------------------------------------------------------------------

#' Grouped Boxplot with Outlier Detection
#'
#' Produces a boxplot for one variable, optionally grouped by a factor. Adds
#' a jittered dot overlay, labels each group's median, and highlights outliers.
#'
#' @param formula A formula: \code{outcome ~ group} for grouped, or a bare
#'   column name / numeric vector for a single-variable boxplot.
#' @param data A data frame.
#' @param fill_palette Character vector of fill colors. Default EasyStat palette.
#' @param notch Logical; draw notched boxes? Default \code{FALSE}.
#' @param title Custom plot title.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_boxplot <- function(formula, data, fill_palette = NULL,
                          notch = FALSE, title = NULL) {
  if (!is.data.frame(data)) stop("'data' must be a data frame.")
  if (is.character(formula)) formula <- stats::as.formula(formula)
  formula_str <- deparse(formula)
  vars        <- all.vars(formula)

  if (length(vars) == 2) {
    outcome_var <- vars[1]; group_var <- vars[2]
    grouped <- TRUE
  } else {
    outcome_var <- vars[1]; group_var <- NULL
    grouped <- FALSE
    data$.group <- "All"
    group_var <- ".group"
  }

  if (!is.numeric(data[[outcome_var]]))
    stop("'", outcome_var, "' must be numeric.")

  data[[group_var]] <- factor(data[[group_var]])
  n_grps  <- nlevels(data[[group_var]])
  palette <- if (is.null(fill_palette)) .ES_CAT_PALETTE[seq_len(n_grps)]
             else fill_palette

  # Detect outliers
  outlier_fn <- function(x) {
    q <- stats::quantile(x, c(0.25, 0.75), na.rm = TRUE)
    iqr_v <- q[2] - q[1]
    x < (q[1] - 1.5 * iqr_v) | x > (q[2] + 1.5 * iqr_v)
  }
  data$.outlier <- ave(data[[outcome_var]], data[[group_var]],
                       FUN = outlier_fn)
  n_out <- sum(data$.outlier, na.rm = TRUE)

  # Medians for annotation
  med_df <- stats::aggregate(stats::as.formula(paste(outcome_var, "~", group_var)),
                              data, FUN = stats::median)
  names(med_df)[2] <- "med"

  plot_title <- if (is.null(title)) {
    if (grouped) paste0(outcome_var, " by ", group_var) else paste0("Distribution of ", outcome_var)
  } else title
  subtitle <- glue::glue("n groups = {n_grps}  |  Outliers detected = {n_out}")

  gg <- ggplot2::ggplot(data,
         ggplot2::aes(x = .data[[group_var]], y = .data[[outcome_var]],
                       fill = .data[[group_var]])) +
    ggplot2::geom_boxplot(notch = notch, outlier.shape = NA,
                           alpha = 0.85, color = "#444444", linewidth = 0.5) +
    ggplot2::geom_jitter(width = 0.15, alpha = 0.35, size = 1.5,
                          color = .ES_COLORS["dark_text"]) +
    ggplot2::geom_text(data = med_df,
                        ggplot2::aes(x = .data[[group_var]], y = med,
                                      label = round(med, 2)),
                        vjust = -0.6, size = 3.3, fontface = "bold",
                        color = .ES_COLORS["dark_text"],
                        inherit.aes = FALSE) +
    ggplot2::scale_fill_manual(values = palette) +
    ggplot2::labs(title = plot_title, subtitle = subtitle,
                   x = if (grouped) group_var else "",
                   y = outcome_var, fill = group_var,
                   caption = .es_caption("Boxplot")) +
    theme_easystat() +
    ggplot2::theme(legend.position = if (n_grps > 1) "right" else "none")

  # Metrics
  grp_vals <- data[[outcome_var]][!is.na(data[[outcome_var]])]
  q_all    <- stats::quantile(grp_vals, c(0.25, 0.5, 0.75))
  metrics  <- list(
    outcome = outcome_var, group = if (grouped) group_var else NULL,
    n_groups = n_grps, q1 = q_all[1], median = q_all[2], q3 = q_all[3],
    iqr = q_all[3] - q_all[1], n_outliers = n_out
  )
  interp <- .generate_boxplot_interpretation(metrics)

  stats_tbl <- med_df
  names(stats_tbl)[2] <- "Median"
  .make_easystat_plot("boxplot", gg, interp,
    list(stats_table = stats_tbl, formula_str = formula_str))
}


# ---------------------------------------------------------------------------
# easy_scatter  \u2014  Scatter Plot with Regression Line
# ---------------------------------------------------------------------------

#' Scatter Plot with Regression Line and Correlation Annotation
#'
#' Draws a scatter plot for two numeric variables, overlays a linear regression
#' line with confidence band, and annotates the Pearson r and p-value.
#'
#' @param formula A formula: \code{y ~ x}.
#' @param data A data frame.
#' @param color_by Optional column name to color points by a third variable.
#' @param smooth Logical; show regression line? Default \code{TRUE}.
#' @param ellipse Logical; draw a 95\% data ellipse? Default \code{TRUE}.
#' @param title Custom plot title.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_scatter <- function(formula, data, color_by = NULL,
                          smooth = TRUE, ellipse = TRUE, title = NULL) {
  if (!is.data.frame(data)) stop("'data' must be a data frame.")
  if (is.character(formula)) formula <- stats::as.formula(formula)
  formula_str <- deparse(formula)
  vars <- all.vars(formula)
  if (length(vars) < 2) stop("Formula must specify y ~ x.")
  y_var <- vars[1]; x_var <- vars[2]
  if (!is.numeric(data[[y_var]]) || !is.numeric(data[[x_var]]))
    stop("Both variables must be numeric.")

  # Correlation for annotation
  complete_idx <- stats::complete.cases(data[[x_var]], data[[y_var]])
  xc <- data[[x_var]][complete_idx]; yc <- data[[y_var]][complete_idx]
  ct <- stats::cor.test(xc, yc)
  r_val  <- round(as.numeric(ct$estimate), 3)
  p_val  <- ct$p.value
  lm_fit <- stats::lm(stats::as.formula(paste(y_var, "~", x_var)), data = data)
  slope  <- stats::coef(lm_fit)[2]
  n      <- sum(complete_idx)

  badge <- .sig_badge(p_val)
  plot_title <- if (is.null(title))
    paste0(y_var, " - ", x_var) else title
  subtitle <- glue::glue("r = {r_val}  |  {badge}  |  n = {n}")

  aes_base <- if (!is.null(color_by)) {
    ggplot2::aes(x = .data[[x_var]], y = .data[[y_var]],
                  color = .data[[color_by]])
  } else {
    ggplot2::aes(x = .data[[x_var]], y = .data[[y_var]])
  }

  gg <- ggplot2::ggplot(data, aes_base) +
    ggplot2::geom_point(alpha = 0.7, size = 2.2,
      color = if (is.null(color_by)) .ES_COLORS["primary"] else NULL)

  if (ellipse && is.null(color_by)) {
    gg <- gg +
      ggplot2::stat_ellipse(color = .ES_COLORS["accent3"], linewidth = 0.8,
                             linetype = "dashed", level = 0.95, type = "norm")
  }

  if (smooth) {
    gg <- gg +
      ggplot2::geom_smooth(method = "lm", formula = y ~ x,
                            color = .ES_COLORS["secondary"],
                            fill  = paste0(.ES_COLORS["secondary"], "33"),
                            linewidth = 1.2, se = TRUE)
  }

  # Annotation box
  x_pos <- min(xc, na.rm = TRUE) + 0.05 * diff(range(xc, na.rm = TRUE))
  y_pos <- max(yc, na.rm = TRUE) - 0.05 * diff(range(yc, na.rm = TRUE))
  gg <- gg +
    ggplot2::annotate("label", x = x_pos, y = y_pos,
                       label = paste0("r = ", r_val, "\n", badge),
                       hjust = 0, vjust = 1, size = 3.2,
                       fill = .ES_COLORS["light_bg"],
                       color = .ES_COLORS["dark_text"]) +
    ggplot2::labs(title = plot_title, subtitle = subtitle,
                   x = x_var, y = y_var,
                   color = if (!is.null(color_by)) color_by else NULL,
                   caption = .es_caption("Scatterplot")) +
    theme_easystat()

  if (!is.null(color_by)) {
    gg <- gg + ggplot2::scale_color_manual(values = .ES_CAT_PALETTE)
  }

  metrics <- list(x_var = x_var, y_var = y_var, r = r_val, n = n,
                  p_value_r = p_val, slope = slope)
  interp  <- .generate_scatter_interpretation(metrics)

  stats_tbl <- data.frame(
    Metric = c("Pearson r", "p-value", "n", "Slope"),
    Value  = c(r_val, .format_p_value(p_val), n, round(slope,4)),
    stringsAsFactors = FALSE
  )
  .make_easystat_plot("scatter", gg, interp,
    list(stats_table = stats_tbl, formula_str = formula_str))
}


# ---------------------------------------------------------------------------
# easy_barplot  \u2014  Frequency / Mean Bar Chart
# ---------------------------------------------------------------------------

#' Annotated Bar Chart
#'
#' Creates a frequency bar chart for categorical variables, or a mean-and-error
#' bar chart for numeric outcomes grouped by a factor.
#'
#' @param x Column name of the variable to plot.
#' @param data A data frame.
#' @param group_by Optional grouping column for grouped frequency bars.
#' @param stat \code{"count"} (default) for frequency, or \code{"mean"} for
#'   mean ± SE bars.
#' @param fill_palette Color palette vector. Default EasyStat palette.
#' @param title Custom plot title.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_barplot <- function(x, data, group_by = NULL,
                          stat = c("count", "mean"),
                          fill_palette = NULL, title = NULL) {
  stat <- match.arg(stat)
  if (!is.data.frame(data)) stop("'data' must be a data frame.")
  if (!x %in% names(data)) stop("'", x, "' not found in data.")

  palette <- if (is.null(fill_palette)) .ES_CAT_PALETTE else fill_palette

  if (stat == "count") {
    data[[x]] <- factor(data[[x]])
    n_levels   <- nlevels(data[[x]])
    plot_title <- if (is.null(title)) paste0("Frequency: ", x) else title

    if (!is.null(group_by)) {
      data[[group_by]] <- factor(data[[group_by]])
      gg <- ggplot2::ggplot(data,
              ggplot2::aes(x = .data[[x]], fill = .data[[group_by]])) +
            ggplot2::geom_bar(position = "dodge", color = "white", alpha = 0.9) +
            ggplot2::scale_fill_manual(values = palette)
      subtitle <- glue::glue("Grouped by {group_by}")
    } else {
      cnt_df <- as.data.frame(table(data[[x]]))
      names(cnt_df) <- c("cat", "freq")
      cnt_df$pct <- round(cnt_df$freq / sum(cnt_df$freq) * 100, 1)

      gg <- ggplot2::ggplot(cnt_df, ggplot2::aes(x = cat, y = freq, fill = cat)) +
            ggplot2::geom_col(color = "white", alpha = 0.9, width = 0.7) +
            ggplot2::geom_text(ggplot2::aes(label = paste0(freq, "\n(", pct, "%)")),
                                vjust = -0.3, size = 3.2, fontface = "bold",
                                color = .ES_COLORS["dark_text"]) +
            ggplot2::scale_fill_manual(values = palette[seq_len(nrow(cnt_df))]) +
            ggplot2::guides(fill = "none")
      subtitle <- glue::glue("{n_levels} categories  |  n = {sum(cnt_df$freq)}")
    }

    gg <- gg +
      ggplot2::labs(title = plot_title, subtitle = subtitle,
                     x = x, y = "Frequency",
                     caption = .es_caption("Bar Chart")) +
      theme_easystat()

    stats_tbl <- as.data.frame(table(data[[x]]))
    names(stats_tbl) <- c("Category", "Count")
    interp <- glue::glue(
      "BAR CHART INTERPRETATION\n\n",
      "The bar chart displays the frequency distribution of '{x}'. ",
      "The most frequent category is '",
      stats_tbl$Category[which.max(stats_tbl$Count)], "' ",
      "(n = {max(stats_tbl$Count)}), and the least frequent is '",
      stats_tbl$Category[which.min(stats_tbl$Count)], "' ",
      "(n = {min(stats_tbl$Count)})."
    )

  } else {
    # Mean \u00B1 SE bar chart
    if (!is.numeric(data[[x]])) stop("For stat='mean', '", x, "' must be numeric.")
    if (is.null(group_by)) stop("'group_by' is required when stat='mean'.")
    data[[group_by]] <- factor(data[[group_by]])
    agg <- stats::aggregate(stats::as.formula(paste(x, "~", group_by)),
                             data, FUN = mean)
    agg$se <- stats::aggregate(stats::as.formula(paste(x, "~", group_by)),
                                data, FUN = function(v) stats::sd(v)/sqrt(length(v)))[[x]]
    names(agg)[2] <- "mean_val"

    plot_title <- if (is.null(title)) paste0("Mean ", x, " by ", group_by) else title
    subtitle   <- glue::glue("Mean (\u00b1 SE) bars  |  n groups = {nlevels(data[[group_by]])}")

    gg <- ggplot2::ggplot(agg,
            ggplot2::aes(x = .data[[group_by]], y = mean_val,
                          fill = .data[[group_by]])) +
          ggplot2::geom_col(color = "white", alpha = 0.9, width = 0.65) +
          ggplot2::geom_errorbar(ggplot2::aes(ymin = mean_val - se,
                                               ymax = mean_val + se),
                                  width = 0.2, color = .ES_COLORS["dark_text"],
                                  linewidth = 0.8) +
          ggplot2::geom_text(ggplot2::aes(label = round(mean_val, 2)),
                              vjust = -0.5, size = 3.3, fontface = "bold",
                              color = .ES_COLORS["dark_text"]) +
          ggplot2::scale_fill_manual(values = palette[seq_len(nrow(agg))]) +
          ggplot2::guides(fill = "none") +
          ggplot2::labs(title = plot_title, subtitle = subtitle,
                         x = group_by, y = paste0("Mean ", x),
                         caption = .es_caption("Bar Chart \u2014 Mean \u00b1 SE")) +
          theme_easystat()

    stats_tbl <- agg[, c(group_by, "mean_val", "se")]
    names(stats_tbl) <- c("Group", "Mean", "SE")
    interp <- glue::glue(
      "MEAN BAR CHART INTERPRETATION\n\n",
      "The chart displays mean values of '{x}' across groups of '{group_by}', ",
      "with error bars representing \u00b1 1 standard error. ",
      "The group with the highest mean is '{agg[[group_by]][which.max(agg$mean_val)]}' ",
      "(M = {round(max(agg$mean_val), 3)})."
    )
  }

  .make_easystat_plot("barplot", gg, interp,
    list(stats_table = stats_tbl, formula_str = paste0("Bar: ", x)))
}


# ---------------------------------------------------------------------------
# easy_qqplot  \u2014  Normal Q-Q Plot
# ---------------------------------------------------------------------------

#' Normal Q-Q Plot with Shapiro-Wilk Annotation
#'
#' Plots sample quantiles against theoretical normal quantiles and annotates
#' the Shapiro-Wilk p-value. Deviations from the diagonal indicate
#' non-normality.
#'
#' @param x Column name or numeric vector.
#' @param data A data frame (required when \code{x} is a column name).
#' @param title Custom plot title.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_qqplot <- function(x, data = NULL, title = NULL) {
  if (is.character(x) && !is.null(data)) {
    var_name <- x; x_vec <- data[[x]]
  } else {
    var_name <- deparse(substitute(x)); x_vec <- x
  }
  x_vec <- x_vec[!is.na(x_vec)]
  if (!is.numeric(x_vec)) stop("'x' must be numeric.")

  sw_p  <- .shapiro_p(x_vec)
  badge <- if (!is.na(sw_p) && sw_p < 0.05) "NON-NORMAL" else "APPROXIMATELY NORMAL"
  n     <- length(x_vec)

  plot_title <- if (is.null(title)) paste0("Normal Q-Q Plot: ", var_name) else title
  subtitle   <- glue::glue("Shapiro-Wilk: {badge}  |  ",
    "{.format_p_statement(sw_p)}  |  n = {n}")

  df_qq <- data.frame(v = x_vec)
  gg <- ggplot2::ggplot(df_qq, ggplot2::aes(sample = v)) +
    ggplot2::geom_qq_line(color = .ES_COLORS["secondary"],
                           linewidth = 1.0, linetype = "dashed") +
    ggplot2::geom_qq(color = .ES_COLORS["primary"], alpha = 0.7, size = 2) +
    ggplot2::labs(title = plot_title, subtitle = subtitle,
                   x = "Theoretical Quantiles (Normal)",
                   y = paste0("Sample Quantiles (", var_name, ")"),
                   caption = .es_caption("Q-Q Plot")) +
    theme_easystat()

  # Annotate Shapiro badge
  gg <- gg +
    ggplot2::annotate("label",
      x = -Inf, y = Inf, hjust = -0.1, vjust = 1.3,
      label = paste0("SW ", .format_p_statement(sw_p),
                     "\n", badge),
      fill  = if (!is.na(sw_p) && sw_p < 0.05) "#FDECEA" else "#EBF9EE",
      color = if (!is.na(sw_p) && sw_p < 0.05) .ES_COLORS["sig_red"]
              else .ES_COLORS["sig_green"],
      size  = 3.2, fontface = "bold"
    )

  metrics  <- list(var_name = var_name, shapiro_p = sw_p)
  interp   <- .generate_qqplot_interpretation(metrics)
  stats_tbl <- data.frame(
    Metric = c("Shapiro-Wilk p", "Verdict", "n"),
    Value  = c(.format_p_value(sw_p), badge, n),
    stringsAsFactors = FALSE
  )
  .make_easystat_plot("qqplot", gg, interp,
    list(stats_table = stats_tbl, formula_str = paste0("QQ: ", var_name)))
}


# ---------------------------------------------------------------------------
# easy_density  \u2014  Kernel Density Plot
# ---------------------------------------------------------------------------

#' Kernel Density Plot with Optional Group Overlay
#'
#' Draws a smooth kernel density estimate for a numeric variable. If a
#' grouping variable is provided, separate overlapping density curves are
#' drawn per group.
#'
#' @param x Column name or numeric vector.
#' @param data A data frame.
#' @param group_by Optional grouping column for multi-group densities.
#' @param fill_alpha Alpha for filled area. Default \code{0.35}.
#' @param title Custom plot title.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_density <- function(x, data = NULL, group_by = NULL,
                          fill_alpha = 0.35, title = NULL) {
  if (!is.null(data) && is.character(x)) {
    var_name <- x; x_vec <- data[[x]]
  } else {
    var_name <- deparse(substitute(x)); x_vec <- x; data <- data.frame(v = x_vec)
    x <- "v"
  }
  if (!is.numeric(data[[x]])) stop("'x' must be numeric.")

  mn   <- mean(data[[x]], na.rm = TRUE)
  md   <- stats::median(data[[x]], na.rm = TRUE)
  sk   <- .skewness_calc(data[[x]][!is.na(data[[x]])])
  sw_p <- .shapiro_p(data[[x]][!is.na(data[[x]])])
  n    <- sum(!is.na(data[[x]]))

  # Approximate mode from density estimate
  dens_obj    <- stats::density(data[[x]], na.rm = TRUE)
  mode_approx <- dens_obj$x[which.max(dens_obj$y)]

  plot_title <- if (is.null(title)) paste0("Density: ", var_name) else title
  subtitle   <- glue::glue("n = {n}  |  Mean = {round(mn,3)}  |  Skewness = {round(sk,3)}")

  if (!is.null(group_by)) {
    data[[group_by]] <- factor(data[[group_by]])
    gg <- ggplot2::ggplot(data,
            ggplot2::aes(x = .data[[x]], fill = .data[[group_by]],
                          color = .data[[group_by]])) +
          ggplot2::geom_density(alpha = fill_alpha, linewidth = 1.0) +
          ggplot2::scale_fill_manual(values  = .ES_CAT_PALETTE) +
          ggplot2::scale_color_manual(values = .ES_CAT_PALETTE)
  } else {
    gg <- ggplot2::ggplot(data, ggplot2::aes(x = .data[[x]])) +
          ggplot2::geom_density(fill = .ES_COLORS["primary"], alpha = fill_alpha,
                                 color = .ES_COLORS["primary"], linewidth = 1.1) +
          ggplot2::geom_vline(xintercept = mn,  linetype = "solid",
                               color = .ES_COLORS["accent2"], linewidth = 0.9) +
          ggplot2::geom_vline(xintercept = md,  linetype = "longdash",
                               color = .ES_COLORS["accent1"], linewidth = 0.9) +
          ggplot2::geom_vline(xintercept = mode_approx, linetype = "dotted",
                               color = .ES_COLORS["accent3"], linewidth = 0.9)
  }

  gg <- gg +
    ggplot2::labs(title = plot_title, subtitle = subtitle,
                   x = var_name, y = "Density",
                   caption = .es_caption("Density Plot")) +
    theme_easystat()

  metrics <- list(var_name = var_name, mean = mn, median = md,
                  skewness = sk, mode_approx = mode_approx)
  interp  <- .generate_density_interpretation(metrics)
  stats_tbl <- data.frame(
    Metric = c("Mean", "Median", "Mode (approx.)", "Skewness"),
    Value  = round(c(mn, md, mode_approx, sk), 4),
    stringsAsFactors = FALSE
  )
  .make_easystat_plot("density", gg, interp,
    list(stats_table = stats_tbl, formula_str = paste0("Density: ", var_name)))
}


# ---------------------------------------------------------------------------
# easy_correlation_heatmap  \u2014  Correlation Matrix Heatmap
# ---------------------------------------------------------------------------

#' Correlation Matrix Heatmap
#'
#' Computes pairwise correlations and displays them as a color-coded heatmap,
#' annotating each cell with the correlation coefficient and a significance star.
#'
#' @param data A data frame.
#' @param vars Character vector of numeric column names. Default all numerics.
#' @param method Correlation method: \code{"pearson"} (default), \code{"spearman"}.
#' @param title Custom plot title.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_correlation_heatmap <- function(data, vars = NULL,
                                      method = "pearson", title = NULL) {
  if (!is.data.frame(data)) stop("'data' must be a data frame.")
  if (is.null(vars)) vars <- names(data)[sapply(data, is.numeric)]
  if (length(vars) < 2) stop("Need at least 2 numeric variables.")

  corr_result <- .easy_corr_matrix(data, vars, method)
  corr_mat    <- corr_result$corr_matrix_raw

  # Melt to long format manually
  n_v  <- length(vars)
  long <- data.frame(
    Var1 = rep(vars, each = n_v),
    Var2 = rep(vars, times = n_v),
    r    = as.vector(corr_mat),
    stringsAsFactors = FALSE
  )
  long$Var1 <- factor(long$Var1, levels = vars)
  long$Var2 <- factor(long$Var2, levels = rev(vars))

  # Significance stars
  p_mat <- corr_result$raw_model$p_matrix
  long$stars <- ""
  for (i in seq_len(nrow(long))) {
    v1 <- as.character(long$Var1[i])
    v2 <- as.character(long$Var2[i])
    if (v1 != v2 && !is.na(p_mat[v1, v2])) {
      p <- p_mat[v1, v2]
      long$stars[i] <- if (p < 0.001) "***"
                       else if (p < 0.01) "**"
                       else if (p < 0.05) "*" else ""
    }
  }
  long$label <- paste0(round(long$r, 2), long$stars)
  long$label[long$Var1 == long$Var2] <- "1.00"

  plot_title <- if (is.null(title))
    paste0("Correlation Heatmap (", tools::toTitleCase(method), ")") else title

  gg <- ggplot2::ggplot(long,
          ggplot2::aes(x = Var1, y = Var2, fill = r)) +
    ggplot2::geom_tile(color = "white", linewidth = 0.5) +
    ggplot2::geom_text(ggplot2::aes(label = label),
                        color = ifelse(abs(long$r) > 0.55, "white", .ES_COLORS["dark_text"]),
                        size = 3.3, fontface = "bold") +
    ggplot2::scale_fill_gradientn(
      colors = .ES_DIV_PALETTE, limits = c(-1, 1), name = "r",
      breaks = c(-1, -0.5, 0, 0.5, 1)
    ) +
    ggplot2::labs(
      title    = plot_title,
      subtitle = paste0(n_v, " variables  |  * p<5.0000%  ** p<1.0000%  *** p<0.1000%"),
      x = NULL, y = NULL,
      caption  = .es_caption("Correlation Heatmap")
    ) +
    ggplot2::coord_fixed() +
    theme_easystat(legend_position = "right") +
    ggplot2::theme(
      axis.text.x = ggplot2::element_text(angle = 40, hjust = 1),
      panel.grid  = ggplot2::element_blank()
    )

  all_r  <- corr_mat[lower.tri(corr_mat)]
  metrics <- list(method = method, n_vars = n_v,
                  n_pairs = n_v * (n_v - 1) / 2, corr_values = all_r)
  interp <- .generate_corr_heatmap_interpretation(metrics)

  .make_easystat_plot("correlation_heatmap", gg, interp,
    list(stats_table = corr_result$coefficients_table,
         formula_str = paste("Heatmap:", paste(vars, collapse = ", "))))
}


# ---------------------------------------------------------------------------
# easy_regression_diagnostics
# ---------------------------------------------------------------------------

#' Regression Diagnostic Plot
#'
#' Creates a fitted-vs-residuals diagnostic figure for linear regression
#' results returned by \code{\link{easy_regression}}.
#'
#' @param result An \code{"easystat_result"} from \code{easy_regression()}.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_regression_diagnostics <- function(result) {
  if (!inherits(result, "easystat_result") || result$test_type != "regression") {
    stop("'result' must be an easystat_result from easy_regression().")
  }
  model <- result$raw_model
  diag_df <- data.frame(
    Fitted = stats::fitted(model),
    Residual = stats::residuals(model),
    Std_Residual = stats::rstandard(model),
    Cook_Distance = stats::cooks.distance(model),
    stringsAsFactors = FALSE
  )
  cook_cut <- 4 / nrow(diag_df)
  diag_df$Flag <- ifelse(diag_df$Cook_Distance > cook_cut, "High influence", "Typical")

  gg <- ggplot2::ggplot(
    diag_df,
    ggplot2::aes(x = .data[["Fitted"]], y = .data[["Residual"]], color = .data[["Flag"]])
  ) +
    ggplot2::geom_hline(yintercept = 0, linetype = "dashed", color = "#666666") +
    ggplot2::geom_point(alpha = 0.8, size = 2.3) +
    ggplot2::geom_smooth(method = "loess", formula = y ~ x, se = FALSE,
                         color = .ES_COLORS["secondary"], linewidth = 1) +
    ggplot2::scale_color_manual(values = c("High influence" = .ES_COLORS["sig_red"],
                                           "Typical" = .ES_COLORS["primary"])) +
    ggplot2::labs(
      title = "Regression Diagnostics",
      subtitle = paste0("Fitted vs residuals | Cook's D cutoff = ", round(cook_cut, 4)),
      x = "Fitted values",
      y = "Residuals",
      color = NULL,
      caption = .es_caption("Regression Diagnostics")
    ) +
    theme_easystat()

  interp <- glue::glue(
    "REGRESSION DIAGNOSTIC PLOT\n\n",
    "The plot shows residuals against fitted values. A roughly random band around zero ",
    "supports linearity and constant variance. Points flagged as high influence exceed ",
    "the common Cook's distance cutoff of 4/n."
  )

  stats_tbl <- data.frame(
    Metric = c("N", "Cook's D cutoff", "Flagged observations"),
    Value = c(nrow(diag_df), round(cook_cut, 4), sum(diag_df$Flag == "High influence")),
    stringsAsFactors = FALSE
  )
  .make_easystat_plot("regression_diagnostics", gg, interp,
                      list(stats_table = stats_tbl, formula_str = result$formula_str))
}

#' Odds Ratio Plot for Logistic Regression
#'
#' Creates a coefficient figure showing odds ratios and confidence intervals
#' for \code{\link{easy_logistic_regression}} results.
#'
#' @param result An \code{"easystat_result"} from \code{easy_logistic_regression()}.
#'
#' @return An \code{"easystat_result"} object with \code{plot_object}.
#' @export
easy_odds_ratio_plot <- function(result) {
  if (!inherits(result, "easystat_result") || result$test_type != "logistic_regression") {
    stop("'result' must be an easystat_result from easy_logistic_regression().")
  }
  tbl <- result$coefficients_table
  tbl <- tbl[tbl$Term != "(Intercept)", , drop = FALSE]
  if (nrow(tbl) == 0) stop("No predictors available for an odds-ratio plot.")
  tbl$Term <- factor(tbl$Term, levels = rev(tbl$Term))

  gg <- ggplot2::ggplot(tbl, ggplot2::aes(x = .data[["Odds Ratio"]], y = .data[["Term"]])) +
    ggplot2::geom_vline(xintercept = 1, linetype = "dashed", color = "#666666") +
    ggplot2::geom_errorbarh(ggplot2::aes(xmin = .data[["OR CI Lower"]],
                                         xmax = .data[["OR CI Upper"]]),
                            height = 0.18, color = .ES_COLORS["primary"]) +
    ggplot2::geom_point(size = 2.8, color = .ES_COLORS["secondary"]) +
    ggplot2::scale_x_log10() +
    ggplot2::labs(
      title = "Logistic Regression Odds Ratios",
      subtitle = "Values above 1 indicate higher odds; below 1 indicate lower odds",
      x = "Odds ratio (log scale)",
      y = NULL,
      caption = .es_caption("Odds Ratio Plot")
    ) +
    theme_easystat()

  interp <- "ODDS RATIO PLOT\n\nThe plot displays each predictor's odds ratio with its confidence interval. Intervals crossing 1 indicate uncertainty about whether the odds increase or decrease."

  .make_easystat_plot("odds_ratio_plot", gg, interp,
                      list(stats_table = tbl, formula_str = result$formula_str))
}


# ---------------------------------------------------------------------------
# easy_autoplot  \u2014  Smart Plot Dispatcher
# ---------------------------------------------------------------------------

#' Automatically Plot an EasyStat Result
#'
#' Chooses the most appropriate plot type based on the \code{test_type} of an
#' \code{easystat_result} object and renders it.
#'
#' @param result An \code{"easystat_result"} object.
#' @param data The original data frame (required for some plot types).
#' @param ... Additional arguments passed to the underlying plot function.
#'
#' @return An \code{"easystat_result"} plot object, invisibly.
#' @export
easy_autoplot <- function(result, data = NULL, ...) {
  if (!inherits(result, "easystat_result"))
    stop("'result' must be an easystat_result object.")

  formula_str <- result$formula_str

  p <- switch(result$test_type,
    regression = {
      if (is.null(data)) stop("'data' required for autoplot of regression.")
      vars <- all.vars(stats::as.formula(formula_str))
      easy_scatter(stats::as.formula(paste(vars[1], "~", vars[2])), data, ...)
    },
    logistic_regression = {
      easy_odds_ratio_plot(result)
    },
    ttest      = {
      if (is.null(data)) stop("'data' required for autoplot of t-test.")
      easy_boxplot(stats::as.formula(formula_str), data, ...)
    },
    anova      = {
      if (is.null(data)) stop("'data' required for autoplot of ANOVA.")
      easy_boxplot(stats::as.formula(formula_str), data, ...)
    },
    describe   = {
      var_name <- trimws(gsub("Descriptive:", "", formula_str))
      if (is.null(data)) stop("'data' required for autoplot of describe.")
      first_var <- strsplit(var_name, ", ")[[1]][1]
      easy_histogram(first_var, data, ...)
    },
    correlation = {
      vars <- all.vars(stats::as.formula(formula_str))
      if (is.null(data)) stop("'data' required for autoplot of correlation.")
      easy_scatter(stats::as.formula(formula_str), data, ...)
    },
    {
      message("No default autoplot for test type '", result$test_type, "'.")
      return(invisible(NULL))
    }
  )

  print(p)
  invisible(p)
}

#' EasyStat: Automated Statistical Analysis, Visualization and Multi-Format
#' Narrative Reporting
#'
#' @description
#' EasyStat provides a unified pipeline for automated statistical analysis and
#' plain-language narrative reporting in R. The four-step pipeline — Core
#' Statistical Engine, Metric Extractor (broom), Narrative Generator Module, and
#' Unified Result Object — transforms raw data into publication-ready output with
#' a single function call.
#'
#' \strong{Descriptive statistics:}
#' \code{\link{easy_describe}}, \code{\link{easy_group_summary}}
#'
#' \strong{Inferential tests:}
#' \code{\link{easy_regression}}, \code{\link{easy_ttest}},
#' \code{\link{easy_anova}}, \code{\link{easy_chisq}},
#' \code{\link{easy_ztest}}, \code{\link{easy_ftest}},
#' \code{\link{easy_correlation}}
#'
#' \strong{Visualizations:}
#' \code{\link{easy_histogram}}, \code{\link{easy_boxplot}},
#' \code{\link{easy_scatter}}, \code{\link{easy_barplot}},
#' \code{\link{easy_qqplot}}, \code{\link{easy_density}},
#' \code{\link{easy_correlation_heatmap}}, \code{\link{easy_autoplot}}
#'
#' \strong{Reporting:}
#' \code{\link{export_to_word}}, \code{\link{theme_easystat}}
#'
#' @section Authors:
#' Mahesh Divakaran (Amity School of Applied Sciences, Amity University Lucknow),
#' Gunjan Singh (Amity School of Applied Sciences, Amity University Lucknow),
#' Jayadevan Shreedharan (Gulf Medical University)
#'
#' @docType package
#' @name EasyStat-package
#' @aliases EasyStat
"_PACKAGE"

# EasyStat ggplot2 Theme and Color System
# Provides a consistent, professional visual identity for all
# EasyStat plots through a custom ggplot2 theme and a unified color palette.
# (Internal module)

# ---------------------------------------------------------------------------
# EasyStat Color Palette
# ---------------------------------------------------------------------------
.ES_COLORS <- c(
  primary    = "#2E5FA3",   # deep blue  \u2014 main accent
  secondary  = "#E84C4C",   # coral red  \u2014 contrast
  accent1    = "#27AE60",   # emerald
  accent2    = "#F39C12",   # amber
  accent3    = "#8E44AD",   # purple
  accent4    = "#16A085",   # teal
  accent5    = "#2980B9",   # sky blue
  neutral    = "#95A5A6",   # grey
  light_bg   = "#F0F4FB",   # very light blue
  dark_text  = "#2C3E50",   # charcoal
  mid_text   = "#555F6D",   # mid grey
  grid_line  = "#E4EAF5",   # subtle grid
  sig_green  = "#1E8449",   # significance green
  sig_red    = "#C0392B",   # non-significant red
  sig_orange = "#D35400"    # borderline
)

# Categorical palette (for group factors \u2014 up to 8 groups)
.ES_CAT_PALETTE <- unname(c(
  .ES_COLORS["primary"],   .ES_COLORS["secondary"],
  .ES_COLORS["accent1"],   .ES_COLORS["accent2"],
  .ES_COLORS["accent3"],   .ES_COLORS["accent4"],
  .ES_COLORS["accent5"],   .ES_COLORS["neutral"]
))

# Diverging palette for heatmaps (red \u2192 white \u2192 blue)
.ES_DIV_PALETTE <- c("#C0392B", "#E74C3C", "#EC7063", "#F1948A",
                      "#FDFEFE", "#85C1E9", "#5DADE2", "#2E86C1", "#1A5276")

# ---------------------------------------------------------------------------
# Core EasyStat ggplot2 Theme
# ---------------------------------------------------------------------------

#' Apply EasyStat ggplot2 Theme
#'
#' Adds a clean, professional EasyStat visual theme to any ggplot2 object.
#'
#' @param base_size Base font size. Default \code{12}.
#' @param legend_position Where to place the legend. Default \code{"right"}.
#'
#' @return A \code{ggplot2::theme} object.
#' @export
theme_easystat <- function(base_size = 12, legend_position = "right") {
  ggplot2::theme_minimal(base_size = base_size) +
    ggplot2::theme(
      # Titles
      plot.title    = ggplot2::element_text(
        face = "bold", size = base_size + 4, color = .ES_COLORS["primary"],
        margin = ggplot2::margin(b = 6)
      ),
      plot.subtitle = ggplot2::element_text(
        size = base_size, color = .ES_COLORS["mid_text"],
        margin = ggplot2::margin(b = 10)
      ),
      plot.caption  = ggplot2::element_text(
        size = base_size - 2, color = .ES_COLORS["neutral"],
        hjust = 0, margin = ggplot2::margin(t = 8)
      ),
      # Panels
      panel.background = ggplot2::element_rect(fill = .ES_COLORS["light_bg"], color = NA),
      plot.background  = ggplot2::element_rect(fill = "white", color = "#D5DDEF", linewidth = 0.6),
      panel.grid.major = ggplot2::element_line(color = .ES_COLORS["grid_line"], linewidth = 0.5),
      panel.grid.minor = ggplot2::element_blank(),
      panel.border     = ggplot2::element_blank(),
      # Axes
      axis.title    = ggplot2::element_text(size = base_size, color = .ES_COLORS["dark_text"], face = "bold"),
      axis.text     = ggplot2::element_text(size = base_size - 1, color = .ES_COLORS["mid_text"]),
      axis.line     = ggplot2::element_line(color = "#C0CBE0", linewidth = 0.4),
      axis.ticks    = ggplot2::element_line(color = "#C0CBE0", linewidth = 0.4),
      # Legend
      legend.position   = legend_position,
      legend.background = ggplot2::element_rect(fill = "white", color = "#D5DDEF", linewidth = 0.4),
      legend.key        = ggplot2::element_rect(fill = "white"),
      legend.title      = ggplot2::element_text(face = "bold", size = base_size - 1),
      legend.text       = ggplot2::element_text(size = base_size - 2),
      # Facets
      strip.background = ggplot2::element_rect(fill = .ES_COLORS["primary"], color = NA),
      strip.text       = ggplot2::element_text(color = "white", face = "bold", size = base_size - 1),
      # Margins
      plot.margin = ggplot2::margin(16, 16, 12, 16)
    )
}

# ---------------------------------------------------------------------------
# Helper: auto-generate caption with EasyStat branding
# ---------------------------------------------------------------------------
.es_caption <- function(test_label = NULL) {
  base <- "EasyStat | Automated Statistical Reporting"
  if (!is.null(test_label)) paste0(base, " | ", test_label) else base
}

# ---------------------------------------------------------------------------
# Helper: significance badge label for plots
# ---------------------------------------------------------------------------
.sig_badge <- function(p) {
  if (is.na(p))    return("p = NA")
  if (p < 0.001)   return(paste0(.format_p_statement(p), " ***"))
  if (p < 0.01)    return(paste0(.format_p_statement(p), " **"))
  if (p < 0.05)    return(paste0(.format_p_statement(p), " *"))
  if (p < 0.10)    return(paste0(.format_p_statement(p), " ."))
  paste0(.format_p_statement(p), " (ns)")
}

# ---------------------------------------------------------------------------
# Helper: smart class constructor for plot results
# ---------------------------------------------------------------------------
.make_easystat_plot <- function(plot_type, plot_object,
                                 interpretation, data_summary = list()) {
  structure(
    list(
      test_type      = plot_type,
      plot_type      = plot_type,
      plot_object    = plot_object,
      explanation    = interpretation,
      data_summary   = data_summary,
      # Stub tables so export_to_word still works
      coefficients_table = if (!is.null(data_summary$stats_table)) data_summary$stats_table
                           else data.frame(Metric = "See plot", Value = "-"),
      model_fit_table    = data.frame(Metric = "Plot Type", Value = plot_type),
      formula_str        = if (!is.null(data_summary$formula_str)) data_summary$formula_str else plot_type
    ),
    class = "easystat_result"
  )
}

# ---------------------------------------------------------------------------
# Print method extension: handle plot objects inside easystat_result
# ---------------------------------------------------------------------------
# (Patches into existing print.easystat_result dispatch)
.render_plot_console <- function(x) {
  cat("\n[EasyStat Plot: ", x$plot_type, "]\n", sep = "")
  print(x$plot_object)
  cat("\n")
  narrative_lines <- strwrap(x$explanation,
                             width = max(getOption("width", 80) - 2, 58),
                             exdent = 2)
  cat(paste(narrative_lines, collapse = "\n"), "\n\n")
}

#' F-Test for Equality of Variances with Automated Narrative Reporting
#'
#' Performs an F-test to compare the variances of two independent groups using
#' \code{stats::var.test()}, extracts the F-statistic, degrees of freedom,
#' p-value, variance ratio, and confidence interval, and generates a
#' plain-language narrative that includes a practical recommendation for
#' downstream t-test selection (equal vs. unequal variances).
#'
#' @param x A numeric vector (Group 1), OR a formula \code{outcome ~ group}.
#' @param y A numeric vector (Group 2). Ignored when \code{x} is a formula.
#' @param data A data frame. Required when \code{x} is a formula.
#' @param ratio Hypothesized ratio of variances under H0. Default \code{1}.
#' @param alternative \code{"two.sided"} (default), \code{"less"}, or \code{"greater"}.
#' @param conf_level Confidence level for the variance ratio CI. Default \code{0.95}.
#' @param alpha Significance threshold for narrative. Default \code{0.05}.
#'
#' @return An \code{"easystat_result"} object.
#'
#' @examples
#' result <- easy_ftest(mpg ~ am, data = mtcars)
#' print(result)
#'
#' @export
easy_ftest <- function(x, y = NULL, data = NULL, ratio = 1,
                       alternative = "two.sided",
                       conf_level = 0.95, alpha = 0.05) {

  alt_choices <- c("two.sided", "less", "greater")
  alternative <- match.arg(alternative, alt_choices)

  label     <- NULL
  grp1_name <- "Group 1"
  grp2_name <- "Group 2"

  # ---- Parse inputs ----
  if (inherits(x, "formula") || is.character(x)) {
    if (is.character(x)) x <- stats::as.formula(x)
    if (is.null(data)) stop("'data' must be provided when 'x' is a formula.")
    vars <- all.vars(x)
    outcome_var <- vars[1]; group_var <- vars[2]
    label <- deparse(x)
    grp_levels <- levels(factor(data[[group_var]]))
    if (length(grp_levels) != 2)
      stop("The grouping variable must have exactly 2 levels.")
    grp1_name <- grp_levels[1]; grp2_name <- grp_levels[2]
    x_vec <- data[[outcome_var]][data[[group_var]] == grp_levels[1]]
    y_vec <- data[[outcome_var]][data[[group_var]] == grp_levels[2]]
  } else {
    if (is.null(y)) stop("'y' is required for a two-sample F-test when 'x' is a vector.")
    x_vec     <- x
    y_vec     <- y
    grp1_name <- deparse(substitute(x))
    grp2_name <- deparse(substitute(y))
    label     <- paste(grp1_name, "vs.", grp2_name)
  }

  x_vec <- x_vec[!is.na(x_vec)]
  y_vec <- y_vec[!is.na(y_vec)]
  if (length(x_vec) < 2) stop("Group 1 must have at least 2 non-missing observations.")
  if (length(y_vec) < 2) stop("Group 2 must have at least 2 non-missing observations.")

  # ---- Step 1: Core Statistical Engine ----
  vtest <- stats::var.test(x_vec, y_vec, ratio       = ratio,
                            alternative = alternative,
                            conf.level  = conf_level)

  # ---- Step 2: Metric Extractor ----
  tidy_v   <- broom::tidy(vtest)
  f_stat   <- tidy_v$statistic
  df1_val  <- tidy_v$num.df
  df2_val  <- tidy_v$den.df
  p_val    <- tidy_v$p.value
  var_ratio <- f_stat
  ci_lo    <- tidy_v$conf.low
  ci_hi    <- tidy_v$conf.high

  var1  <- round(stats::var(x_vec), 6)
  var2  <- round(stats::var(y_vec), 6)
  sd1   <- round(stats::sd(x_vec), 6)
  sd2   <- round(stats::sd(y_vec), 6)
  n1    <- length(x_vec)
  n2    <- length(y_vec)

  coef_tbl <- data.frame(
    Metric = c(paste0("Variance \u2014 ", grp1_name), paste0("Variance \u2014 ", grp2_name),
               paste0("SD \u2014 ", grp1_name),       paste0("SD \u2014 ", grp2_name),
               paste0("n \u2014 ", grp1_name),        paste0("n \u2014 ", grp2_name),
               "Variance Ratio (F)",
               paste0(round(conf_level * 100), "% CI lower (ratio)"),
               paste0(round(conf_level * 100), "% CI upper (ratio)")),
    Value  = c(var1, var2, sd1, sd2, n1, n2,
               round(var_ratio, 6), round(ci_lo, 6), round(ci_hi, 6)),
    stringsAsFactors = FALSE
  )

  fit_tbl <- data.frame(
    Metric = c("F-statistic", "Numerator df", "Denominator df",
               "p-value", "Alternative", "Conclusion"),
    Value  = c(round(f_stat, 4), df1_val, df2_val,
               .format_p_value(p_val),
               alternative,
               if (!is.na(p_val) && p_val < alpha) "Variances are UNEQUAL" else "Variances are EQUAL"),
    stringsAsFactors = FALSE
  )

  metrics <- list(
    p_value   = p_val,
    f_stat    = f_stat,
    df1       = df1_val,
    df2       = df2_val,
    var_ratio = var_ratio,
    ci_lower  = ci_lo,
    ci_upper  = ci_hi
  )

  explanation <- .generate_ftest_narrative(metrics, label)

  structure(
    list(
      test_type          = "ftest",
      formula_str        = label,
      raw_model          = vtest,
      coefficients_table = coef_tbl,
      model_fit_table    = fit_tbl,
      explanation        = explanation
    ),
    class = "easystat_result"
  )
}

---
title: "Getting Started with EasyStat"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Getting Started with EasyStat}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(
  collapse  = TRUE,
  comment   = "#>",
  fig.width = 7,
  fig.height = 4.5,
  out.width = "100%"
)
library(EasyStat)
```

## Overview

**EasyStat** implements a four-step pipeline that transforms raw data into
publication-ready statistical output with a single function call:

1. **Core Statistical Engine** — wraps base-R `stats` functions (`lm`,
   `t.test`, `aov`, etc.)
2. **Metric Extractor** — uses `broom::tidy()` / `broom::glance()` to
   extract key values (p-value, effect size, CIs, df)
3. **Narrative Generator Module** — applies conditional logic to produce a
   statistically sound, plain-language interpretation
4. **Unified Result Object** — returns an `easystat_result` S3 object that
   prints as HTML in RStudio Viewer or as ASCII in the console, and can be
   exported to Word

---

## Descriptive Statistics

### Single variable

```{r describe-single}
result <- easy_describe(mtcars$mpg)
print(result, viewer = FALSE)
```

### Multiple variables from a data frame

```{r describe-multi}
result <- easy_describe(mtcars, vars = c("mpg", "hp", "wt"))
print(result, viewer = FALSE)
```

### Group summaries

```{r group-summary}
result <- easy_group_summary(mpg ~ cyl, data = mtcars)
print(result, viewer = FALSE)
```

---

## Inferential Tests

### Linear Regression

```{r regression}
result <- easy_regression(mpg ~ wt + hp, data = mtcars)
print(result, viewer = FALSE)
```

### Independent Samples t-Test

```{r ttest}
result <- easy_ttest(mpg ~ am, data = mtcars)
print(result, viewer = FALSE)
```

### One-Way ANOVA

```{r anova}
result <- easy_anova(Sepal.Length ~ Species, data = iris)
print(result, viewer = FALSE)
```

### Chi-Square Test of Independence

```{r chisq}
result <- easy_chisq(~ cyl + am, data = mtcars)
print(result, viewer = FALSE)
```

### F-Test for Equality of Variances

```{r ftest}
result <- easy_ftest(mpg ~ am, data = mtcars)
print(result, viewer = FALSE)
```

### Correlation Analysis

```{r correlation}
result <- easy_correlation(~ mpg + wt, data = mtcars)
print(result, viewer = FALSE)
```

#### Pairwise correlation matrix

```{r corr-matrix}
result <- easy_correlation(mtcars, vars = c("mpg", "hp", "wt", "disp"))
print(result, viewer = FALSE)
```

---

## Visualizations

All plot functions return an `easystat_result` object. Access the ggplot2
object via `result$plot_object` and the plain-language narrative via
`result$explanation`.

### Histogram

```{r histogram}
p <- easy_histogram("mpg", data = mtcars)
p$plot_object
```

### Grouped Box Plot

```{r boxplot}
p <- easy_boxplot(Sepal.Length ~ Species, data = iris)
p$plot_object
```

### Scatter Plot with Regression Line

```{r scatter}
p <- easy_scatter(mpg ~ wt, data = mtcars)
p$plot_object
```

### Bar Chart (mean +/- SE)

```{r barplot}
p <- easy_barplot("mpg", data = mtcars, group_by = "cyl", stat = "mean")
p$plot_object
```

### Q-Q Plot

```{r qqplot}
p <- easy_qqplot("mpg", data = mtcars)
p$plot_object
```

### Density Plot

```{r density}
p <- easy_density("Sepal.Length", data = iris, group_by = "Species")
p$plot_object
```

### Correlation Heatmap

```{r heatmap}
p <- easy_correlation_heatmap(mtcars, vars = c("mpg", "hp", "wt", "qsec", "drat"))
p$plot_object
```

---

## Export to Microsoft Word

`export_to_word()` creates a formatted `.docx` report with the result
narrative and tables.

```{r word-export, eval=FALSE}
reg_result <- easy_regression(mpg ~ wt + hp, data = mtcars)

export_to_word(
  reg_result,
  file   = "MyReport.docx",
  title  = "Fuel Economy Analysis",
  author = "Mahesh Divakaran, Gunjan Singh, Jayadevan Shreedharan"
)
```

---

## The `easystat_result` Object

Every EasyStat function returns a list with class `"easystat_result"`:

| Field | Contents |
|---|---|
| `test_type` | Character identifier (e.g. `"regression"`, `"ttest"`) |
| `formula_str` | Formula or label used |
| `raw_model` | The underlying R model object (`lm`, `htest`, etc.) |
| `coefficients_table` | `data.frame` of parameter estimates |
| `model_fit_table` | `data.frame` of fit / summary statistics |
| `explanation` | Plain-language narrative string |
| `plot_object` | ggplot2 object (visualization functions only) |

You can access any field directly:

```{r fields}
result <- easy_ttest(mpg ~ am, data = mtcars)
cat(result$explanation)
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easystat_theme.R
\name{theme_easystat}
\alias{theme_easystat}
\title{Apply EasyStat ggplot2 Theme}
\usage{
theme_easystat(base_size = 12, legend_position = "right")
}
\arguments{
\item{base_size}{Base font size. Default \code{12}.}

\item{legend_position}{Where to place the legend. Default \code{"right"}.}
}
\value{
A \code{ggplot2::theme} object.
}
\description{
Adds a clean, professional EasyStat visual theme to any ggplot2 object.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_nonparametric.R
\name{easy_kruskal}
\alias{easy_kruskal}
\title{Kruskal-Wallis Test with Automated Narrative Reporting}
\usage{
easy_kruskal(formula, data, alpha = 0.05)
}
\arguments{
\item{formula}{A formula of the form \code{outcome ~ group}.}

\item{data}{A data frame.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An \code{"easystat_result"} object.
}
\description{
Runs a Kruskal-Wallis rank-sum test for comparing three or more groups.
}
\examples{
result <- easy_kruskal(Sepal.Length ~ Species, data = iris)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_regression.R
\name{easy_regression}
\alias{easy_regression}
\title{Run a Linear Regression with Automated Narrative Reporting}
\usage{
easy_regression(formula, data, alpha = 0.05)
}
\arguments{
\item{formula}{A \code{formula} object or a character string formula (e.g.,
\code{"mpg ~ wt + hp"}). Passed directly to \code{stats::lm()}.}

\item{data}{A data frame containing the variables referenced in \code{formula}.}

\item{alpha}{Significance threshold used in narrative generation. Default \code{0.05}.}
}
\value{
An object of class \code{"easystat_result"} (an R \code{list}) with:
  \describe{
    \item{\code{test_type}}{Character: \code{"regression"}}
    \item{\code{formula_str}}{Character string of the formula used}
    \item{\code{raw_model}}{The raw \code{lm} object for advanced use}
    \item{\code{coefficients_table}}{Tidy data frame of coefficients, SEs, t-stats, p-values}
    \item{\code{model_fit_table}}{Data frame with R\eqn{^2}, Adjusted R\eqn{^2}, F-statistic, p-value}
    \item{\code{explanation}}{Plain-language narrative string}
  }
}
\description{
Executes a standard OLS linear regression using \code{stats::lm()}, extracts
key metrics via the \code{broom} package, and automatically generates a
plain-language narrative explanation via the Narrative Generator Module.
}
\examples{
result <- easy_regression(mpg ~ wt + hp, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_autoplot}
\alias{easy_autoplot}
\title{Automatically Plot an EasyStat Result}
\usage{
easy_autoplot(result, data = NULL, ...)
}
\arguments{
\item{result}{An \code{"easystat_result"} object.}

\item{data}{The original data frame (required for some plot types).}

\item{...}{Additional arguments passed to the underlying plot function.}
}
\value{
An \code{"easystat_result"} plot object, invisibly.
}
\description{
Chooses the most appropriate plot type based on the \code{test_type} of an
\code{easystat_result} object and renders it.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_describe.R
\name{easy_group_summary}
\alias{easy_group_summary}
\title{Group-Wise Summary Statistics with Narrative}
\usage{
easy_group_summary(formula, data, digits = 4)
}
\arguments{
\item{formula}{A formula of the form \code{outcome ~ group}.}

\item{data}{A data frame containing the variables.}

\item{digits}{Number of decimal places. Default \code{4}.}
}
\value{
An \code{"easystat_result"} object.
}
\description{
Computes descriptive statistics for a numeric outcome variable stratified
by a grouping factor, providing both a comparison table and a narrative
highlighting which group has the highest/lowest mean and variability.
}
\examples{
result <- easy_group_summary(mpg ~ cyl, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_methods.R
\name{summary.easystat_result}
\alias{summary.easystat_result}
\title{Summarize an EasyStat Result Object}
\usage{
\method{summary}{easystat_result}(object, ...)
}
\arguments{
\item{object}{An \code{"easystat_result"} object.}

\item{...}{Passed to \code{print.easystat_result}.}
}
\value{
Called for its side effects (printing to the console or RStudio
  Viewer). Returns \code{object} invisibly via
  \code{\link{print.easystat_result}}.
}
\description{
Summarize an EasyStat Result Object
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_odds_ratio_plot}
\alias{easy_odds_ratio_plot}
\title{Odds Ratio Plot for Logistic Regression}
\usage{
easy_odds_ratio_plot(result)
}
\arguments{
\item{result}{An \code{"easystat_result"} from \code{easy_logistic_regression()}.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Creates a coefficient figure showing odds ratios and confidence intervals
for \code{\link{easy_logistic_regression}} results.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_anova.R
\name{easy_anova}
\alias{easy_anova}
\title{Run a One-Way ANOVA with Automated Narrative Reporting}
\usage{
easy_anova(formula, data, alpha = 0.05)
}
\arguments{
\item{formula}{A \code{formula} of the form \code{outcome ~ group_factor}, or
a character string. Passed directly to \code{stats::aov()}.}

\item{data}{A data frame containing the variables in \code{formula}.}

\item{alpha}{Significance threshold for the narrative. Default \code{0.05}.}
}
\value{
An object of class \code{"easystat_result"} with:
  \describe{
    \item{\code{test_type}}{Character: \code{"anova"}}
    \item{\code{formula_str}}{Character string of the formula used}
    \item{\code{raw_model}}{The raw \code{aov} object}
    \item{\code{coefficients_table}}{ANOVA table (SS, df, MS, F, p)}
    \item{\code{model_fit_table}}{Summary metrics (F-statistic, eta-squared, p-value)}
    \item{\code{explanation}}{Plain-language narrative string}
  }
}
\description{
Executes a one-way ANOVA using \code{stats::aov()}, extracts key metrics
via \code{broom}, computes eta-squared as an effect-size measure, and
generates a plain-language narrative via the Narrative Generator Module.
}
\examples{
result <- easy_anova(Sepal.Length ~ Species, data = iris)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_histogram}
\alias{easy_histogram}
\title{Annotated Histogram with Normal Curve Overlay}
\usage{
easy_histogram(
  x,
  data = NULL,
  bins = NULL,
  fill_color = NULL,
  show_normal = TRUE,
  title = NULL
)
}
\arguments{
\item{x}{Character column name OR a numeric vector.}

\item{data}{A data frame (required when \code{x} is a column name).}

\item{bins}{Number of histogram bins. Default \code{NULL} (auto).}

\item{fill_color}{Bar fill color. Default EasyStat primary blue.}

\item{show_normal}{Logical; overlay normal curve? Default \code{TRUE}.}

\item{title}{Custom plot title. Default auto-generated.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Draws a histogram of a numeric variable, overlays a fitted normal density
curve, and annotates the plot with the mean, median, and standard deviation.
Normality is assessed via the Shapiro-Wilk test, and the result is displayed
in the subtitle.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_boxplot}
\alias{easy_boxplot}
\title{Grouped Boxplot with Outlier Detection}
\usage{
easy_boxplot(formula, data, fill_palette = NULL, notch = FALSE, title = NULL)
}
\arguments{
\item{formula}{A formula: \code{outcome ~ group} for grouped, or a bare
column name / numeric vector for a single-variable boxplot.}

\item{data}{A data frame.}

\item{fill_palette}{Character vector of fill colors. Default EasyStat palette.}

\item{notch}{Logical; draw notched boxes? Default \code{FALSE}.}

\item{title}{Custom plot title.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Produces a boxplot for one variable, optionally grouped by a factor. Adds
a jittered dot overlay, labels each group's median, and highlights outliers.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_barplot}
\alias{easy_barplot}
\title{Annotated Bar Chart}
\usage{
easy_barplot(
  x,
  data,
  group_by = NULL,
  stat = c("count", "mean"),
  fill_palette = NULL,
  title = NULL
)
}
\arguments{
\item{x}{Column name of the variable to plot.}

\item{data}{A data frame.}

\item{group_by}{Optional grouping column for grouped frequency bars.}

\item{stat}{\code{"count"} (default) for frequency, or \code{"mean"} for
mean ± SE bars.}

\item{fill_palette}{Color palette vector. Default EasyStat palette.}

\item{title}{Custom plot title.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Creates a frequency bar chart for categorical variables, or a mean-and-error
bar chart for numeric outcomes grouped by a factor.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_methods.R
\name{print.easystat_result}
\alias{print.easystat_result}
\title{Print an EasyStat Result Object}
\usage{
\method{print}{easystat_result}(x, viewer = NULL, ...)
}
\arguments{
\item{x}{An object of class \code{"easystat_result"}.}

\item{viewer}{Logical. Force HTML Viewer output (\code{TRUE}) or console
output (\code{FALSE}). Default \code{NULL} auto-detects.}

\item{...}{Currently ignored.}
}
\value{
\code{x} invisibly.
}
\description{
Automatically renders an \code{easystat_result} object. In an interactive
RStudio session the HTML Viewer is used; otherwise clean ASCII tables and
the plain-language narrative are written to the console.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_ftest.R
\name{easy_ftest}
\alias{easy_ftest}
\title{F-Test for Equality of Variances with Automated Narrative Reporting}
\usage{
easy_ftest(
  x,
  y = NULL,
  data = NULL,
  ratio = 1,
  alternative = "two.sided",
  conf_level = 0.95,
  alpha = 0.05
)
}
\arguments{
\item{x}{A numeric vector (Group 1), OR a formula \code{outcome ~ group}.}

\item{y}{A numeric vector (Group 2). Ignored when \code{x} is a formula.}

\item{data}{A data frame. Required when \code{x} is a formula.}

\item{ratio}{Hypothesized ratio of variances under H0. Default \code{1}.}

\item{alternative}{\code{"two.sided"} (default), \code{"less"}, or \code{"greater"}.}

\item{conf_level}{Confidence level for the variance ratio CI. Default \code{0.95}.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An \code{"easystat_result"} object.
}
\description{
Performs an F-test to compare the variances of two independent groups using
\code{stats::var.test()}, extracts the F-statistic, degrees of freedom,
p-value, variance ratio, and confidence interval, and generates a
plain-language narrative that includes a practical recommendation for
downstream t-test selection (equal vs. unequal variances).
}
\examples{
result <- easy_ftest(mpg ~ am, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_chisq.R
\name{easy_chisq}
\alias{easy_chisq}
\title{Chi-Square Tests with Automated Narrative Reporting}
\usage{
easy_chisq(x, y = NULL, data = NULL, p = NULL, correct = TRUE, alpha = 0.05)
}
\arguments{
\item{x}{A factor/character vector, OR a contingency table (matrix), OR a
formula \code{~ var1 + var2} for independence, or \code{~ var1} for GOF.}

\item{y}{A factor/character vector (second categorical variable) for the
independence test. Ignored when \code{x} is a table or formula.}

\item{data}{A data frame. Required when \code{x} is a formula.}

\item{p}{Numeric vector of expected probabilities for the GOF test.
If \code{NULL} (default), equal probabilities are assumed.}

\item{correct}{Logical; apply Yates' continuity correction? Default \code{TRUE}.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An \code{"easystat_result"} object with:
  \describe{
    \item{\code{coefficients_table}}{Observed vs. expected frequency table}
    \item{\code{model_fit_table}}{Chi-square statistic, df, p-value, Cramér's V}
    \item{\code{explanation}}{Plain-language narrative}
  }
}
\description{
Runs either a \strong{chi-square test of independence} (two categorical
variables) or a \strong{goodness-of-fit test} (one variable vs. expected
proportions), extracts Cramér's V as the effect-size measure, and generates
a plain-language narrative via the Narrative Generator Module.
}
\examples{
# Independence test
result <- easy_chisq(~ cyl + am, data = mtcars)
print(result)

# Goodness-of-fit
result <- easy_chisq(~ cyl, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_ztest.R
\name{easy_ztest}
\alias{easy_ztest}
\title{One-Sample and Two-Sample Z-Tests with Automated Narrative Reporting}
\usage{
easy_ztest(
  x,
  y = NULL,
  data = NULL,
  mu = 0,
  sigma = NULL,
  sigma2 = NULL,
  alternative = "two.sided",
  conf_level = 0.95,
  alpha = 0.05
)
}
\arguments{
\item{x}{A numeric vector (Group 1), OR a formula \code{outcome ~ group}
for a two-sample test when \code{data} is provided.}

\item{y}{A numeric vector (Group 2) for a two-sample test. Ignored when
\code{x} is a formula.}

\item{data}{A data frame. Required when \code{x} is a formula.}

\item{mu}{Hypothesized population mean (one-sample) or mean difference
(two-sample). Default \code{0}.}

\item{sigma}{Known population SD for Group 1 (or the single group).
If \code{NULL} (default), the sample SD is used.}

\item{sigma2}{Known population SD for Group 2. If \code{NULL}, uses
the sample SD of Group 2.}

\item{alternative}{\code{"two.sided"} (default), \code{"less"},
or \code{"greater"}.}

\item{conf_level}{Confidence level. Default \code{0.95}.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An \code{"easystat_result"} object.
}
\description{
Performs a z-test using the normal distribution. When the population
standard deviation (\code{sigma}) is not provided, the sample SD is used
(valid for large samples, n \eqn{\geq} 30, by the Central Limit Theorem).
Key metrics — z-statistic, p-value, confidence interval, and Cohen's d —
are extracted and fed to the Narrative Generator Module.
}
\examples{
# One-sample z-test (large n, CLT)
result <- easy_ztest(mtcars$mpg, mu = 20)
print(result)

# Two-sample z-test via formula
result <- easy_ztest(mpg ~ am, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_logistic_regression.R
\name{easy_logistic_regression}
\alias{easy_logistic_regression}
\title{Run a Logistic Regression with Automated Narrative Reporting}
\usage{
easy_logistic_regression(formula, data, alpha = 0.05, conf_level = 0.95)
}
\arguments{
\item{formula}{A \code{formula} object or a character string formula (e.g.,
\code{"am ~ mpg + wt"}). The outcome must be binary.}

\item{data}{A data frame containing the variables referenced in \code{formula}.}

\item{alpha}{Significance threshold used in narrative generation. Default \code{0.05}.}

\item{conf_level}{Confidence level for odds-ratio intervals. Default \code{0.95}.}
}
\value{
An object of class \code{"easystat_result"} with coefficient, odds-ratio,
  model-fit, raw \code{glm}, and narrative components.
}
\description{
Executes a binary logistic regression using \code{stats::glm()} with
\code{family = binomial}, extracts coefficients, odds ratios, approximate
confidence intervals, and model-fit metrics, then generates a plain-language
narrative via the Narrative Generator Module.
}
\examples{
result <- easy_logistic_regression(am ~ mpg + wt, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_regression_diagnostics}
\alias{easy_regression_diagnostics}
\title{Regression Diagnostic Plot}
\usage{
easy_regression_diagnostics(result)
}
\arguments{
\item{result}{An \code{"easystat_result"} from \code{easy_regression()}.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Creates a fitted-vs-residuals diagnostic figure for linear regression
results returned by \code{\link{easy_regression}}.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/export_to_word.R
\name{export_to_word}
\alias{export_to_word}
\title{Export an EasyStat Result to a Formatted Microsoft Word Document}
\usage{
export_to_word(result, file, title = NULL, author = "EasyStat")
}
\arguments{
\item{result}{An object of class \code{"easystat_result"} as returned by
\code{\link{easy_regression}}, \code{\link{easy_logistic_regression}},
\code{\link{easy_ttest}}, or \code{\link{easy_anova}}.}

\item{file}{Character string. Path to the output \code{.docx} file.
Must be provided by the caller; for example, use
\code{tempfile(fileext = ".docx")} for a temporary file.}

\item{title}{Character string. Report title printed at the top of the
document. If \code{NULL} (default) a title is auto-generated from the
test type.}

\item{author}{Character string. Author name(s) for the report header.
Default \code{"EasyStat"}.}
}
\value{
The \code{file} path invisibly (a length-one character vector). The
  \code{.docx} file is written to the path supplied via \code{file} as a
  side-effect.
}
\description{
Takes a unified \code{easystat_result} object and writes a fully formatted
\code{.docx} report using the \code{flextable} and \code{officer} packages.
The report contains a title page header, the plain-language narrative,
both statistical tables rendered as professional \code{flextable} objects,
and a footer with metadata. All of this is produced in a single function call.
}
\examples{
\donttest{
  result <- easy_regression(mpg ~ wt + hp, data = mtcars)
  export_to_word(result, file = tempfile(fileext = ".docx"),
                author = "Mr. Mahesh Divakaran")
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_describe.R
\name{easy_describe}
\alias{easy_describe}
\title{Comprehensive Descriptive Statistics with Narrative}
\usage{
easy_describe(data, vars = NULL, digits = 4, conf_level = 0.95)
}
\arguments{
\item{data}{A numeric vector \strong{or} a data frame.}

\item{vars}{Character vector of column names to describe when \code{data}
is a data frame. If \code{NULL} (default), all numeric columns are used.}

\item{digits}{Number of decimal places in the summary table. Default \code{4}.}

\item{conf_level}{Confidence level for the mean CI. Default \code{0.95}.}
}
\value{
An \code{"easystat_result"} object with:
  \describe{
    \item{\code{coefficients_table}}{Wide-format summary statistics table}
    \item{\code{model_fit_table}}{Shape and normality digest}
    \item{\code{explanation}}{Plain-language narrative (one per variable)}
  }
}
\description{
Computes a rich set of descriptive statistics for one or more numeric
variables, including measures of central tendency, dispersion, shape
(skewness, kurtosis), and normality (Shapiro-Wilk), together with an
automatic plain-language narrative interpretation.
}
\examples{
result <- easy_describe(mtcars, vars = c("mpg", "hp", "wt"))
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_qqplot}
\alias{easy_qqplot}
\title{Normal Q-Q Plot with Shapiro-Wilk Annotation}
\usage{
easy_qqplot(x, data = NULL, title = NULL)
}
\arguments{
\item{x}{Column name or numeric vector.}

\item{data}{A data frame (required when \code{x} is a column name).}

\item{title}{Custom plot title.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Plots sample quantiles against theoretical normal quantiles and annotates
the Shapiro-Wilk p-value. Deviations from the diagonal indicate
non-normality.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_scatter}
\alias{easy_scatter}
\title{Scatter Plot with Regression Line and Correlation Annotation}
\usage{
easy_scatter(
  formula,
  data,
  color_by = NULL,
  smooth = TRUE,
  ellipse = TRUE,
  title = NULL
)
}
\arguments{
\item{formula}{A formula: \code{y ~ x}.}

\item{data}{A data frame.}

\item{color_by}{Optional column name to color points by a third variable.}

\item{smooth}{Logical; show regression line? Default \code{TRUE}.}

\item{ellipse}{Logical; draw a 95\% data ellipse? Default \code{TRUE}.}

\item{title}{Custom plot title.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Draws a scatter plot for two numeric variables, overlays a linear regression
line with confidence band, and annotates the Pearson r and p-value.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_density}
\alias{easy_density}
\title{Kernel Density Plot with Optional Group Overlay}
\usage{
easy_density(x, data = NULL, group_by = NULL, fill_alpha = 0.35, title = NULL)
}
\arguments{
\item{x}{Column name or numeric vector.}

\item{data}{A data frame.}

\item{group_by}{Optional grouping column for multi-group densities.}

\item{fill_alpha}{Alpha for filled area. Default \code{0.35}.}

\item{title}{Custom plot title.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Draws a smooth kernel density estimate for a numeric variable. If a
grouping variable is provided, separate overlapping density curves are
drawn per group.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_ttest.R
\name{easy_ttest}
\alias{easy_ttest}
\title{Run an Independent-Samples t-Test with Automated Narrative Reporting}
\usage{
easy_ttest(
  x,
  y = NULL,
  data = NULL,
  mu = 0,
  var.equal = FALSE,
  conf.level = 0.95,
  alpha = 0.05
)
}
\arguments{
\item{x}{A numeric vector, OR a formula of the form \code{outcome ~ group}
when \code{data} is provided.}

\item{y}{A numeric vector (second group) when \code{x} is not a formula.
Ignored when \code{x} is a formula.}

\item{data}{A data frame. Required when \code{x} is a formula.}

\item{mu}{Null hypothesis value for the mean (one-sample test). Default \code{0}.}

\item{var.equal}{Logical; assume equal variances? Default \code{FALSE} (Welch).}

\item{conf.level}{Confidence level. Default \code{0.95}.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An object of class \code{"easystat_result"} with:
  \describe{
    \item{\code{test_type}}{Character: \code{"ttest"}}
    \item{\code{formula_str}}{Description of the comparison}
    \item{\code{raw_model}}{The raw \code{htest} object}
    \item{\code{coefficients_table}}{Group means and confidence interval}
    \item{\code{model_fit_table}}{t-statistic, df, and p-value}
    \item{\code{explanation}}{Plain-language narrative string}
  }
}
\description{
Executes a two-sample (or one-sample) t-test using \code{stats::t.test()},
extracts key metrics via \code{broom}, and generates a plain-language
narrative via the Narrative Generator Module.
}
\examples{
result <- easy_ttest(mpg ~ am, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_plots.R
\name{easy_correlation_heatmap}
\alias{easy_correlation_heatmap}
\title{Correlation Matrix Heatmap}
\usage{
easy_correlation_heatmap(data, vars = NULL, method = "pearson", title = NULL)
}
\arguments{
\item{data}{A data frame.}

\item{vars}{Character vector of numeric column names. Default all numerics.}

\item{method}{Correlation method: \code{"pearson"} (default), \code{"spearman"}.}

\item{title}{Custom plot title.}
}
\value{
An \code{"easystat_result"} object with \code{plot_object}.
}
\description{
Computes pairwise correlations and displays them as a color-coded heatmap,
annotating each cell with the correlation coefficient and a significance star.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_nonparametric.R
\name{easy_wilcox}
\alias{easy_wilcox}
\title{Wilcoxon Tests with Automated Narrative Reporting}
\usage{
easy_wilcox(
  x,
  y = NULL,
  data = NULL,
  mu = 0,
  paired = FALSE,
  alternative = "two.sided",
  conf_level = 0.95,
  alpha = 0.05
)
}
\arguments{
\item{x}{Numeric vector, or a formula of the form \code{outcome ~ group}.}

\item{y}{Optional numeric vector for paired or two-sample tests.}

\item{data}{Data frame used when \code{x} is a formula.}

\item{mu}{Null hypothesized location or location shift. Default \code{0}.}

\item{paired}{Logical. Use paired test? Default \code{FALSE}.}

\item{alternative}{\code{"two.sided"}, \code{"less"}, or \code{"greater"}.}

\item{conf_level}{Confidence level. Default \code{0.95}.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An \code{"easystat_result"} object.
}
\description{
Runs a one-sample, paired, or two-sample Wilcoxon test using
\code{stats::wilcox.test()} and returns an \code{"easystat_result"} object.
}
\examples{
result <- easy_wilcox(mpg ~ am, data = mtcars)
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/easy_correlation.R
\name{easy_correlation}
\alias{easy_correlation}
\title{Correlation Analysis with Automated Narrative Reporting}
\usage{
easy_correlation(
  x,
  y = NULL,
  data = NULL,
  vars = NULL,
  method = "pearson",
  conf_level = 0.95,
  alpha = 0.05
)
}
\arguments{
\item{x}{A numeric vector, a data frame, OR a formula \code{~ x + y}.}

\item{y}{A numeric vector (paired with \code{x}). Ignored when \code{x}
is a formula or data frame.}

\item{data}{A data frame. Required when \code{x} is a formula.}

\item{vars}{Character vector of column names when \code{x} is a data frame
and pairwise analysis is desired. Default \code{NULL} = all numeric cols.}

\item{method}{Correlation method: \code{"pearson"} (default),
\code{"spearman"}, or \code{"kendall"}.}

\item{conf_level}{Confidence level for Pearson CI. Default \code{0.95}.}

\item{alpha}{Significance threshold for narrative. Default \code{0.05}.}
}
\value{
An \code{"easystat_result"} object.
}
\description{
Computes bivariate or pairwise correlations (Pearson, Spearman, or Kendall)
with significance tests and confidence intervals. For two variables a full
narrative is generated; for multiple variables a correlation matrix is
returned with a summary digest.
}
\examples{
result <- easy_correlation(~ mpg + wt, data = mtcars)
print(result)

result <- easy_correlation(mtcars, vars = c("mpg", "hp", "wt", "disp"))
print(result)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/EasyStat-package.R
\docType{package}
\name{EasyStat-package}
\alias{EasyStat-package}
\alias{EasyStat}
\title{EasyStat: Automated Statistical Analysis, Visualization and Multi-Format
Narrative Reporting}
\description{
EasyStat provides a unified pipeline for automated statistical analysis and
plain-language narrative reporting in R. The four-step pipeline — Core
Statistical Engine, Metric Extractor (broom), Narrative Generator Module, and
Unified Result Object — transforms raw data into publication-ready output with
a single function call.

\strong{Descriptive statistics:}
\code{\link{easy_describe}}, \code{\link{easy_group_summary}}

\strong{Inferential tests:}
\code{\link{easy_regression}}, \code{\link{easy_ttest}},
\code{\link{easy_anova}}, \code{\link{easy_chisq}},
\code{\link{easy_ztest}}, \code{\link{easy_ftest}},
\code{\link{easy_correlation}}

\strong{Visualizations:}
\code{\link{easy_histogram}}, \code{\link{easy_boxplot}},
\code{\link{easy_scatter}}, \code{\link{easy_barplot}},
\code{\link{easy_qqplot}}, \code{\link{easy_density}},
\code{\link{easy_correlation_heatmap}}, \code{\link{easy_autoplot}}

\strong{Reporting:}
\code{\link{export_to_word}}, \code{\link{theme_easystat}}
}
\section{Authors}{

Mahesh Divakaran (Amity School of Applied Sciences, Amity University Lucknow),
Gunjan Singh (Amity School of Applied Sciences, Amity University Lucknow),
Jayadevan Shreedharan (Gulf Medical University)
}

\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/itsmdivakaran/Easystat}
  \item \url{https://itsmdivakaran.github.io/Easystat/}
  \item Report bugs at \url{https://github.com/itsmdivakaran/Easystat/issues}
}

}
\author{
\strong{Maintainer}: Mahesh Divakaran \email{imaheshdivakaran@gmail.com} (Amity School of Applied Sciences, Amity University Lucknow)

Authors:
\itemize{
  \item Gunjan Singh (Amity School of Applied Sciences, Amity University Lucknow)
  \item Jayadevan Shreedharan (Gulf Medical University)
}

}
